[{"id":"node_modules/@jenkins-cd/js-modules/js/ModuleSpec.js","source":"var Version = require('./Version');\n\nfunction ModuleSpec(qName) {\n    var qNameTokens = qName.split(\":\");\n    \n    if (qNameTokens.length === 2) {\n        var namespace = qNameTokens[0].trim();\n        var nsTokens = namespace.split(\"/\");\n        var namespaceProvider = undefined;\n        if (nsTokens.length === 2) {\n            namespaceProvider = nsTokens[0].trim();\n            namespace = nsTokens[1].trim();\n            if (namespaceProvider !== 'plugin' && namespaceProvider !== 'core-assets') {\n                console.error('Unsupported module namespace provider \"' + namespaceProvider + '\". Setting to undefined.');\n                namespaceProvider = undefined;\n            }\n        }\n        \n        var npmName = parseNPMName(qNameTokens[1].trim());\n        \n        this.nsProvider = namespaceProvider;\n        this.namespace = namespace;\n        this.moduleName = npmName.name;\n        this.moduleVersion = npmName.version;\n    } else {\n        // The module/bundle is not in a namespace and doesn't\n        // need to be loaded i.e. it will load itself and export.\n        var npmName = parseNPMName(qNameTokens[0].trim());\n\n        this.moduleName = npmName.name;\n        this.moduleVersion = npmName.version;\n    }\n\n    // Attach version compatibility info\n    var versions = [];\n    \n    if (this.moduleVersion) {\n        var moduleVersionTokens = this.moduleVersion.split(/[,|]+/);\n\n        for (var i = 0; i < moduleVersionTokens.length; i++) {\n            var moduleVersionToken = moduleVersionTokens[i].trim();\n            var parsedVersion = new Version(moduleVersionToken);\n            versions.push(parsedVersion);\n        }\n    }\n    \n    this.moduleCompatVersions = versions;\n}\n\nModuleSpec.prototype.getLoadBundleVersion = function() {\n    if (this.moduleCompatVersions.length === 0) {\n        // If no versions were specified on the name, then we\n        // just return undefined.\n        return undefined;\n    }\n    // If a version is specified, we use the first \"specific\" version\n    // e.g. \"1.1.2\" is specific while \"1.1.x\" and \"any\" are not.\n    for (var i = 0; i < this.moduleCompatVersions.length; i++) {\n        var version = this.moduleCompatVersions[i];\n        if (version.isSpecific()) {\n            return version;\n        }\n    }\n    \n    // If there's no specific version then we return the first\n    // version in the list.\n    return this.moduleCompatVersions[0];\n};\n\nModuleSpec.prototype.getLoadBundleName = function() {\n    var version = this.getLoadBundleVersion();\n    if (version) {\n        return this.moduleName + '@' + version.asBaseVersionString();\n    } else {\n        return this.moduleName;\n    }\n};\n\nModuleSpec.prototype.importAs = function() {\n    if (this.moduleName.charAt(0) === '.') {\n        return this.moduleName;\n    }\n    \n    var version = this.getLoadBundleVersion();\n    var importName = normalizePackageName(this.moduleName);\n    var importNS = this.namespace;\n    \n    if (!importNS) {\n        importNS = importName;\n    }\n    \n    var importAs = importNS + ':' + importName;\n    if (this.nsProvider) {\n        importAs = this.nsProvider + '/' + importAs;\n    }\n    if (version) {\n        importAs += '@' + version.asBaseVersionString();\n    }\n    \n    return importAs;\n};\n\nModuleSpec.prototype.getLoadBundleFileNamePrefix = function() {\n    var version = this.getLoadBundleVersion();\n    var normalizedName = normalizePackageName(this.moduleName);\n    if (version) {\n        // If a version was specified then we only do the script load if a\n        // specific version was provided i.e. loading does not get triggered\n        // by imports that specify non-specific version numbers e.g. \"any\"\n        // or \"1.2.x\". A specific version number would be e.g. \"1.2.3\" i.e.\n        // fully qualified. When loading is not triggered, the import is depending\n        // on another import (with a specific version) or on a bundle do an\n        // export of an internal dependency i.e. on another bundle \"providing\"\n        // the module be exporting it.\n        if (version.isSpecific()) {\n            return normalizedName + '-' + version.asLoadVersionString();\n        } else {\n            return undefined;\n        }\n    } else {\n        return normalizedName;\n    }\n};\n\n/**\n * Normalize an NPM package name by removing all non alpha numerics and replacing\n * with hyphens.\n * @param packageName The NPM package name.\n * @returns The normalized NPM package name.\n */\nfunction normalizePackageName(packageName) {\n    packageName = packageName.replace(/[^\\w.]/g, \"-\"); // replace non alphanumerics.\n    if (packageName.charAt(0) === '-') {\n        packageName = packageName.substring(1);\n    }\n    return packageName;\n};\n\nfunction parseNPMName(resourceName) {\n    if (resourceName.length > 1) {\n        var npmName = {};\n        var orgSlashIndex = resourceName.indexOf('/');\n        \n        if (resourceName.charAt(0) === '@' && orgSlashIndex > 0) {\n            // It's an NPM org package. Strip off the org and package\n            // and add it to the name. We'll get the rest then and parse\n            // that.\n            npmName.name = resourceName.substring(0, orgSlashIndex + 1);\n            \n            // Remove the org part from the name and continue parsing.\n            resourceName = resourceName.substring(orgSlashIndex + 1);\n        } else {\n            // Initialise it so we can append to it below.\n            npmName.name = '';\n        }\n        \n        var versionIndex = resourceName.indexOf('@');\n        if (versionIndex > 0) {\n            npmName.name += resourceName.substring(0, versionIndex);\n            npmName.version = resourceName.substring(versionIndex + 1);\n        } else {\n            npmName.name += resourceName;\n        }\n        \n        return npmName;\n    } else {\n        return {\n            name: resourceName\n        }\n    }\n}\n\nmodule.exports = ModuleSpec;","deps":{"./Version":"node_modules/@jenkins-cd/js-modules/js/Version.js"}},{"id":"node_modules/@jenkins-cd/js-modules/js/ResourceLocationResolver.js","source":"function ResourceLocationResolver(canResolveFunc, resolverFunc, ordinal) {\n    this.canResolveFunc = canResolveFunc;\n    this.resolverFunc = resolverFunc;\n    // Use an ordinal for crude ordering\n    if (typeof ordinal === 'number') {\n        this.ordinal = ordinal;\n    } else {\n        this.ordinal = Number.MAX_VALUE;\n    }\n}\n\nResourceLocationResolver.prototype.canResolve = function(moduleSpec) {\n    return this.canResolveFunc(moduleSpec);\n};\n\nResourceLocationResolver.sort = function (resolvers) {\n    resolvers.sort(function(r1, r2) {\n        return r2.ordinal - r1.ordinal;\n    });\n};\n\nmodule.exports = ResourceLocationResolver;","deps":{}},{"id":"node_modules/@jenkins-cd/js-modules/js/Version.js","source":"function Version(version) {\n    this.raw = version;\n\n    // Remove leading non alphanum chars e.g. to\n    // convert \"^1.2.3\" to \"1.2.3\". If the version is something\n    // like \"any\" then the string will be trimmed to nothing and\n    // the next check catches it.\n    version = version.replace(/^(\\D)/, \"\");\n    \n    if (!version || version.length === 0) {\n        return;\n    }\n    \n    function normalizeToken(string) {\n        // remove anything that's not a digit, a dot or an x.\n        var normalized = string.replace(/[^\\d]/g, '');\n        if (normalized === '') {\n            return undefined;\n        }\n        return normalized;\n    }\n    \n    var versionTokens = version.split('.');\n    \n    this.prerelease = undefined;\n    \n    var patchAndPrerelease = '';\n    for (var i = 2; i < versionTokens.length; i++) {\n        if (patchAndPrerelease.length > 0) {\n            patchAndPrerelease += '.';\n        }\n        patchAndPrerelease += versionTokens[i];\n        \n        var separatorIdx = patchAndPrerelease.indexOf('-');\n        if (separatorIdx !== -1) {\n            this.patch = normalizeToken(patchAndPrerelease.substring(0, separatorIdx));\n            this.prerelease = patchAndPrerelease.substring(separatorIdx + 1);\n        } else {\n            this.patch = normalizeToken(patchAndPrerelease);\n        }\n    }\n    \n    if (versionTokens.length >= 2) {\n        this.minor = normalizeToken(versionTokens[1]);\n    }\n    if (versionTokens.length >= 1) {\n        this.major = normalizeToken(versionTokens[0]);\n    }    \n}\n\nVersion.prototype.isSpecific = function() {\n    return (this.major !== undefined && this.minor !== undefined && this.patch !== undefined);\n};\n\n/**\n * Get the \"base\" version string for this version number.\n * <p/>\n * This string should only ever include the major, minor and patch tokens\n * of the version i.e. should never include a prerelease tag.\n * @returns {string}\n */\nVersion.prototype.asBaseVersionString = function(separator) {\n    separator = (separator ? separator : '.');\n    \n    if (!this.major || this.major === 'x') {\n        if (this.raw === 'any') {\n            return this.raw;\n        } else {\n            return undefined;\n        }\n    } else if (!this.minor || this.minor === 'x') {\n        return this.major + separator + 'x';\n    } else if (!this.patch || this.patch === 'x') {\n        return this.major + separator + this.minor + separator + 'x';\n    } else {\n        return this.major + separator + this.minor + separator + this.patch;\n    }\n};\n\n/**\n * Get the load version string for this version number.\n * <p/>\n * This string should only ever include the major, minor and patch tokens\n * of the version i.e. should never include a prerelease tag. This function\n * just calls <code>asBaseVersionString</code>, supplying a hyphen as the\n * separator.\n * @returns {string}\n */\nVersion.prototype.asLoadVersionString = function() {\n    return this.asBaseVersionString('-');\n};\n\nmodule.exports = Version;","deps":{}},{"id":"node_modules/@jenkins-cd/js-modules/js/index.js","source":"var internal = require(\"./internal\");\nvar promise = require(\"./promise\");\nvar ModuleSpec = require('./ModuleSpec');\nvar onRegisterTimeout;\nvar whoami;\n\n/**\n * What's the top level module/bundle name.\n * @param moduleQName The module QName.\n * @returns The module QName, or undefined if unknown.\n */\nexports.whoami = function(moduleQName) {\n    if (moduleQName) {\n        whoami = moduleQName;\n        internal.whoami(whoami);\n    }\n    return whoami;\n};\n\n/**\n * Asynchronously import/require a set of modules.\n *\n * <p>\n * Responsible for triggering the async loading of modules if a given module is not already loaded.\n *\n * @param moduleQNames... A list of module \"qualified\" names, each containing the module name prefixed with the namespace\n * and separated by a colon i.e. \"<namespace>:<moduleName>\" e.g. \"jquery:jquery2\".\n *\n * @return A Promise, allowing async load of all modules. The promise is only fulfilled when all modules are loaded.\n */\nexports.importModule = function() {\n    if (arguments.length === 1) {\n        return internal.importModule(arguments[0], onRegisterTimeout);\n    }\n\n    var moduleQNames = [];\n    for (var i = 0; i < arguments.length; i++) {\n        var argument = arguments[i];\n        if (typeof argument === 'string') {\n            moduleQNames.push(argument);\n        }\n    }\n\n    if (moduleQNames.length == 0) {\n        throw new Error(\"No module names specified.\");\n    }\n\n    return promise.make(function (resolve, reject) {\n        var fulfillments = [];\n\n        function onFulfillment() {\n            if (fulfillments.length === moduleQNames.length) {\n                var modules = [];\n                for (var i = 0; i < fulfillments.length; i++) {\n                    if (fulfillments[i].value) {\n                        modules.push(fulfillments[i].value);\n                    } else {\n                        // don't have everything yet so can't fulfill all.\n                        return;\n                    }\n                }\n                // If we make it here, then we have fulfilled all individual promises, which \n                // means we can now fulfill the top level import promise.\n                resolve(modules);\n            }\n        }\n\n        // doRequire for each module\n        for (var i = 0; i < moduleQNames.length; i++) {\n            function doRequire(moduleQName) {\n                var promise = internal.importModule(moduleQName, onRegisterTimeout);\n                var fulfillment = {\n                    promise: promise,\n                    value: undefined\n                };\n                fulfillments.push(fulfillment);\n                promise\n                    .onFulfilled(function(value) {\n                        fulfillment.value = value;\n                        onFulfillment();\n                    })\n                    .onRejected(function(error) {\n                        reject(error);\n                    });\n            }\n            doRequire(moduleQNames[i]);\n        }\n    }).applyArgsOnFulfill();\n};\n\n/**\n * Synchronously \"require\" a module that it already loaded/registered.\n *\n * <p>\n * This function will throw an error if the module is not already loaded via an outer call to 'import'\n * (or 'import').\n *\n * @param moduleQName The module \"qualified\" name containing the module name prefixed with the namespace\n * separated by a colon i.e. \"<namespace>:<moduleName>\" e.g. \"jquery:jquery2\".\n *\n * @return The module.\n */\nexports.requireModule = function(moduleQName) {\n    var parsedModuleName = new ModuleSpec(moduleQName);\n    var module = internal.getModule(parsedModuleName);\n    if (!module) {\n        throw new Error(\"Unable to perform synchronous 'require' for module '\" + moduleQName + \"'. This module is not pre-loaded. \" +\n            \"The module needs to have been asynchronously pre-loaded via an outer call to 'import'.\");\n    }\n    return module.exports;\n};\n\n/**\n * Export a module.\n *\n * @param namespace The namespace in which the module resides, or \"undefined\" if the modules is in\n * the \"global\" module namespace e.g. a Jenkins core bundle.\n * @param moduleName The name of the module.\n * @param module The CommonJS style module, or \"undefined\" if we just want to notify other modules waiting on\n * the loading of this module.\n * @param onError On error callback;\n */\nexports.exportModule = function(namespace, moduleName, module, onError) {\n    try {\n        var moduleQName = (namespace ? namespace + ':' : '') + moduleName;\n        var moduleSpec = new ModuleSpec(moduleQName);\n        var moduleNamespaceObj = internal.getModuleNamespaceObj(moduleSpec);\n        var moduleLoadName = moduleSpec.getLoadBundleName();\n\n        if (moduleNamespaceObj[moduleLoadName]) {\n            if (namespace) {\n                console.debug(\"Jenkins plugin module '\" + namespace + \":\" + moduleName + \"' already registered.\");\n            } else {\n                console.debug(\"Jenkins global module '\" + moduleName + \"' already registered.\");\n            }\n            return;\n        }\n\n        if (!module) {\n            module = {\n                exports: {}\n            };\n        } else if (module.exports === undefined) {\n            module = {\n                exports: module\n            };\n        }\n        moduleNamespaceObj[moduleLoadName] = module;\n\n        // Notify all that the module has been registered. See internal.loadModule also.\n        internal.notifyModuleExported(moduleSpec, module.exports);\n    } catch (e) {\n        console.error(e);\n        if (onError) {\n            onError(e);\n        }\n    }\n};\n\n/**\n * Add a resource resolver.\n * @param {ResourceLocationResolver} resourceLocationResolver The resource resolver.\n */\nexports.addResourceLocationResolver = function(resourceLocationResolver) {\n    internal.addResourceLocationResolver(resourceLocationResolver);\n};\n\n/**\n * Get the ResourceLocationResolver function for the supplied ModuleSpec.\n * @param {ModuleSpec} moduleSpec The ModuleSpec.\n * @returns {function} The ResourceLocationResolver function for the supplied\n * ModuleSpec, or null if none specified.\n */\nexports.getResourceLocationResolver = function (moduleSpec) {\n    if (typeof moduleSpec === 'string') {\n        moduleSpec = new ModuleSpec(moduleSpec);\n    }\n    var resolver = internal.getResourceLocationResolverFunc(moduleSpec);\n    if (resolver) {\n        return function(resourcePath) {\n            return resolver(moduleSpec, resourcePath);\n        }\n    }\n    return undefined;\n};\n\n/**\n * Add a module's CSS to the browser page.\n *\n * <p>\n * The assumption is that the CSS can be accessed at e.g.\n * {@code <rootURL>/plugin/<namespace>/jsmodules/<moduleName>/style.css} i.e.\n * the pluginId acts as the namespace.\n *\n * @param namespace The namespace in which the module resides.\n * @param moduleName The name of the module.\n * @param onError On error callback;\n */\nexports.addModuleCSSToPage = function(namespace, moduleName, onError) {\n    try {\n        internal.addModuleCSSToPage(namespace, moduleName);\n    } catch (e) {\n        console.error(e);\n        if (onError) {\n            onError(e);\n        }\n    }\n};\n\n/**\n * Add a plugin CSS file to the browser page.\n *\n * @param pluginName The Jenkins plugin in which the module resides.\n * @param cssPath The CSS path.\n * @param onError On error callback;\n */\nexports.addPluginCSSToPage = function(pluginName, cssPath, onError) {\n    try {\n        internal.addPluginCSSToPage(pluginName, cssPath);\n    } catch (e) {\n        console.error(e);\n        if (onError) {\n            onError(e);\n        }\n    }\n};\n\n/**\n * Create a js-modules CSS id that can be used to refer to a link element.\n * @param cssPath The CSS path/url.\n * @param namespace Optional namespace.\n */\nexports.toCSSId = function (cssPath, namespace) {\n    return internal.toCSSId(cssPath, namespace);\n};\n\n/**\n * Add CSS file to the browser page.\n *\n * @param cssPath The CSS path.\n * @param onError On error callback;\n */\nexports.addCSSToPage = function(cssPath, onError) {\n    try {\n        if (cssPath.indexOf(internal.getAdjunctURL()) === 0) {\n            internal.addCSSToPage(undefined, cssPath);\n        } else if (cssPath.indexOf('http://') === 0 || cssPath.indexOf('https://') === 0) {\n            // the css path is already fully qualified\n            internal.addCSSToPage(undefined, cssPath);\n        } else {\n            internal.addCSSToPage(undefined, internal.getRootURL() + '/' + cssPath);\n        }\n    } catch (e) {\n        console.error(e);\n        if (onError) {\n            onError(e);\n        }\n    }\n};\n\n/**\n * Add a javascript &lt;script&gt; element to the document &lt;head&gt;.\n * <p/>\n * Options:\n * <ul>\n *     <li><strong>scriptId</strong>: The script Id to use for the element. If not specified, one will be generated from the scriptSrc.</li>\n *     <li><strong>async</strong>: Asynchronous loading of the script. Default is 'true'.</li>\n *     <li><strong>success</strong>: An optional onload success function for the script element.</li>\n *     <li><strong>error</strong>: An optional onload error function for the script element. This is called if the .js file exists but there's an error evaluating the script. It is NOT called if the .js file doesn't exist (ala 404).</li>\n *     <li><strong>removeElementOnLoad</strong>: Remove the script element after loading the script. Default is 'false'.</li>\n * </ul>\n *\n * @param scriptSrc The script src.\n * @param options Optional script load options object. See above.\n */\nexports.addScript = function(scriptSrc, options) {\n    internal.addScript(scriptSrc, options);\n};\n\n/**\n * Set the module registration timeout i.e. the length of time to wait for a module to load before failing.\n *\n * @param timeout Millisecond duration before onRegister times out. Defaults to 10000 (10s) if not specified.\n */\nexports.setRegisterTimeout = function(timeout) {\n    onRegisterTimeout = timeout;\n}\n\n/**\n * Set the Jenkins root/base URL.\n *\n * @param rootUrl The root/base URL.\n */\nexports.setRootURL = function(rootUrl) {\n    internal.setRootURL(rootUrl);\n};\n\nexports.getRootURL = internal.getRootURL;\nexports.getAdjunctURL = internal.getAdjunctURL;\n\n/**\n * Manually initialise the Jenkins Global.\n * <p>\n * This should only ever be called from a test environment.\n */\nexports.initJenkinsGlobal = function() {\n    internal.initJenkinsGlobal();\n};\n\ninternal.onJenkinsGlobalInit(function(jenkinsCIGlobal) {\n    // For backward compatibility, we need to make some js-modules\n    // functions globally available e.g. to allow legacy code wait for\n    // certain modules to be loaded, as with legacy adjuncts.\n    if (!jenkinsCIGlobal._internal) {\n        // Put the functions on an object called '_internal' as a way\n        // of hinting to people to not use it.\n        jenkinsCIGlobal._internal = {\n            importModule: exports.importModule,\n            addScript: internal.addScript\n        };\n    }\n});","deps":{"./ModuleSpec":"node_modules/@jenkins-cd/js-modules/js/ModuleSpec.js","./internal":"node_modules/@jenkins-cd/js-modules/js/internal.js","./promise":"node_modules/@jenkins-cd/js-modules/js/promise.js"}},{"id":"node_modules/@jenkins-cd/js-modules/js/internal.js","source":"var promise = require(\"./promise\");\nvar ModuleSpec = require('./ModuleSpec');\nvar ResourceLocationResolver = require('./ResourceLocationResolver');\n\nvar jenkinsCIGlobal;\nvar globalInitListeners = [];\nvar whoami;\n\nexports.whoami = function(moduleQName) {\n    if (moduleQName) {\n        whoami = new ModuleSpec(moduleQName);\n        whoami.nsProvider = getBundleNSProviderFromScriptElement(whoami.namespace, whoami.moduleName);\n    }\n    return whoami;\n};\n\nexports.onJenkinsGlobalInit = function(callback) {\n    globalInitListeners.push(callback);\n};\n\nexports.initJenkinsGlobal = function() {\n    jenkinsCIGlobal = {\n    };\n    if (globalInitListeners) {\n        for (var i = 0; i < globalInitListeners.length; i++) {\n            globalInitListeners[i](jenkinsCIGlobal);\n        }\n    }\n};\n\nexports.clearJenkinsGlobal = function() {    \n    jenkinsCIGlobal = undefined;\n    whoami = undefined;\n};\n\nexports.addResourceLocationResolver = function(resourceLocationResolver) {\n    var resolvers = getResourceLocationResolvers();\n    resolvers.push(resourceLocationResolver);\n    ResourceLocationResolver.sort(resolvers);\n};\n\nexports.getJenkins = function() {\n    if (jenkinsCIGlobal) {\n        return jenkinsCIGlobal;\n    }\n    if (window.jenkinsCIGlobal) {\n        jenkinsCIGlobal = window.jenkinsCIGlobal;\n    } else {\n        exports.initJenkinsGlobal();\n        jenkinsCIGlobal.rootURL = getRootURL();\n        window.jenkinsCIGlobal = jenkinsCIGlobal;\n    }   \n    return jenkinsCIGlobal;\n};\n\nexports.getModuleNamespaceObj = function(moduleSpec) {\n    if (moduleSpec.namespace) {\n        return exports.getNamespace(moduleSpec.namespace);\n    } else {\n        return exports.getGlobalModules();\n    }\n};\n\nexports.getNamespace = function(namespaceName) {\n    var namespaces = exports.getNamespaces();\n    var namespace = namespaces[namespaceName];\n    if (!namespace) {\n        namespace = {\n            globalNS: false            \n        };\n        namespaces[namespaceName] = namespace;\n    }\n    return namespace;\n};\n\nexports.importModule = function(moduleQName, onRegisterTimeout) {\n    return promise.make(function (resolve, reject) {\n        var moduleSpec = new ModuleSpec(moduleQName);\n        var module = exports.getModule(moduleSpec);\n\n        if (module) {\n            // module already loaded\n            resolve(module.exports);\n        } else {\n            if (onRegisterTimeout === 0) {\n                if (moduleSpec.namespace) {\n                    throw new Error('Module ' + moduleSpec.namespace + ':' + moduleSpec.moduleName + ' require failure. Async load mode disabled.');\n                } else {\n                    throw new Error('Global module ' + moduleSpec.moduleName + ' require failure. Async load mode disabled.');\n                }\n            }\n\n            // module not loaded. Load async, fulfilling promise once registered\n            exports.loadModule(moduleSpec, onRegisterTimeout)\n                .onFulfilled(function (moduleExports) {\n                    resolve(moduleExports);\n                })\n                .onRejected(function (error) {\n                    reject(error);\n                });\n        }\n    });    \n};\n\nexports.loadModule = function(moduleSpec, onRegisterTimeout) {\n    var module = exports.getModule(moduleSpec);\n    \n    if (module) {\n        // Module already loaded. This prob shouldn't happen.\n        console.log(\"Unexpected call to 'loadModule' for a module (\" + moduleSpec.moduleName + \") that's already loaded.\");\n        return promise.make(function (resolve) {\n            resolve(module.exports);\n        });\n    }\n\n    function waitForRegistration(loadingModule, onRegisterTimeout) {\n        return promise.make(function (resolve, reject) {\n            if (typeof onRegisterTimeout !== \"number\") {\n                onRegisterTimeout = 10000;\n            }\n            \n            var timeoutObj = setTimeout(function () {\n                // Timed out waiting on the module to load and register itself.\n                if (!loadingModule.loaded) {\n                    var moduleSpec = loadingModule.moduleSpec;\n                    var errorDetail;\n                    \n                    if (moduleSpec.namespace) {\n                        errorDetail = \"Timed out waiting on module '\" + moduleSpec.namespace + \":\" + moduleSpec.moduleName + \"' to load.\";\n                    } else {\n                        errorDetail = \"Timed out waiting on module '\" + moduleSpec.moduleName + \"' to load.\";\n                    }                    \n                    console.error('Module load failure: ' + errorDetail);\n\n                    // Call the reject function and tell it we timed out\n                    reject({\n                        reason: 'timeout',\n                        detail: errorDetail\n                    });\n                }\n            }, onRegisterTimeout);\n            \n            loadingModule.waitList.push({\n                resolve: resolve,\n                timeoutObj: timeoutObj\n            });                    \n        });\n    }\n\n    var loadVersion = moduleSpec.getLoadBundleVersion();\n    var doScriptLoad = true;\n    \n    if (loadVersion) {\n        // If a version was specified then we only do the script load if a\n        // specific version was provided i.e. loading does not get triggered\n        // by imports that specify non-specific version numbers e.g. \"any\"\n        // or \"1.2.x\". A specific version number would be e.g. \"1.2.3\" i.e.\n        // fully qualified. When loading is not triggered, the import is depending\n        // on another import (with a specific version) or on another bundle to do an\n        // export of an internal dependency i.e. on another bundle \"providing\"\n        // the module by exporting it.\n        doScriptLoad = loadVersion.isSpecific();\n    }\n\n    var loadingModule = getLoadingModule(moduleSpec);\n    if (!loadingModule.waitList) {\n        loadingModule.waitList = [];\n    }\n    loadingModule.moduleSpec = moduleSpec; \n    loadingModule.loaded = false;\n\n    try {\n        return waitForRegistration(loadingModule, onRegisterTimeout);\n    } finally {\n        if (doScriptLoad && !loadingModule.loadedBy) {\n            // Capture the name of the bundle that triggered importing/loading\n            // of the bundle.\n            loadingModule.loadedBy = whoami;\n\n            var loadModuleName = moduleSpec.getLoadBundleName();\n            var scriptId = exports.toModuleId(moduleSpec.namespace, loadModuleName) + ':js';\n            var scriptSrc = exports.toModuleSrc(moduleSpec, 'js');\n            var scriptEl = exports.addScript(scriptSrc, {\n                scriptId: scriptId,\n                scriptSrcBase: ''\n            });\n\n            if (scriptEl) {\n                // Set the module spec info on the <script> element. This allows us to resolve the\n                // nsProvider for that bundle after 'whoami' is called for it (as it loads). whoami\n                // is not called with the nsProvider info on it because a given bundle can\n                // potentially be loaded from multiple different ns providers, so we only resole the provider\n                // at load-time i.e. just after a bundle is loaded it calls 'whoami' for itself\n                // and then this module magically works out where it was loaded from (it's nsProvider)\n                // by locating the <script> element and using this information. For a module/bundle, knowing\n                // where it was loaded from is important because it dictates where that module/bundle\n                // should load it dependencies from. For example, the Bootstrap module/bundle depends on the\n                // jQuery bundle. So, if the bootstrap bundle is loaded from the 'core-assets' namespace provider,\n                // then that means the jQuery bundle should also be loaded from the 'core-assets'\n                // namespace provider.\n                // See getBundleNSProviderFromScriptElement.\n                scriptEl.setAttribute('data-jenkins-module-nsProvider', moduleSpec.nsProvider);\n                scriptEl.setAttribute('data-jenkins-module-namespace', moduleSpec.namespace);\n                scriptEl.setAttribute('data-jenkins-module-moduleName', loadModuleName);\n            } else {\n                loadingModule.loadedBy = undefined;\n            }\n        }\n    }\n};\n\nexports.addScript = function(scriptSrc, options) {\n    if (!scriptSrc) {\n        console.warn('Call to addScript with undefined \"scriptSrc\" arg.');\n        return undefined;\n    }    \n    \n    var normalizedOptions;\n    \n    // If there's no options object, create it.\n    if (typeof options === 'object') {\n        normalizedOptions = options;\n    } else {\n        normalizedOptions = {};\n    }\n    \n    // May want to transform/map some urls.\n    if (normalizedOptions.scriptSrcMap) {\n        if (typeof normalizedOptions.scriptSrcMap === 'function') {\n            scriptSrc = normalizedOptions.scriptSrcMap(scriptSrc);\n        } else if (Array.isArray(normalizedOptions.scriptSrcMap)) {\n            // it's an array of suffix mappings\n            for (var i = 0; i < normalizedOptions.scriptSrcMap.length; i++) {\n                var mapping = normalizedOptions.scriptSrcMap[i];\n                if (mapping.from && mapping.to) {\n                    if (endsWith(scriptSrc, mapping.from)) {\n                        normalizedOptions.originalScriptSrc = scriptSrc;\n                        scriptSrc = scriptSrc.replace(mapping.from, mapping.to);\n                        break;\n                    }\n                }\n            }\n        }\n    }\n    \n    normalizedOptions.scriptId = getScriptId(scriptSrc, options);\n    \n    // set some default options\n    if (normalizedOptions.async === undefined) {\n        normalizedOptions.async = true;\n    }\n    if (normalizedOptions.scriptSrcBase === undefined) {\n        normalizedOptions.scriptSrcBase = '@root';\n    }\n    \n    if (normalizedOptions.scriptSrcBase === '@root') {\n        normalizedOptions.scriptSrcBase = getRootURL() + '/';\n    } else if (normalizedOptions.scriptSrcBase === '@adjunct') {\n        normalizedOptions.scriptSrcBase = getAdjunctURL() + '/';\n    }\n\n    var document = window.document;\n    var head = exports.getHeadElement();\n    var script = document.getElementById(normalizedOptions.scriptId);\n\n    if (script) {\n        var replaceable = script.getAttribute('data-replaceable');\n        if (replaceable && replaceable === 'true') {\n            // This <script> element is replaceable. In this case, \n            // we remove the existing script element and add a new one of the\n            // same id and with the specified src attribute.\n            // Adding happens below.\n            script.parentNode.removeChild(script);\n        } else {\n            return undefined;\n        }\n    }\n\n    script = createElement('script');\n\n    // Parts of the following onload code were inspired by how the ACE editor does it,\n    // as well as from the follow SO post: http://stackoverflow.com/a/4845802/1166986\n    var onload = function (_, isAborted) {\n        script.setAttribute('data-onload-complete', true);\n        try {\n            if (isAborted) {\n                console.warn('Script load aborted: ' + scriptSrc);\n            } else if (!script.readyState || script.readyState === \"loaded\" || script.readyState === \"complete\") {\n                // If the options contains an onload function, call it.\n                if (typeof normalizedOptions.success === 'function') {\n                    normalizedOptions.success(script);\n                }\n                return;\n            }\n            if (typeof normalizedOptions.error === 'function') {\n                normalizedOptions.error(script, isAborted);\n            }\n        } finally {\n            if (normalizedOptions.removeElementOnLoad) {\n                head.removeChild(script);\n            }\n            // Handle memory leak in IE\n            script = script.onload = script.onreadystatechange = null;\n        }\n    };\n    script.onload = onload; \n    script.onreadystatechange = onload;\n\n    script.setAttribute('id', normalizedOptions.scriptId);\n    script.setAttribute('type', 'text/javascript');\n    script.setAttribute('src', normalizedOptions.scriptSrcBase + scriptSrc);\n    if (normalizedOptions.originalScriptSrc) {\n        script.setAttribute('data-referrer', normalizedOptions.originalScriptSrc);        \n    }\n    if (normalizedOptions.async) {\n        script.setAttribute('async', normalizedOptions.async);\n    }\n    \n    head.appendChild(script);\n    \n    return script;\n};\n\nexports.notifyModuleExported = function(moduleSpec, moduleExports) {\n    var loadingModule = getLoadingModule(moduleSpec);\n    \n    loadingModule.loaded = true;\n    if (loadingModule.waitList) {\n        for (var i = 0; i < loadingModule.waitList.length; i++) {\n            var waiter = loadingModule.waitList[i];\n            clearTimeout(waiter.timeoutObj);\n            waiter.resolve(moduleExports);\n        }\n    }    \n};\n\nexports.addModuleCSSToPage = function(namespace, moduleName) {\n    var moduleSpec = exports.getModuleSpec(namespace + ':' + moduleName);\n    var cssElId = exports.toModuleId(namespace, moduleName) + ':css';\n    var cssPath = exports.toModuleSrc(moduleSpec, 'css');\n    return exports.addCSSToPage(namespace, cssPath, cssElId);\n};\n\nexports.addPluginCSSToPage = function(namespace, cssPath, cssElId) {\n    var cssPath = exports.getPluginPath(namespace) + '/' + cssPath;\n    return exports.addCSSToPage(namespace, cssPath, cssElId);\n};\n\nexports.toCSSId = function (cssPath, namespace) {\n    return 'jenkins-js-module:' + (namespace || 'global' ) + ':css:' + cssPath;\n};\n\nexports.addCSSToPage = function(namespace, cssPath, cssElId) {\n    var document = window.document;\n    \n    if (cssElId === undefined) {\n        cssElId = exports.toCSSId(cssPath, namespace);\n    }\n    \n    var cssEl = document.getElementById(cssElId);\n    \n    if (cssEl) {\n        // already added to page\n        return;\n    }\n\n    var docHead = exports.getHeadElement();\n    cssEl = createElement('link');\n    cssEl.setAttribute('id', cssElId);\n    cssEl.setAttribute('type', 'text/css');\n    cssEl.setAttribute('rel', 'stylesheet');\n    cssEl.setAttribute('href', cssPath);\n    docHead.appendChild(cssEl);\n\n    return cssEl;\n};\n\nexports.getGlobalModules = function() {\n    var jenkinsCIGlobal = exports.getJenkins();\n    if (!jenkinsCIGlobal.globals) {\n        jenkinsCIGlobal.globals = {\n            globalNS: true\n        };\n    }\n    return jenkinsCIGlobal.globals;\n};\n\nexports.getNamespaces = function() {\n    var jenkinsCIGlobal = exports.getJenkins();\n\n    // The namespaces are stored in an object named \"plugins\". This is a legacy from the\n    // time when all modules lived in plugins. By right we'd like to rename this, but\n    // that would cause compatibility issues.\n\n    if (!jenkinsCIGlobal.plugins) {\n        jenkinsCIGlobal.plugins = {\n            __README__: 'This object holds namespaced JS modules/bundles, with the property names representing the module namespace. It\\'s name (\"plugins\") is a legacy thing. Changing it to a better name (e.g. \"namespaces\") would cause compatibility issues.'\n        };\n    }\n    return jenkinsCIGlobal.plugins;\n};\n\nexports.toModuleId = function(namespace, moduleName) {\n    return 'jenkins-js-module:' + (namespace ? namespace + ':' : '') + moduleName;\n};\n\nexports.toModuleSrc = function(moduleSpec, srcType) {\n    var nsProvider = moduleSpec.nsProvider;\n\n    // If a moduleSpec on a module/bundle import doesn't specify a namespace provider\n    // (i.e. is of the form \"a:b\" and not \"core-assets/a:b\"),\n    // then check \"this\" bundles module spec and see if it was imported from a specific\n    // namespace. If it was (e.g. 'core-assets'), then import from that namespace.\n    if (nsProvider === undefined) {\n        nsProvider = thisBundleNamespaceProvider();\n        if (nsProvider === undefined) {\n            nsProvider = 'adjuncts';\n        }\n        // Store the nsProvider back onto the moduleSpec.\n        moduleSpec.nsProvider = nsProvider;\n    }\n\n    var srcPath = undefined;\n    if (srcType === 'js') {\n        srcPath = moduleSpec.getLoadBundleFileNamePrefix() + '.js';\n    } else if (srcType === 'css') {\n        srcPath = moduleSpec.getLoadBundleFileNamePrefix() + '/style.css';\n    } else {\n        throw new Error('Unsupported srcType \"'+ srcType + '\".');\n    }\n\n    // Maybe there's a custom resource resolver for this resource.\n    var resourceLocationResolverFunc = getResourceLocationResolverFunc(moduleSpec);\n    if (resourceLocationResolverFunc) {\n        var resourcePath = resourceLocationResolverFunc(moduleSpec, srcPath);\n        if (resourcePath) {\n            return resourcePath;\n        }\n    }\n\n    // Default resource resolution ...\n    if (nsProvider === 'adjuncts') {\n        return exports.getAdjunctJSModulesPath(moduleSpec.namespace) + '/' + srcPath;\n    } else if (nsProvider === 'plugin') {\n        return exports.getPluginJSModulesPath(moduleSpec.namespace) + '/' + srcPath;\n    } else if (nsProvider === 'core-assets') {\n        return exports.getCoreAssetsJSModulesPath(moduleSpec.namespace) + '/' + srcPath;\n    } else {\n        throw new Error('Unsupported namespace provider: ' + nsProvider);\n    }\n};\n\nexports.getAdjunctJSModulesPath = function(namespace) {\n    if (namespace) {\n        return getAdjunctURL() + '/org/jenkins/ui/jsmodules/' + namespace;\n    } else {\n        return getAdjunctURL() + '/org/jenkins/ui/jsmodules';\n    }\n};\n\nexports.getPluginJSModulesPath = function(pluginId) {\n    return exports.getPluginPath(pluginId) + '/jsmodules';\n};\n\nexports.getCoreAssetsJSModulesPath = function(namespace) {\n    return getRootURL() + '/assets/' + namespace + '/jsmodules';\n};\n\nexports.getPluginPath = function(pluginId) {\n    return getRootURL() + '/plugin/' + pluginId;\n};\n\nexports.getHeadElement = function() {\n    var docHead = window.document.getElementsByTagName(\"head\");\n    if (!docHead || docHead.length == 0) {\n        throw new Error('No head element found in document.');\n    }\n    return docHead[0];\n};\n\nexports.setRootURL = function(url) {    \n    if (!jenkinsCIGlobal) {\n        exports.initJenkinsGlobal();\n    }\n    jenkinsCIGlobal.rootURL = url;\n};\n\nexports.getModule = function(moduleSpec) {\n    var namespace = exports.getModuleNamespaceObj(moduleSpec);\n    \n    if (!moduleSpec.moduleVersion) {\n        return namespace[moduleSpec.moduleName];\n    } else {\n        for (var i = 0; i < moduleSpec.moduleCompatVersions.length; i++) {\n            var moduleCompatVersion = moduleSpec.moduleCompatVersions[i];\n            var module = namespace[moduleSpec.moduleName + '@' + moduleCompatVersion.raw];\n            if (module) {\n                return module;\n            }\n        }\n    }\n    \n    return undefined;\n};\n\nexports.getModuleSpec = function(moduleQName) {\n    var moduleSpec = new ModuleSpec(moduleQName);\n    var moduleNamespaceObj = exports.getModuleNamespaceObj(moduleSpec);\n    if (moduleNamespaceObj) {\n        var loading = getLoadingModule(moduleSpec);\n        if (loading && loading.moduleSpec) {\n            return loading.moduleSpec;\n        }\n    }\n    return moduleSpec;\n};\n\nfunction getResourceLocationResolvers() {\n    var jenkinsCIGlobal = exports.getJenkins();\n    if (!jenkinsCIGlobal.resourceLocationResolvers) {\n        jenkinsCIGlobal.resourceLocationResolvers = [];\n    }\n    return jenkinsCIGlobal.resourceLocationResolvers;\n}\n\nfunction getResourceLocationResolverFunc(moduleSpec) {\n    var resolvers = getResourceLocationResolvers();\n\n    for (var i = 0; i < resolvers.length; i++) {\n        var resolver = resolvers[i];\n        if (resolver && resolver.canResolve(moduleSpec)) {\n            return resolver.resolverFunc;\n        }\n    }\n\n    // Failed to find a specific resolver for the supplied moduleSpec.\n    // In this case, lets try the resolver used to load the bundle\n    // that's currently loading this resource. Iow, resources should\n    // be loaded from the same location as the bundle that's triggering\n    // the loading of that resource. Obviously this is recursive up\n    // through the \"parents\".\n    var loadingModule = getLoadingModule(moduleSpec);\n    if (loadingModule.loadedBy) {\n        return getResourceLocationResolverFunc(loadingModule.loadedBy);\n    }\n\n    return undefined;\n}\nexports.getResourceLocationResolverFunc = getResourceLocationResolverFunc;\n\nfunction getScriptId(scriptSrc, config) {\n    if (typeof config === 'string') {\n        return config;\n    } else if (typeof config === 'object' && config.scriptId) {\n        return config.scriptId;\n    } else {\n        return 'jenkins-script:' + scriptSrc;\n    }    \n}\n\nexports.getRootURL = getRootURL;\nfunction getRootURL() {\n    if (jenkinsCIGlobal && jenkinsCIGlobal.rootURL) {\n        return jenkinsCIGlobal.rootURL;\n    }\n    \n    var docHead = exports.getHeadElement();\n    var rootURL = getAttribute(docHead, \"data-rooturl\");\n\n    if (rootURL === undefined || rootURL === null) {\n        // Backward compatibility - used to use a 'resurl' attribute.\n        rootURL = getAttribute(docHead, \"resurl\");\n        if (rootURL === undefined || rootURL === null) {\n            throw new Error(\"Attribute 'data-rooturl' not defined on the document <head> element.\");\n        }\n    }\n\n    if (jenkinsCIGlobal) {\n        jenkinsCIGlobal.rootURL = rootURL;\n    }\n    \n    return rootURL;\n}\n\nexports.getAdjunctURL = getAdjunctURL;\nfunction getAdjunctURL() {\n    if (jenkinsCIGlobal && jenkinsCIGlobal.adjunctURL) {\n        return jenkinsCIGlobal.adjunctURL;\n    }\n    \n    var docHead = exports.getHeadElement();\n    var adjunctURL = getAttribute(docHead, \"data-adjuncturl\");\n\n    if (adjunctURL === undefined || adjunctURL === null) {\n        // Backward compatibility - older Jenkins do not have the adjunct url on the\n        // <head> element. Lets try getting the resurl (older jenkins) and patching it \n        // to be an adjunct url.\n        adjunctURL = getAttribute(docHead, \"resurl\");\n        if (adjunctURL === undefined || adjunctURL === null) {\n            throw new Error(\"Attribute 'data-adjuncturl' not defined on the document <head> element.\");\n        }\n        // Replace the first occurrence of 'static/' with 'adjuncts/' \n        adjunctURL = adjunctURL.replace('static\\/', 'adjuncts\\/');\n    }\n\n    if (jenkinsCIGlobal) {\n        jenkinsCIGlobal.adjunctURL = adjunctURL;\n    }\n    \n    return adjunctURL;\n}\n\nfunction createElement(name) {\n    var document = window.document;\n    return document.createElement(name);\n}\n\nfunction getAttribute(element, attributeName) {\n    var value = element.getAttribute(attributeName.toLowerCase());\n    \n    if (value) {\n        return value;\n    } else {\n        // try without lowercasing\n        return element.getAttribute(attributeName);\n    }    \n}\n\nfunction getLoadingModule(moduleSpec) {\n    var moduleNamespaceObj = exports.getModuleNamespaceObj(moduleSpec);\n    var moduleName = moduleSpec.getLoadBundleName();\n\n    if (!moduleNamespaceObj.loadingModules) {\n        moduleNamespaceObj.loadingModules = {};\n    }\n    if (!moduleNamespaceObj.loadingModules[moduleName]) {\n        moduleNamespaceObj.loadingModules[moduleName] = {};\n    }\n    return moduleNamespaceObj.loadingModules[moduleName];\n}\n\nfunction endsWith(string, suffix) {\n    return (string.indexOf(suffix, string.length - suffix.length) !== -1);\n}\n\nfunction thisBundleNamespaceProvider() {\n    if (whoami !== undefined) {\n        return whoami.nsProvider;\n    }\n    return undefined;\n}\n\nfunction getBundleNSProviderFromScriptElement(namespace, moduleName) {\n    var docHead = exports.getHeadElement();\n    var scripts = docHead.getElementsByTagName(\"script\");\n\n    for (var i = 0; i < scripts.length; i++) {\n        var script = scripts[i];\n        var elNamespace = script.getAttribute('data-jenkins-module-namespace');\n        var elModuleName = script.getAttribute('data-jenkins-module-moduleName');\n\n        if (elNamespace === namespace && elModuleName === moduleName) {\n            return script.getAttribute('data-jenkins-module-nsProvider');\n        }\n    }\n\n    return undefined;\n}","deps":{"./ModuleSpec":"node_modules/@jenkins-cd/js-modules/js/ModuleSpec.js","./ResourceLocationResolver":"node_modules/@jenkins-cd/js-modules/js/ResourceLocationResolver.js","./promise":"node_modules/@jenkins-cd/js-modules/js/promise.js"}},{"id":"node_modules/@jenkins-cd/js-modules/js/promise.js","source":"exports.make = function(executor) {\n    var thePromise = new APromise();\n    executor.call(thePromise, function(result) {\n        thePromise.resolve(result);\n    }, function(reason) {\n        thePromise.reject(reason);\n    });\n    return thePromise;\n};\n\nfunction APromise() {\n    this.state = 'PENDING';\n    this.whenFulfilled = undefined;\n    this.whenRejected = undefined;\n    this.applyFulfillArgs = false;\n}\n\nAPromise.prototype.applyArgsOnFulfill = function() {\n    this.applyFulfillArgs = true;\n    return this;\n}\n\nAPromise.prototype.resolve = function (result) {\n    this.state = 'FULFILLED';\n    \n    var thePromise = this;\n    function doFulfill(whenFulfilled, result) {\n        if (thePromise.applyFulfillArgs) {\n            whenFulfilled.apply(whenFulfilled, result);\n        } else {\n            whenFulfilled(result);\n        }\n    }\n    \n    if (this.whenFulfilled) {\n        doFulfill(this.whenFulfilled, result);\n    }\n    // redefine \"onFulfilled\" to call immediately\n    this.onFulfilled = function (whenFulfilled) {\n        if (whenFulfilled) {\n            doFulfill(whenFulfilled, result);\n        }\n        return this;\n    }\n};\n\nAPromise.prototype.reject = function (reason) {\n    this.state = 'REJECTED';\n    if (this.whenRejected) {\n        this.whenRejected(reason);\n    }\n    // redefine \"onRejected\" to call immediately\n    this.onRejected = function(whenRejected) {\n        if (whenRejected) {\n            whenRejected(reason);\n        }\n        return this;\n    }\n};\n\nAPromise.prototype.onFulfilled = function(whenFulfilled) {\n    if (!whenFulfilled) {\n        throw new Error('Must provide an \"whenFulfilled\" callback.');\n    }\n    this.whenFulfilled = whenFulfilled;\n    return this;\n};\n\nAPromise.prototype.onRejected = function(whenRejected) {        \n    if (whenRejected) {\n        this.whenRejected = whenRejected;\n    }\n    return this;\n};","deps":{}},{"id":"node_modules/babel-polyfill/lib/index.js","source":"(function (global){\n\"use strict\";\n\nrequire(\"core-js/shim\");\n\nrequire(\"regenerator-runtime/runtime\");\n\nrequire(\"core-js/fn/regexp/escape\");\n\nif (global._babelPolyfill) {\n  throw new Error(\"only one instance of babel-polyfill is allowed\");\n}\nglobal._babelPolyfill = true;\n\nvar DEFINE_PROPERTY = \"defineProperty\";\nfunction define(O, key, value) {\n  O[key] || Object[DEFINE_PROPERTY](O, key, {\n    writable: true,\n    configurable: true,\n    value: value\n  });\n}\n\ndefine(String.prototype, \"padLeft\", \"\".padStart);\ndefine(String.prototype, \"padRight\", \"\".padEnd);\n\n\"pop,reverse,shift,keys,values,entries,indexOf,every,some,forEach,map,filter,find,findIndex,includes,join,slice,concat,push,splice,unshift,sort,lastIndexOf,reduce,reduceRight,copyWithin,fill\".split(\",\").forEach(function (key) {\n  [][key] && define(Array, key, Function.call.bind([][key]));\n});\n}).call(this,typeof global !== \"undefined\" ? global : typeof self !== \"undefined\" ? self : typeof window !== \"undefined\" ? window : {})","deps":{"core-js/fn/regexp/escape":"node_modules/babel-polyfill/node_modules/core-js/fn/regexp/escape.js","core-js/shim":"node_modules/babel-polyfill/node_modules/core-js/shim.js","regenerator-runtime/runtime":"node_modules/regenerator-runtime/runtime.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/fn/regexp/escape.js","source":"require('../../modules/core.regexp.escape');\nmodule.exports = require('../../modules/_core').RegExp.escape;","deps":{"../../modules/_core":"node_modules/babel-polyfill/node_modules/core-js/modules/_core.js","../../modules/core.regexp.escape":"node_modules/babel-polyfill/node_modules/core-js/modules/core.regexp.escape.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_a-function.js","source":"module.exports = function(it){\n  if(typeof it != 'function')throw TypeError(it + ' is not a function!');\n  return it;\n};","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_a-number-value.js","source":"var cof = require('./_cof');\nmodule.exports = function(it, msg){\n  if(typeof it != 'number' && cof(it) != 'Number')throw TypeError(msg);\n  return +it;\n};","deps":{"./_cof":"node_modules/babel-polyfill/node_modules/core-js/modules/_cof.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_add-to-unscopables.js","source":"var UNSCOPABLES = require('./_wks')('unscopables')\n  , ArrayProto  = Array.prototype;\nif(ArrayProto[UNSCOPABLES] == undefined)require('./_hide')(ArrayProto, UNSCOPABLES, {});\nmodule.exports = function(key){\n  ArrayProto[UNSCOPABLES][key] = true;\n};","deps":{"./_hide":"node_modules/babel-polyfill/node_modules/core-js/modules/_hide.js","./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-instance.js","source":"module.exports = function(it, Constructor, name, forbiddenField){\n  if(!(it instanceof Constructor) || (forbiddenField !== undefined && forbiddenField in it)){\n    throw TypeError(name + ': incorrect invocation!');\n  } return it;\n};","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","source":"var isObject = require('./_is-object');\nmodule.exports = function(it){\n  if(!isObject(it))throw TypeError(it + ' is not an object!');\n  return it;\n};","deps":{"./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-copy-within.js","source":"'use strict';\nvar toObject = require('./_to-object')\n  , toIndex  = require('./_to-index')\n  , toLength = require('./_to-length');\n\nmodule.exports = [].copyWithin || function copyWithin(target/*= 0*/, start/*= 0, end = @length*/){\n  var O     = toObject(this)\n    , len   = toLength(O.length)\n    , to    = toIndex(target, len)\n    , from  = toIndex(start, len)\n    , end   = arguments.length > 2 ? arguments[2] : undefined\n    , count = Math.min((end === undefined ? len : toIndex(end, len)) - from, len - to)\n    , inc   = 1;\n  if(from < to && to < from + count){\n    inc  = -1;\n    from += count - 1;\n    to   += count - 1;\n  }\n  while(count-- > 0){\n    if(from in O)O[to] = O[from];\n    else delete O[to];\n    to   += inc;\n    from += inc;\n  } return O;\n};","deps":{"./_to-index":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-index.js","./_to-length":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-length.js","./_to-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-object.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-fill.js","source":"'use strict';\nvar toObject = require('./_to-object')\n  , toIndex  = require('./_to-index')\n  , toLength = require('./_to-length');\nmodule.exports = function fill(value /*, start = 0, end = @length */){\n  var O      = toObject(this)\n    , length = toLength(O.length)\n    , aLen   = arguments.length\n    , index  = toIndex(aLen > 1 ? arguments[1] : undefined, length)\n    , end    = aLen > 2 ? arguments[2] : undefined\n    , endPos = end === undefined ? length : toIndex(end, length);\n  while(endPos > index)O[index++] = value;\n  return O;\n};","deps":{"./_to-index":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-index.js","./_to-length":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-length.js","./_to-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-object.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-from-iterable.js","source":"var forOf = require('./_for-of');\n\nmodule.exports = function(iter, ITERATOR){\n  var result = [];\n  forOf(iter, false, result.push, result, ITERATOR);\n  return result;\n};","deps":{"./_for-of":"node_modules/babel-polyfill/node_modules/core-js/modules/_for-of.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-includes.js","source":"var toIObject = require('./_to-iobject')\n  , toLength  = require('./_to-length')\n  , toIndex   = require('./_to-index');\nmodule.exports = function(IS_INCLUDES){\n  return function($this, el, fromIndex){\n    var O      = toIObject($this)\n      , length = toLength(O.length)\n      , index  = toIndex(fromIndex, length)\n      , value;\n    // Array#includes uses SameValueZero equality algorithm\n    if(IS_INCLUDES && el != el)while(length > index){\n      value = O[index++];\n      if(value != value)return true;\n    // Array#toIndex ignores holes, Array#includes - not\n    } else for(;length > index; index++)if(IS_INCLUDES || index in O){\n      if(O[index] === el)return IS_INCLUDES || index || 0;\n    } return !IS_INCLUDES && -1;\n  };\n};","deps":{"./_to-index":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-index.js","./_to-iobject":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-iobject.js","./_to-length":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-length.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-methods.js","source":"var ctx      = require('./_ctx')\n  , IObject  = require('./_iobject')\n  , toObject = require('./_to-object')\n  , toLength = require('./_to-length')\n  , asc      = require('./_array-species-create');\nmodule.exports = function(TYPE, $create){\n  var IS_MAP        = TYPE == 1\n    , IS_FILTER     = TYPE == 2\n    , IS_SOME       = TYPE == 3\n    , IS_EVERY      = TYPE == 4\n    , IS_FIND_INDEX = TYPE == 6\n    , NO_HOLES      = TYPE == 5 || IS_FIND_INDEX\n    , create        = $create || asc;\n  return function($this, callbackfn, that){\n    var O      = toObject($this)\n      , self   = IObject(O)\n      , f      = ctx(callbackfn, that, 3)\n      , length = toLength(self.length)\n      , index  = 0\n      , result = IS_MAP ? create($this, length) : IS_FILTER ? create($this, 0) : undefined\n      , val, res;\n    for(;length > index; index++)if(NO_HOLES || index in self){\n      val = self[index];\n      res = f(val, index, O);\n      if(TYPE){\n        if(IS_MAP)result[index] = res;            // map\n        else if(res)switch(TYPE){\n          case 3: return true;                    // some\n          case 5: return val;                     // find\n          case 6: return index;                   // findIndex\n          case 2: result.push(val);               // filter\n        } else if(IS_EVERY)return false;          // every\n      }\n    }\n    return IS_FIND_INDEX ? -1 : IS_SOME || IS_EVERY ? IS_EVERY : result;\n  };\n};","deps":{"./_array-species-create":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-species-create.js","./_ctx":"node_modules/babel-polyfill/node_modules/core-js/modules/_ctx.js","./_iobject":"node_modules/babel-polyfill/node_modules/core-js/modules/_iobject.js","./_to-length":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-length.js","./_to-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-object.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-reduce.js","source":"var aFunction = require('./_a-function')\n  , toObject  = require('./_to-object')\n  , IObject   = require('./_iobject')\n  , toLength  = require('./_to-length');\n\nmodule.exports = function(that, callbackfn, aLen, memo, isRight){\n  aFunction(callbackfn);\n  var O      = toObject(that)\n    , self   = IObject(O)\n    , length = toLength(O.length)\n    , index  = isRight ? length - 1 : 0\n    , i      = isRight ? -1 : 1;\n  if(aLen < 2)for(;;){\n    if(index in self){\n      memo = self[index];\n      index += i;\n      break;\n    }\n    index += i;\n    if(isRight ? index < 0 : length <= index){\n      throw TypeError('Reduce of empty array with no initial value');\n    }\n  }\n  for(;isRight ? index >= 0 : length > index; index += i)if(index in self){\n    memo = callbackfn(memo, self[index], index, O);\n  }\n  return memo;\n};","deps":{"./_a-function":"node_modules/babel-polyfill/node_modules/core-js/modules/_a-function.js","./_iobject":"node_modules/babel-polyfill/node_modules/core-js/modules/_iobject.js","./_to-length":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-length.js","./_to-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-object.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-species-constructor.js","source":"var isObject = require('./_is-object')\n  , isArray  = require('./_is-array')\n  , SPECIES  = require('./_wks')('species');\n\nmodule.exports = function(original){\n  var C;\n  if(isArray(original)){\n    C = original.constructor;\n    // cross-realm fallback\n    if(typeof C == 'function' && (C === Array || isArray(C.prototype)))C = undefined;\n    if(isObject(C)){\n      C = C[SPECIES];\n      if(C === null)C = undefined;\n    }\n  } return C === undefined ? Array : C;\n};","deps":{"./_is-array":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-array.js","./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js","./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-species-create.js","source":"var speciesConstructor = require('./_array-species-constructor');\n\nmodule.exports = function(original, length){\n  return new (speciesConstructor(original))(length);\n};","deps":{"./_array-species-constructor":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-species-constructor.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_bind.js","source":"'use strict';\nvar aFunction  = require('./_a-function')\n  , isObject   = require('./_is-object')\n  , invoke     = require('./_invoke')\n  , arraySlice = [].slice\n  , factories  = {};\n\nvar construct = function(F, len, args){\n  if(!(len in factories)){\n    for(var n = [], i = 0; i < len; i++)n[i] = 'a[' + i + ']';\n    factories[len] = Function('F,a', 'return new F(' + n.join(',') + ')');\n  } return factories[len](F, args);\n};\n\nmodule.exports = Function.bind || function bind(that /*, args... */){\n  var fn       = aFunction(this)\n    , partArgs = arraySlice.call(arguments, 1);\n  var bound = function(/* args... */){\n    var args = partArgs.concat(arraySlice.call(arguments));\n    return this instanceof bound ? construct(fn, args.length, args) : invoke(fn, args, that);\n  };\n  if(isObject(fn.prototype))bound.prototype = fn.prototype;\n  return bound;\n};","deps":{"./_a-function":"node_modules/babel-polyfill/node_modules/core-js/modules/_a-function.js","./_invoke":"node_modules/babel-polyfill/node_modules/core-js/modules/_invoke.js","./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_classof.js","source":"var cof = require('./_cof')\n  , TAG = require('./_wks')('toStringTag')\n  // ES3 wrong here\n  , ARG = cof(function(){ return arguments; }()) == 'Arguments';\n\n// fallback for IE11 Script Access Denied error\nvar tryGet = function(it, key){\n  try {\n    return it[key];\n  } catch(e){ /* empty */ }\n};\n\nmodule.exports = function(it){\n  var O, T, B;\n  return it === undefined ? 'Undefined' : it === null ? 'Null'\n    // @@toStringTag case\n    : typeof (T = tryGet(O = Object(it), TAG)) == 'string' ? T\n    // builtinTag case\n    : ARG ? cof(O)\n    // ES3 arguments fallback\n    : (B = cof(O)) == 'Object' && typeof O.callee == 'function' ? 'Arguments' : B;\n};","deps":{"./_cof":"node_modules/babel-polyfill/node_modules/core-js/modules/_cof.js","./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_cof.js","source":"var toString = {}.toString;\n\nmodule.exports = function(it){\n  return toString.call(it).slice(8, -1);\n};","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_collection-strong.js","source":"'use strict';\nvar dP          = require('./_object-dp').f\n  , create      = require('./_object-create')\n  , redefineAll = require('./_redefine-all')\n  , ctx         = require('./_ctx')\n  , anInstance  = require('./_an-instance')\n  , defined     = require('./_defined')\n  , forOf       = require('./_for-of')\n  , $iterDefine = require('./_iter-define')\n  , step        = require('./_iter-step')\n  , setSpecies  = require('./_set-species')\n  , DESCRIPTORS = require('./_descriptors')\n  , fastKey     = require('./_meta').fastKey\n  , SIZE        = DESCRIPTORS ? '_s' : 'size';\n\nvar getEntry = function(that, key){\n  // fast case\n  var index = fastKey(key), entry;\n  if(index !== 'F')return that._i[index];\n  // frozen object case\n  for(entry = that._f; entry; entry = entry.n){\n    if(entry.k == key)return entry;\n  }\n};\n\nmodule.exports = {\n  getConstructor: function(wrapper, NAME, IS_MAP, ADDER){\n    var C = wrapper(function(that, iterable){\n      anInstance(that, C, NAME, '_i');\n      that._i = create(null); // index\n      that._f = undefined;    // first entry\n      that._l = undefined;    // last entry\n      that[SIZE] = 0;         // size\n      if(iterable != undefined)forOf(iterable, IS_MAP, that[ADDER], that);\n    });\n    redefineAll(C.prototype, {\n      // 23.1.3.1 Map.prototype.clear()\n      // 23.2.3.2 Set.prototype.clear()\n      clear: function clear(){\n        for(var that = this, data = that._i, entry = that._f; entry; entry = entry.n){\n          entry.r = true;\n          if(entry.p)entry.p = entry.p.n = undefined;\n          delete data[entry.i];\n        }\n        that._f = that._l = undefined;\n        that[SIZE] = 0;\n      },\n      // 23.1.3.3 Map.prototype.delete(key)\n      // 23.2.3.4 Set.prototype.delete(value)\n      'delete': function(key){\n        var that  = this\n          , entry = getEntry(that, key);\n        if(entry){\n          var next = entry.n\n            , prev = entry.p;\n          delete that._i[entry.i];\n          entry.r = true;\n          if(prev)prev.n = next;\n          if(next)next.p = prev;\n          if(that._f == entry)that._f = next;\n          if(that._l == entry)that._l = prev;\n          that[SIZE]--;\n        } return !!entry;\n      },\n      // 23.2.3.6 Set.prototype.forEach(callbackfn, thisArg = undefined)\n      // 23.1.3.5 Map.prototype.forEach(callbackfn, thisArg = undefined)\n      forEach: function forEach(callbackfn /*, that = undefined */){\n        anInstance(this, C, 'forEach');\n        var f = ctx(callbackfn, arguments.length > 1 ? arguments[1] : undefined, 3)\n          , entry;\n        while(entry = entry ? entry.n : this._f){\n          f(entry.v, entry.k, this);\n          // revert to the last existing entry\n          while(entry && entry.r)entry = entry.p;\n        }\n      },\n      // 23.1.3.7 Map.prototype.has(key)\n      // 23.2.3.7 Set.prototype.has(value)\n      has: function has(key){\n        return !!getEntry(this, key);\n      }\n    });\n    if(DESCRIPTORS)dP(C.prototype, 'size', {\n      get: function(){\n        return defined(this[SIZE]);\n      }\n    });\n    return C;\n  },\n  def: function(that, key, value){\n    var entry = getEntry(that, key)\n      , prev, index;\n    // change existing entry\n    if(entry){\n      entry.v = value;\n    // create new entry\n    } else {\n      that._l = entry = {\n        i: index = fastKey(key, true), // <- index\n        k: key,                        // <- key\n        v: value,                      // <- value\n        p: prev = that._l,             // <- previous entry\n        n: undefined,                  // <- next entry\n        r: false                       // <- removed\n      };\n      if(!that._f)that._f = entry;\n      if(prev)prev.n = entry;\n      that[SIZE]++;\n      // add to index\n      if(index !== 'F')that._i[index] = entry;\n    } return that;\n  },\n  getEntry: getEntry,\n  setStrong: function(C, NAME, IS_MAP){\n    // add .keys, .values, .entries, [@@iterator]\n    // 23.1.3.4, 23.1.3.8, 23.1.3.11, 23.1.3.12, 23.2.3.5, 23.2.3.8, 23.2.3.10, 23.2.3.11\n    $iterDefine(C, NAME, function(iterated, kind){\n      this._t = iterated;  // target\n      this._k = kind;      // kind\n      this._l = undefined; // previous\n    }, function(){\n      var that  = this\n        , kind  = that._k\n        , entry = that._l;\n      // revert to the last existing entry\n      while(entry && entry.r)entry = entry.p;\n      // get next entry\n      if(!that._t || !(that._l = entry = entry ? entry.n : that._t._f)){\n        // or finish the iteration\n        that._t = undefined;\n        return step(1);\n      }\n      // return step by kind\n      if(kind == 'keys'  )return step(0, entry.k);\n      if(kind == 'values')return step(0, entry.v);\n      return step(0, [entry.k, entry.v]);\n    }, IS_MAP ? 'entries' : 'values' , !IS_MAP, true);\n\n    // add [@@species], 23.1.2.2, 23.2.2.2\n    setSpecies(NAME);\n  }\n};","deps":{"./_an-instance":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-instance.js","./_ctx":"node_modules/babel-polyfill/node_modules/core-js/modules/_ctx.js","./_defined":"node_modules/babel-polyfill/node_modules/core-js/modules/_defined.js","./_descriptors":"node_modules/babel-polyfill/node_modules/core-js/modules/_descriptors.js","./_for-of":"node_modules/babel-polyfill/node_modules/core-js/modules/_for-of.js","./_iter-define":"node_modules/babel-polyfill/node_modules/core-js/modules/_iter-define.js","./_iter-step":"node_modules/babel-polyfill/node_modules/core-js/modules/_iter-step.js","./_meta":"node_modules/babel-polyfill/node_modules/core-js/modules/_meta.js","./_object-create":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-create.js","./_object-dp":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dp.js","./_redefine-all":"node_modules/babel-polyfill/node_modules/core-js/modules/_redefine-all.js","./_set-species":"node_modules/babel-polyfill/node_modules/core-js/modules/_set-species.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_collection-to-json.js","source":"var classof = require('./_classof')\n  , from    = require('./_array-from-iterable');\nmodule.exports = function(NAME){\n  return function toJSON(){\n    if(classof(this) != NAME)throw TypeError(NAME + \"#toJSON isn't generic\");\n    return from(this);\n  };\n};","deps":{"./_array-from-iterable":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-from-iterable.js","./_classof":"node_modules/babel-polyfill/node_modules/core-js/modules/_classof.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_collection-weak.js","source":"'use strict';\nvar redefineAll       = require('./_redefine-all')\n  , getWeak           = require('./_meta').getWeak\n  , anObject          = require('./_an-object')\n  , isObject          = require('./_is-object')\n  , anInstance        = require('./_an-instance')\n  , forOf             = require('./_for-of')\n  , createArrayMethod = require('./_array-methods')\n  , $has              = require('./_has')\n  , arrayFind         = createArrayMethod(5)\n  , arrayFindIndex    = createArrayMethod(6)\n  , id                = 0;\n\n// fallback for uncaught frozen keys\nvar uncaughtFrozenStore = function(that){\n  return that._l || (that._l = new UncaughtFrozenStore);\n};\nvar UncaughtFrozenStore = function(){\n  this.a = [];\n};\nvar findUncaughtFrozen = function(store, key){\n  return arrayFind(store.a, function(it){\n    return it[0] === key;\n  });\n};\nUncaughtFrozenStore.prototype = {\n  get: function(key){\n    var entry = findUncaughtFrozen(this, key);\n    if(entry)return entry[1];\n  },\n  has: function(key){\n    return !!findUncaughtFrozen(this, key);\n  },\n  set: function(key, value){\n    var entry = findUncaughtFrozen(this, key);\n    if(entry)entry[1] = value;\n    else this.a.push([key, value]);\n  },\n  'delete': function(key){\n    var index = arrayFindIndex(this.a, function(it){\n      return it[0] === key;\n    });\n    if(~index)this.a.splice(index, 1);\n    return !!~index;\n  }\n};\n\nmodule.exports = {\n  getConstructor: function(wrapper, NAME, IS_MAP, ADDER){\n    var C = wrapper(function(that, iterable){\n      anInstance(that, C, NAME, '_i');\n      that._i = id++;      // collection id\n      that._l = undefined; // leak store for uncaught frozen objects\n      if(iterable != undefined)forOf(iterable, IS_MAP, that[ADDER], that);\n    });\n    redefineAll(C.prototype, {\n      // 23.3.3.2 WeakMap.prototype.delete(key)\n      // 23.4.3.3 WeakSet.prototype.delete(value)\n      'delete': function(key){\n        if(!isObject(key))return false;\n        var data = getWeak(key);\n        if(data === true)return uncaughtFrozenStore(this)['delete'](key);\n        return data && $has(data, this._i) && delete data[this._i];\n      },\n      // 23.3.3.4 WeakMap.prototype.has(key)\n      // 23.4.3.4 WeakSet.prototype.has(value)\n      has: function has(key){\n        if(!isObject(key))return false;\n        var data = getWeak(key);\n        if(data === true)return uncaughtFrozenStore(this).has(key);\n        return data && $has(data, this._i);\n      }\n    });\n    return C;\n  },\n  def: function(that, key, value){\n    var data = getWeak(anObject(key), true);\n    if(data === true)uncaughtFrozenStore(that).set(key, value);\n    else data[that._i] = value;\n    return that;\n  },\n  ufstore: uncaughtFrozenStore\n};","deps":{"./_an-instance":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-instance.js","./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_array-methods":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-methods.js","./_for-of":"node_modules/babel-polyfill/node_modules/core-js/modules/_for-of.js","./_has":"node_modules/babel-polyfill/node_modules/core-js/modules/_has.js","./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js","./_meta":"node_modules/babel-polyfill/node_modules/core-js/modules/_meta.js","./_redefine-all":"node_modules/babel-polyfill/node_modules/core-js/modules/_redefine-all.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_collection.js","source":"'use strict';\nvar global            = require('./_global')\n  , $export           = require('./_export')\n  , redefine          = require('./_redefine')\n  , redefineAll       = require('./_redefine-all')\n  , meta              = require('./_meta')\n  , forOf             = require('./_for-of')\n  , anInstance        = require('./_an-instance')\n  , isObject          = require('./_is-object')\n  , fails             = require('./_fails')\n  , $iterDetect       = require('./_iter-detect')\n  , setToStringTag    = require('./_set-to-string-tag')\n  , inheritIfRequired = require('./_inherit-if-required');\n\nmodule.exports = function(NAME, wrapper, methods, common, IS_MAP, IS_WEAK){\n  var Base  = global[NAME]\n    , C     = Base\n    , ADDER = IS_MAP ? 'set' : 'add'\n    , proto = C && C.prototype\n    , O     = {};\n  var fixMethod = function(KEY){\n    var fn = proto[KEY];\n    redefine(proto, KEY,\n      KEY == 'delete' ? function(a){\n        return IS_WEAK && !isObject(a) ? false : fn.call(this, a === 0 ? 0 : a);\n      } : KEY == 'has' ? function has(a){\n        return IS_WEAK && !isObject(a) ? false : fn.call(this, a === 0 ? 0 : a);\n      } : KEY == 'get' ? function get(a){\n        return IS_WEAK && !isObject(a) ? undefined : fn.call(this, a === 0 ? 0 : a);\n      } : KEY == 'add' ? function add(a){ fn.call(this, a === 0 ? 0 : a); return this; }\n        : function set(a, b){ fn.call(this, a === 0 ? 0 : a, b); return this; }\n    );\n  };\n  if(typeof C != 'function' || !(IS_WEAK || proto.forEach && !fails(function(){\n    new C().entries().next();\n  }))){\n    // create collection constructor\n    C = common.getConstructor(wrapper, NAME, IS_MAP, ADDER);\n    redefineAll(C.prototype, methods);\n    meta.NEED = true;\n  } else {\n    var instance             = new C\n      // early implementations not supports chaining\n      , HASNT_CHAINING       = instance[ADDER](IS_WEAK ? {} : -0, 1) != instance\n      // V8 ~  Chromium 40- weak-collections throws on primitives, but should return false\n      , THROWS_ON_PRIMITIVES = fails(function(){ instance.has(1); })\n      // most early implementations doesn't supports iterables, most modern - not close it correctly\n      , ACCEPT_ITERABLES     = $iterDetect(function(iter){ new C(iter); }) // eslint-disable-line no-new\n      // for early implementations -0 and +0 not the same\n      , BUGGY_ZERO = !IS_WEAK && fails(function(){\n        // V8 ~ Chromium 42- fails only with 5+ elements\n        var $instance = new C()\n          , index     = 5;\n        while(index--)$instance[ADDER](index, index);\n        return !$instance.has(-0);\n      });\n    if(!ACCEPT_ITERABLES){ \n      C = wrapper(function(target, iterable){\n        anInstance(target, C, NAME);\n        var that = inheritIfRequired(new Base, target, C);\n        if(iterable != undefined)forOf(iterable, IS_MAP, that[ADDER], that);\n        return that;\n      });\n      C.prototype = proto;\n      proto.constructor = C;\n    }\n    if(THROWS_ON_PRIMITIVES || BUGGY_ZERO){\n      fixMethod('delete');\n      fixMethod('has');\n      IS_MAP && fixMethod('get');\n    }\n    if(BUGGY_ZERO || HASNT_CHAINING)fixMethod(ADDER);\n    // weak collections should not contains .clear method\n    if(IS_WEAK && proto.clear)delete proto.clear;\n  }\n\n  setToStringTag(C, NAME);\n\n  O[NAME] = C;\n  $export($export.G + $export.W + $export.F * (C != Base), O);\n\n  if(!IS_WEAK)common.setStrong(C, NAME, IS_MAP);\n\n  return C;\n};","deps":{"./_an-instance":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-instance.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js","./_for-of":"node_modules/babel-polyfill/node_modules/core-js/modules/_for-of.js","./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_inherit-if-required":"node_modules/babel-polyfill/node_modules/core-js/modules/_inherit-if-required.js","./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js","./_iter-detect":"node_modules/babel-polyfill/node_modules/core-js/modules/_iter-detect.js","./_meta":"node_modules/babel-polyfill/node_modules/core-js/modules/_meta.js","./_redefine":"node_modules/babel-polyfill/node_modules/core-js/modules/_redefine.js","./_redefine-all":"node_modules/babel-polyfill/node_modules/core-js/modules/_redefine-all.js","./_set-to-string-tag":"node_modules/babel-polyfill/node_modules/core-js/modules/_set-to-string-tag.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_core.js","source":"var core = module.exports = {version: '2.4.0'};\nif(typeof __e == 'number')__e = core;","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_create-property.js","source":"'use strict';\nvar $defineProperty = require('./_object-dp')\n  , createDesc      = require('./_property-desc');\n\nmodule.exports = function(object, index, value){\n  if(index in object)$defineProperty.f(object, index, createDesc(0, value));\n  else object[index] = value;\n};","deps":{"./_object-dp":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dp.js","./_property-desc":"node_modules/babel-polyfill/node_modules/core-js/modules/_property-desc.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_ctx.js","source":"var aFunction = require('./_a-function');\nmodule.exports = function(fn, that, length){\n  aFunction(fn);\n  if(that === undefined)return fn;\n  switch(length){\n    case 1: return function(a){\n      return fn.call(that, a);\n    };\n    case 2: return function(a, b){\n      return fn.call(that, a, b);\n    };\n    case 3: return function(a, b, c){\n      return fn.call(that, a, b, c);\n    };\n  }\n  return function(/* ...args */){\n    return fn.apply(that, arguments);\n  };\n};","deps":{"./_a-function":"node_modules/babel-polyfill/node_modules/core-js/modules/_a-function.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_date-to-primitive.js","source":"'use strict';\nvar anObject    = require('./_an-object')\n  , toPrimitive = require('./_to-primitive')\n  , NUMBER      = 'number';\n\nmodule.exports = function(hint){\n  if(hint !== 'string' && hint !== NUMBER && hint !== 'default')throw TypeError('Incorrect hint');\n  return toPrimitive(anObject(this), hint != NUMBER);\n};","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_to-primitive":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-primitive.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_defined.js","source":"module.exports = function(it){\n  if(it == undefined)throw TypeError(\"Can't call method on  \" + it);\n  return it;\n};","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_descriptors.js","source":"module.exports = !require('./_fails')(function(){\n  return Object.defineProperty({}, 'a', {get: function(){ return 7; }}).a != 7;\n});","deps":{"./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_dom-create.js","source":"var isObject = require('./_is-object')\n  , document = require('./_global').document\n  // in old IE typeof document.createElement is 'object'\n  , is = isObject(document) && isObject(document.createElement);\nmodule.exports = function(it){\n  return is ? document.createElement(it) : {};\n};","deps":{"./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_enum-bug-keys.js","source":"module.exports = (\n  'constructor,hasOwnProperty,isPrototypeOf,propertyIsEnumerable,toLocaleString,toString,valueOf'\n).split(',');","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_enum-keys.js","source":"var getKeys = require('./_object-keys')\n  , gOPS    = require('./_object-gops')\n  , pIE     = require('./_object-pie');\nmodule.exports = function(it){\n  var result     = getKeys(it)\n    , getSymbols = gOPS.f;\n  if(getSymbols){\n    var symbols = getSymbols(it)\n      , isEnum  = pIE.f\n      , i       = 0\n      , key;\n    while(symbols.length > i)if(isEnum.call(it, key = symbols[i++]))result.push(key);\n  } return result;\n};","deps":{"./_object-gops":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gops.js","./_object-keys":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-keys.js","./_object-pie":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-pie.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","source":"var global    = require('./_global')\n  , core      = require('./_core')\n  , hide      = require('./_hide')\n  , redefine  = require('./_redefine')\n  , ctx       = require('./_ctx')\n  , PROTOTYPE = 'prototype';\n\nvar $export = function(type, name, source){\n  var IS_FORCED = type & $export.F\n    , IS_GLOBAL = type & $export.G\n    , IS_STATIC = type & $export.S\n    , IS_PROTO  = type & $export.P\n    , IS_BIND   = type & $export.B\n    , target    = IS_GLOBAL ? global : IS_STATIC ? global[name] || (global[name] = {}) : (global[name] || {})[PROTOTYPE]\n    , exports   = IS_GLOBAL ? core : core[name] || (core[name] = {})\n    , expProto  = exports[PROTOTYPE] || (exports[PROTOTYPE] = {})\n    , key, own, out, exp;\n  if(IS_GLOBAL)source = name;\n  for(key in source){\n    // contains in native\n    own = !IS_FORCED && target && target[key] !== undefined;\n    // export native or passed\n    out = (own ? target : source)[key];\n    // bind timers to global for call from export context\n    exp = IS_BIND && own ? ctx(out, global) : IS_PROTO && typeof out == 'function' ? ctx(Function.call, out) : out;\n    // extend global\n    if(target)redefine(target, key, out, type & $export.U);\n    // export\n    if(exports[key] != out)hide(exports, key, exp);\n    if(IS_PROTO && expProto[key] != out)expProto[key] = out;\n  }\n};\nglobal.core = core;\n// type bitmap\n$export.F = 1;   // forced\n$export.G = 2;   // global\n$export.S = 4;   // static\n$export.P = 8;   // proto\n$export.B = 16;  // bind\n$export.W = 32;  // wrap\n$export.U = 64;  // safe\n$export.R = 128; // real proto method for `library` \nmodule.exports = $export;","deps":{"./_core":"node_modules/babel-polyfill/node_modules/core-js/modules/_core.js","./_ctx":"node_modules/babel-polyfill/node_modules/core-js/modules/_ctx.js","./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_hide":"node_modules/babel-polyfill/node_modules/core-js/modules/_hide.js","./_redefine":"node_modules/babel-polyfill/node_modules/core-js/modules/_redefine.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails-is-regexp.js","source":"var MATCH = require('./_wks')('match');\nmodule.exports = function(KEY){\n  var re = /./;\n  try {\n    '/./'[KEY](re);\n  } catch(e){\n    try {\n      re[MATCH] = false;\n      return !'/./'[KEY](re);\n    } catch(f){ /* empty */ }\n  } return true;\n};","deps":{"./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js","source":"module.exports = function(exec){\n  try {\n    return !!exec();\n  } catch(e){\n    return true;\n  }\n};","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_fix-re-wks.js","source":"'use strict';\nvar hide     = require('./_hide')\n  , redefine = require('./_redefine')\n  , fails    = require('./_fails')\n  , defined  = require('./_defined')\n  , wks      = require('./_wks');\n\nmodule.exports = function(KEY, length, exec){\n  var SYMBOL   = wks(KEY)\n    , fns      = exec(defined, SYMBOL, ''[KEY])\n    , strfn    = fns[0]\n    , rxfn     = fns[1];\n  if(fails(function(){\n    var O = {};\n    O[SYMBOL] = function(){ return 7; };\n    return ''[KEY](O) != 7;\n  })){\n    redefine(String.prototype, KEY, strfn);\n    hide(RegExp.prototype, SYMBOL, length == 2\n      // 21.2.5.8 RegExp.prototype[@@replace](string, replaceValue)\n      // 21.2.5.11 RegExp.prototype[@@split](string, limit)\n      ? function(string, arg){ return rxfn.call(string, this, arg); }\n      // 21.2.5.6 RegExp.prototype[@@match](string)\n      // 21.2.5.9 RegExp.prototype[@@search](string)\n      : function(string){ return rxfn.call(string, this); }\n    );\n  }\n};","deps":{"./_defined":"node_modules/babel-polyfill/node_modules/core-js/modules/_defined.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js","./_hide":"node_modules/babel-polyfill/node_modules/core-js/modules/_hide.js","./_redefine":"node_modules/babel-polyfill/node_modules/core-js/modules/_redefine.js","./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_flags.js","source":"'use strict';\n// 21.2.5.3 get RegExp.prototype.flags\nvar anObject = require('./_an-object');\nmodule.exports = function(){\n  var that   = anObject(this)\n    , result = '';\n  if(that.global)     result += 'g';\n  if(that.ignoreCase) result += 'i';\n  if(that.multiline)  result += 'm';\n  if(that.unicode)    result += 'u';\n  if(that.sticky)     result += 'y';\n  return result;\n};","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_for-of.js","source":"var ctx         = require('./_ctx')\n  , call        = require('./_iter-call')\n  , isArrayIter = require('./_is-array-iter')\n  , anObject    = require('./_an-object')\n  , toLength    = require('./_to-length')\n  , getIterFn   = require('./core.get-iterator-method')\n  , BREAK       = {}\n  , RETURN      = {};\nvar exports = module.exports = function(iterable, entries, fn, that, ITERATOR){\n  var iterFn = ITERATOR ? function(){ return iterable; } : getIterFn(iterable)\n    , f      = ctx(fn, that, entries ? 2 : 1)\n    , index  = 0\n    , length, step, iterator, result;\n  if(typeof iterFn != 'function')throw TypeError(iterable + ' is not iterable!');\n  // fast case for arrays with default iterator\n  if(isArrayIter(iterFn))for(length = toLength(iterable.length); length > index; index++){\n    result = entries ? f(anObject(step = iterable[index])[0], step[1]) : f(iterable[index]);\n    if(result === BREAK || result === RETURN)return result;\n  } else for(iterator = iterFn.call(iterable); !(step = iterator.next()).done; ){\n    result = call(iterator, f, step.value, entries);\n    if(result === BREAK || result === RETURN)return result;\n  }\n};\nexports.BREAK  = BREAK;\nexports.RETURN = RETURN;","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_ctx":"node_modules/babel-polyfill/node_modules/core-js/modules/_ctx.js","./_is-array-iter":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-array-iter.js","./_iter-call":"node_modules/babel-polyfill/node_modules/core-js/modules/_iter-call.js","./_to-length":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-length.js","./core.get-iterator-method":"node_modules/babel-polyfill/node_modules/core-js/modules/core.get-iterator-method.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","source":"var global = module.exports = typeof window != 'undefined' && window.Math == Math\n  ? window : typeof self != 'undefined' && self.Math == Math ? self : Function('return this')();\nif(typeof __g == 'number')__g = global;","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_has.js","source":"var hasOwnProperty = {}.hasOwnProperty;\nmodule.exports = function(it, key){\n  return hasOwnProperty.call(it, key);\n};","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_hide.js","source":"var dP         = require('./_object-dp')\n  , createDesc = require('./_property-desc');\nmodule.exports = require('./_descriptors') ? function(object, key, value){\n  return dP.f(object, key, createDesc(1, value));\n} : function(object, key, value){\n  object[key] = value;\n  return object;\n};","deps":{"./_descriptors":"node_modules/babel-polyfill/node_modules/core-js/modules/_descriptors.js","./_object-dp":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dp.js","./_property-desc":"node_modules/babel-polyfill/node_modules/core-js/modules/_property-desc.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_html.js","source":"module.exports = require('./_global').document && document.documentElement;","deps":{"./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_ie8-dom-define.js","source":"module.exports = !require('./_descriptors') && !require('./_fails')(function(){\n  return Object.defineProperty(require('./_dom-create')('div'), 'a', {get: function(){ return 7; }}).a != 7;\n});","deps":{"./_descriptors":"node_modules/babel-polyfill/node_modules/core-js/modules/_descriptors.js","./_dom-create":"node_modules/babel-polyfill/node_modules/core-js/modules/_dom-create.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_inherit-if-required.js","source":"var isObject       = require('./_is-object')\n  , setPrototypeOf = require('./_set-proto').set;\nmodule.exports = function(that, target, C){\n  var P, S = target.constructor;\n  if(S !== C && typeof S == 'function' && (P = S.prototype) !== C.prototype && isObject(P) && setPrototypeOf){\n    setPrototypeOf(that, P);\n  } return that;\n};","deps":{"./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js","./_set-proto":"node_modules/babel-polyfill/node_modules/core-js/modules/_set-proto.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_invoke.js","source":"module.exports = function(fn, args, that){\n  var un = that === undefined;\n  switch(args.length){\n    case 0: return un ? fn()\n                      : fn.call(that);\n    case 1: return un ? fn(args[0])\n                      : fn.call(that, args[0]);\n    case 2: return un ? fn(args[0], args[1])\n                      : fn.call(that, args[0], args[1]);\n    case 3: return un ? fn(args[0], args[1], args[2])\n                      : fn.call(that, args[0], args[1], args[2]);\n    case 4: return un ? fn(args[0], args[1], args[2], args[3])\n                      : fn.call(that, args[0], args[1], args[2], args[3]);\n  } return              fn.apply(that, args);\n};","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_iobject.js","source":"var cof = require('./_cof');\nmodule.exports = Object('z').propertyIsEnumerable(0) ? Object : function(it){\n  return cof(it) == 'String' ? it.split('') : Object(it);\n};","deps":{"./_cof":"node_modules/babel-polyfill/node_modules/core-js/modules/_cof.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-array-iter.js","source":"var Iterators  = require('./_iterators')\n  , ITERATOR   = require('./_wks')('iterator')\n  , ArrayProto = Array.prototype;\n\nmodule.exports = function(it){\n  return it !== undefined && (Iterators.Array === it || ArrayProto[ITERATOR] === it);\n};","deps":{"./_iterators":"node_modules/babel-polyfill/node_modules/core-js/modules/_iterators.js","./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-array.js","source":"var cof = require('./_cof');\nmodule.exports = Array.isArray || function isArray(arg){\n  return cof(arg) == 'Array';\n};","deps":{"./_cof":"node_modules/babel-polyfill/node_modules/core-js/modules/_cof.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-integer.js","source":"var isObject = require('./_is-object')\n  , floor    = Math.floor;\nmodule.exports = function isInteger(it){\n  return !isObject(it) && isFinite(it) && floor(it) === it;\n};","deps":{"./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js","source":"module.exports = function(it){\n  return typeof it === 'object' ? it !== null : typeof it === 'function';\n};","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-regexp.js","source":"var isObject = require('./_is-object')\n  , cof      = require('./_cof')\n  , MATCH    = require('./_wks')('match');\nmodule.exports = function(it){\n  var isRegExp;\n  return isObject(it) && ((isRegExp = it[MATCH]) !== undefined ? !!isRegExp : cof(it) == 'RegExp');\n};","deps":{"./_cof":"node_modules/babel-polyfill/node_modules/core-js/modules/_cof.js","./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js","./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_iter-call.js","source":"var anObject = require('./_an-object');\nmodule.exports = function(iterator, fn, value, entries){\n  try {\n    return entries ? fn(anObject(value)[0], value[1]) : fn(value);\n  // 7.4.6 IteratorClose(iterator, completion)\n  } catch(e){\n    var ret = iterator['return'];\n    if(ret !== undefined)anObject(ret.call(iterator));\n    throw e;\n  }\n};","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_iter-create.js","source":"'use strict';\nvar create         = require('./_object-create')\n  , descriptor     = require('./_property-desc')\n  , setToStringTag = require('./_set-to-string-tag')\n  , IteratorPrototype = {};\n\n// 25.1.2.1.1 %IteratorPrototype%[@@iterator]()\nrequire('./_hide')(IteratorPrototype, require('./_wks')('iterator'), function(){ return this; });\n\nmodule.exports = function(Constructor, NAME, next){\n  Constructor.prototype = create(IteratorPrototype, {next: descriptor(1, next)});\n  setToStringTag(Constructor, NAME + ' Iterator');\n};","deps":{"./_hide":"node_modules/babel-polyfill/node_modules/core-js/modules/_hide.js","./_object-create":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-create.js","./_property-desc":"node_modules/babel-polyfill/node_modules/core-js/modules/_property-desc.js","./_set-to-string-tag":"node_modules/babel-polyfill/node_modules/core-js/modules/_set-to-string-tag.js","./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_iter-define.js","source":"'use strict';\nvar LIBRARY        = require('./_library')\n  , $export        = require('./_export')\n  , redefine       = require('./_redefine')\n  , hide           = require('./_hide')\n  , has            = require('./_has')\n  , Iterators      = require('./_iterators')\n  , $iterCreate    = require('./_iter-create')\n  , setToStringTag = require('./_set-to-string-tag')\n  , getPrototypeOf = require('./_object-gpo')\n  , ITERATOR       = require('./_wks')('iterator')\n  , BUGGY          = !([].keys && 'next' in [].keys()) // Safari has buggy iterators w/o `next`\n  , FF_ITERATOR    = '@@iterator'\n  , KEYS           = 'keys'\n  , VALUES         = 'values';\n\nvar returnThis = function(){ return this; };\n\nmodule.exports = function(Base, NAME, Constructor, next, DEFAULT, IS_SET, FORCED){\n  $iterCreate(Constructor, NAME, next);\n  var getMethod = function(kind){\n    if(!BUGGY && kind in proto)return proto[kind];\n    switch(kind){\n      case KEYS: return function keys(){ return new Constructor(this, kind); };\n      case VALUES: return function values(){ return new Constructor(this, kind); };\n    } return function entries(){ return new Constructor(this, kind); };\n  };\n  var TAG        = NAME + ' Iterator'\n    , DEF_VALUES = DEFAULT == VALUES\n    , VALUES_BUG = false\n    , proto      = Base.prototype\n    , $native    = proto[ITERATOR] || proto[FF_ITERATOR] || DEFAULT && proto[DEFAULT]\n    , $default   = $native || getMethod(DEFAULT)\n    , $entries   = DEFAULT ? !DEF_VALUES ? $default : getMethod('entries') : undefined\n    , $anyNative = NAME == 'Array' ? proto.entries || $native : $native\n    , methods, key, IteratorPrototype;\n  // Fix native\n  if($anyNative){\n    IteratorPrototype = getPrototypeOf($anyNative.call(new Base));\n    if(IteratorPrototype !== Object.prototype){\n      // Set @@toStringTag to native iterators\n      setToStringTag(IteratorPrototype, TAG, true);\n      // fix for some old engines\n      if(!LIBRARY && !has(IteratorPrototype, ITERATOR))hide(IteratorPrototype, ITERATOR, returnThis);\n    }\n  }\n  // fix Array#{values, @@iterator}.name in V8 / FF\n  if(DEF_VALUES && $native && $native.name !== VALUES){\n    VALUES_BUG = true;\n    $default = function values(){ return $native.call(this); };\n  }\n  // Define iterator\n  if((!LIBRARY || FORCED) && (BUGGY || VALUES_BUG || !proto[ITERATOR])){\n    hide(proto, ITERATOR, $default);\n  }\n  // Plug for library\n  Iterators[NAME] = $default;\n  Iterators[TAG]  = returnThis;\n  if(DEFAULT){\n    methods = {\n      values:  DEF_VALUES ? $default : getMethod(VALUES),\n      keys:    IS_SET     ? $default : getMethod(KEYS),\n      entries: $entries\n    };\n    if(FORCED)for(key in methods){\n      if(!(key in proto))redefine(proto, key, methods[key]);\n    } else $export($export.P + $export.F * (BUGGY || VALUES_BUG), NAME, methods);\n  }\n  return methods;\n};","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_has":"node_modules/babel-polyfill/node_modules/core-js/modules/_has.js","./_hide":"node_modules/babel-polyfill/node_modules/core-js/modules/_hide.js","./_iter-create":"node_modules/babel-polyfill/node_modules/core-js/modules/_iter-create.js","./_iterators":"node_modules/babel-polyfill/node_modules/core-js/modules/_iterators.js","./_library":"node_modules/babel-polyfill/node_modules/core-js/modules/_library.js","./_object-gpo":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gpo.js","./_redefine":"node_modules/babel-polyfill/node_modules/core-js/modules/_redefine.js","./_set-to-string-tag":"node_modules/babel-polyfill/node_modules/core-js/modules/_set-to-string-tag.js","./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_iter-detect.js","source":"var ITERATOR     = require('./_wks')('iterator')\n  , SAFE_CLOSING = false;\n\ntry {\n  var riter = [7][ITERATOR]();\n  riter['return'] = function(){ SAFE_CLOSING = true; };\n  Array.from(riter, function(){ throw 2; });\n} catch(e){ /* empty */ }\n\nmodule.exports = function(exec, skipClosing){\n  if(!skipClosing && !SAFE_CLOSING)return false;\n  var safe = false;\n  try {\n    var arr  = [7]\n      , iter = arr[ITERATOR]();\n    iter.next = function(){ return {done: safe = true}; };\n    arr[ITERATOR] = function(){ return iter; };\n    exec(arr);\n  } catch(e){ /* empty */ }\n  return safe;\n};","deps":{"./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_iter-step.js","source":"module.exports = function(done, value){\n  return {value: value, done: !!done};\n};","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_iterators.js","source":"module.exports = {};","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_keyof.js","source":"var getKeys   = require('./_object-keys')\n  , toIObject = require('./_to-iobject');\nmodule.exports = function(object, el){\n  var O      = toIObject(object)\n    , keys   = getKeys(O)\n    , length = keys.length\n    , index  = 0\n    , key;\n  while(length > index)if(O[key = keys[index++]] === el)return key;\n};","deps":{"./_object-keys":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-keys.js","./_to-iobject":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-iobject.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_library.js","source":"module.exports = false;","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_math-expm1.js","source":"var $expm1 = Math.expm1;\nmodule.exports = (!$expm1\n  // Old FF bug\n  || $expm1(10) > 22025.465794806719 || $expm1(10) < 22025.4657948067165168\n  // Tor Browser bug\n  || $expm1(-2e-17) != -2e-17\n) ? function expm1(x){\n  return (x = +x) == 0 ? x : x > -1e-6 && x < 1e-6 ? x + x * x / 2 : Math.exp(x) - 1;\n} : $expm1;","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_math-log1p.js","source":"module.exports = Math.log1p || function log1p(x){\n  return (x = +x) > -1e-8 && x < 1e-8 ? x - x * x / 2 : Math.log(1 + x);\n};","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_math-sign.js","source":"module.exports = Math.sign || function sign(x){\n  return (x = +x) == 0 || x != x ? x : x < 0 ? -1 : 1;\n};","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_meta.js","source":"var META     = require('./_uid')('meta')\n  , isObject = require('./_is-object')\n  , has      = require('./_has')\n  , setDesc  = require('./_object-dp').f\n  , id       = 0;\nvar isExtensible = Object.isExtensible || function(){\n  return true;\n};\nvar FREEZE = !require('./_fails')(function(){\n  return isExtensible(Object.preventExtensions({}));\n});\nvar setMeta = function(it){\n  setDesc(it, META, {value: {\n    i: 'O' + ++id, // object ID\n    w: {}          // weak collections IDs\n  }});\n};\nvar fastKey = function(it, create){\n  // return primitive with prefix\n  if(!isObject(it))return typeof it == 'symbol' ? it : (typeof it == 'string' ? 'S' : 'P') + it;\n  if(!has(it, META)){\n    // can't set metadata to uncaught frozen object\n    if(!isExtensible(it))return 'F';\n    // not necessary to add metadata\n    if(!create)return 'E';\n    // add missing metadata\n    setMeta(it);\n  // return object ID\n  } return it[META].i;\n};\nvar getWeak = function(it, create){\n  if(!has(it, META)){\n    // can't set metadata to uncaught frozen object\n    if(!isExtensible(it))return true;\n    // not necessary to add metadata\n    if(!create)return false;\n    // add missing metadata\n    setMeta(it);\n  // return hash weak collections IDs\n  } return it[META].w;\n};\n// add metadata on freeze-family methods calling\nvar onFreeze = function(it){\n  if(FREEZE && meta.NEED && isExtensible(it) && !has(it, META))setMeta(it);\n  return it;\n};\nvar meta = module.exports = {\n  KEY:      META,\n  NEED:     false,\n  fastKey:  fastKey,\n  getWeak:  getWeak,\n  onFreeze: onFreeze\n};","deps":{"./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js","./_has":"node_modules/babel-polyfill/node_modules/core-js/modules/_has.js","./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js","./_object-dp":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dp.js","./_uid":"node_modules/babel-polyfill/node_modules/core-js/modules/_uid.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_metadata.js","source":"var Map     = require('./es6.map')\n  , $export = require('./_export')\n  , shared  = require('./_shared')('metadata')\n  , store   = shared.store || (shared.store = new (require('./es6.weak-map')));\n\nvar getOrCreateMetadataMap = function(target, targetKey, create){\n  var targetMetadata = store.get(target);\n  if(!targetMetadata){\n    if(!create)return undefined;\n    store.set(target, targetMetadata = new Map);\n  }\n  var keyMetadata = targetMetadata.get(targetKey);\n  if(!keyMetadata){\n    if(!create)return undefined;\n    targetMetadata.set(targetKey, keyMetadata = new Map);\n  } return keyMetadata;\n};\nvar ordinaryHasOwnMetadata = function(MetadataKey, O, P){\n  var metadataMap = getOrCreateMetadataMap(O, P, false);\n  return metadataMap === undefined ? false : metadataMap.has(MetadataKey);\n};\nvar ordinaryGetOwnMetadata = function(MetadataKey, O, P){\n  var metadataMap = getOrCreateMetadataMap(O, P, false);\n  return metadataMap === undefined ? undefined : metadataMap.get(MetadataKey);\n};\nvar ordinaryDefineOwnMetadata = function(MetadataKey, MetadataValue, O, P){\n  getOrCreateMetadataMap(O, P, true).set(MetadataKey, MetadataValue);\n};\nvar ordinaryOwnMetadataKeys = function(target, targetKey){\n  var metadataMap = getOrCreateMetadataMap(target, targetKey, false)\n    , keys        = [];\n  if(metadataMap)metadataMap.forEach(function(_, key){ keys.push(key); });\n  return keys;\n};\nvar toMetaKey = function(it){\n  return it === undefined || typeof it == 'symbol' ? it : String(it);\n};\nvar exp = function(O){\n  $export($export.S, 'Reflect', O);\n};\n\nmodule.exports = {\n  store: store,\n  map: getOrCreateMetadataMap,\n  has: ordinaryHasOwnMetadata,\n  get: ordinaryGetOwnMetadata,\n  set: ordinaryDefineOwnMetadata,\n  keys: ordinaryOwnMetadataKeys,\n  key: toMetaKey,\n  exp: exp\n};","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_shared":"node_modules/babel-polyfill/node_modules/core-js/modules/_shared.js","./es6.map":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.map.js","./es6.weak-map":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.weak-map.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_microtask.js","source":"var global    = require('./_global')\n  , macrotask = require('./_task').set\n  , Observer  = global.MutationObserver || global.WebKitMutationObserver\n  , process   = global.process\n  , Promise   = global.Promise\n  , isNode    = require('./_cof')(process) == 'process';\n\nmodule.exports = function(){\n  var head, last, notify;\n\n  var flush = function(){\n    var parent, fn;\n    if(isNode && (parent = process.domain))parent.exit();\n    while(head){\n      fn   = head.fn;\n      head = head.next;\n      try {\n        fn();\n      } catch(e){\n        if(head)notify();\n        else last = undefined;\n        throw e;\n      }\n    } last = undefined;\n    if(parent)parent.enter();\n  };\n\n  // Node.js\n  if(isNode){\n    notify = function(){\n      process.nextTick(flush);\n    };\n  // browsers with MutationObserver\n  } else if(Observer){\n    var toggle = true\n      , node   = document.createTextNode('');\n    new Observer(flush).observe(node, {characterData: true}); // eslint-disable-line no-new\n    notify = function(){\n      node.data = toggle = !toggle;\n    };\n  // environments with maybe non-completely correct, but existent Promise\n  } else if(Promise && Promise.resolve){\n    var promise = Promise.resolve();\n    notify = function(){\n      promise.then(flush);\n    };\n  // for other environments - macrotask based on:\n  // - setImmediate\n  // - MessageChannel\n  // - window.postMessag\n  // - onreadystatechange\n  // - setTimeout\n  } else {\n    notify = function(){\n      // strange IE + webpack dev server bug - use .call(global)\n      macrotask.call(global, flush);\n    };\n  }\n\n  return function(fn){\n    var task = {fn: fn, next: undefined};\n    if(last)last.next = task;\n    if(!head){\n      head = task;\n      notify();\n    } last = task;\n  };\n};","deps":{"./_cof":"node_modules/babel-polyfill/node_modules/core-js/modules/_cof.js","./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_task":"node_modules/babel-polyfill/node_modules/core-js/modules/_task.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-assign.js","source":"'use strict';\n// 19.1.2.1 Object.assign(target, source, ...)\nvar getKeys  = require('./_object-keys')\n  , gOPS     = require('./_object-gops')\n  , pIE      = require('./_object-pie')\n  , toObject = require('./_to-object')\n  , IObject  = require('./_iobject')\n  , $assign  = Object.assign;\n\n// should work with symbols and should have deterministic property order (V8 bug)\nmodule.exports = !$assign || require('./_fails')(function(){\n  var A = {}\n    , B = {}\n    , S = Symbol()\n    , K = 'abcdefghijklmnopqrst';\n  A[S] = 7;\n  K.split('').forEach(function(k){ B[k] = k; });\n  return $assign({}, A)[S] != 7 || Object.keys($assign({}, B)).join('') != K;\n}) ? function assign(target, source){ // eslint-disable-line no-unused-vars\n  var T     = toObject(target)\n    , aLen  = arguments.length\n    , index = 1\n    , getSymbols = gOPS.f\n    , isEnum     = pIE.f;\n  while(aLen > index){\n    var S      = IObject(arguments[index++])\n      , keys   = getSymbols ? getKeys(S).concat(getSymbols(S)) : getKeys(S)\n      , length = keys.length\n      , j      = 0\n      , key;\n    while(length > j)if(isEnum.call(S, key = keys[j++]))T[key] = S[key];\n  } return T;\n} : $assign;","deps":{"./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js","./_iobject":"node_modules/babel-polyfill/node_modules/core-js/modules/_iobject.js","./_object-gops":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gops.js","./_object-keys":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-keys.js","./_object-pie":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-pie.js","./_to-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-object.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-create.js","source":"var anObject    = require('./_an-object')\n  , dPs         = require('./_object-dps')\n  , enumBugKeys = require('./_enum-bug-keys')\n  , IE_PROTO    = require('./_shared-key')('IE_PROTO')\n  , Empty       = function(){ /* empty */ }\n  , PROTOTYPE   = 'prototype';\n\n// Create object with fake `null` prototype: use iframe Object with cleared prototype\nvar createDict = function(){\n  // Thrash, waste and sodomy: IE GC bug\n  var iframe = require('./_dom-create')('iframe')\n    , i      = enumBugKeys.length\n    , lt     = '<'\n    , gt     = '>'\n    , iframeDocument;\n  iframe.style.display = 'none';\n  require('./_html').appendChild(iframe);\n  iframe.src = 'javascript:'; // eslint-disable-line no-script-url\n  // createDict = iframe.contentWindow.Object;\n  // html.removeChild(iframe);\n  iframeDocument = iframe.contentWindow.document;\n  iframeDocument.open();\n  iframeDocument.write(lt + 'script' + gt + 'document.F=Object' + lt + '/script' + gt);\n  iframeDocument.close();\n  createDict = iframeDocument.F;\n  while(i--)delete createDict[PROTOTYPE][enumBugKeys[i]];\n  return createDict();\n};\n\nmodule.exports = Object.create || function create(O, Properties){\n  var result;\n  if(O !== null){\n    Empty[PROTOTYPE] = anObject(O);\n    result = new Empty;\n    Empty[PROTOTYPE] = null;\n    // add \"__proto__\" for Object.getPrototypeOf polyfill\n    result[IE_PROTO] = O;\n  } else result = createDict();\n  return Properties === undefined ? result : dPs(result, Properties);\n};","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_dom-create":"node_modules/babel-polyfill/node_modules/core-js/modules/_dom-create.js","./_enum-bug-keys":"node_modules/babel-polyfill/node_modules/core-js/modules/_enum-bug-keys.js","./_html":"node_modules/babel-polyfill/node_modules/core-js/modules/_html.js","./_object-dps":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dps.js","./_shared-key":"node_modules/babel-polyfill/node_modules/core-js/modules/_shared-key.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dp.js","source":"var anObject       = require('./_an-object')\n  , IE8_DOM_DEFINE = require('./_ie8-dom-define')\n  , toPrimitive    = require('./_to-primitive')\n  , dP             = Object.defineProperty;\n\nexports.f = require('./_descriptors') ? Object.defineProperty : function defineProperty(O, P, Attributes){\n  anObject(O);\n  P = toPrimitive(P, true);\n  anObject(Attributes);\n  if(IE8_DOM_DEFINE)try {\n    return dP(O, P, Attributes);\n  } catch(e){ /* empty */ }\n  if('get' in Attributes || 'set' in Attributes)throw TypeError('Accessors not supported!');\n  if('value' in Attributes)O[P] = Attributes.value;\n  return O;\n};","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_descriptors":"node_modules/babel-polyfill/node_modules/core-js/modules/_descriptors.js","./_ie8-dom-define":"node_modules/babel-polyfill/node_modules/core-js/modules/_ie8-dom-define.js","./_to-primitive":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-primitive.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dps.js","source":"var dP       = require('./_object-dp')\n  , anObject = require('./_an-object')\n  , getKeys  = require('./_object-keys');\n\nmodule.exports = require('./_descriptors') ? Object.defineProperties : function defineProperties(O, Properties){\n  anObject(O);\n  var keys   = getKeys(Properties)\n    , length = keys.length\n    , i = 0\n    , P;\n  while(length > i)dP.f(O, P = keys[i++], Properties[P]);\n  return O;\n};","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_descriptors":"node_modules/babel-polyfill/node_modules/core-js/modules/_descriptors.js","./_object-dp":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dp.js","./_object-keys":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-keys.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-forced-pam.js","source":"module.exports = require('./_library')|| !require('./_fails')(function(){\n  var K = Math.random();\n  // In FF throws only define methods\n  __defineSetter__.call(null, K, function(){ /* empty */});\n  delete require('./_global')[K];\n});","deps":{"./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js","./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_library":"node_modules/babel-polyfill/node_modules/core-js/modules/_library.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopd.js","source":"var pIE            = require('./_object-pie')\n  , createDesc     = require('./_property-desc')\n  , toIObject      = require('./_to-iobject')\n  , toPrimitive    = require('./_to-primitive')\n  , has            = require('./_has')\n  , IE8_DOM_DEFINE = require('./_ie8-dom-define')\n  , gOPD           = Object.getOwnPropertyDescriptor;\n\nexports.f = require('./_descriptors') ? gOPD : function getOwnPropertyDescriptor(O, P){\n  O = toIObject(O);\n  P = toPrimitive(P, true);\n  if(IE8_DOM_DEFINE)try {\n    return gOPD(O, P);\n  } catch(e){ /* empty */ }\n  if(has(O, P))return createDesc(!pIE.f.call(O, P), O[P]);\n};","deps":{"./_descriptors":"node_modules/babel-polyfill/node_modules/core-js/modules/_descriptors.js","./_has":"node_modules/babel-polyfill/node_modules/core-js/modules/_has.js","./_ie8-dom-define":"node_modules/babel-polyfill/node_modules/core-js/modules/_ie8-dom-define.js","./_object-pie":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-pie.js","./_property-desc":"node_modules/babel-polyfill/node_modules/core-js/modules/_property-desc.js","./_to-iobject":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-iobject.js","./_to-primitive":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-primitive.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopn-ext.js","source":"var toIObject = require('./_to-iobject')\n  , gOPN      = require('./_object-gopn').f\n  , toString  = {}.toString;\n\nvar windowNames = typeof window == 'object' && window && Object.getOwnPropertyNames\n  ? Object.getOwnPropertyNames(window) : [];\n\nvar getWindowNames = function(it){\n  try {\n    return gOPN(it);\n  } catch(e){\n    return windowNames.slice();\n  }\n};\n\nmodule.exports.f = function getOwnPropertyNames(it){\n  return windowNames && toString.call(it) == '[object Window]' ? getWindowNames(it) : gOPN(toIObject(it));\n};","deps":{"./_object-gopn":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopn.js","./_to-iobject":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-iobject.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopn.js","source":"var $keys      = require('./_object-keys-internal')\n  , hiddenKeys = require('./_enum-bug-keys').concat('length', 'prototype');\n\nexports.f = Object.getOwnPropertyNames || function getOwnPropertyNames(O){\n  return $keys(O, hiddenKeys);\n};","deps":{"./_enum-bug-keys":"node_modules/babel-polyfill/node_modules/core-js/modules/_enum-bug-keys.js","./_object-keys-internal":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-keys-internal.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gops.js","source":"exports.f = Object.getOwnPropertySymbols;","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gpo.js","source":"var has         = require('./_has')\n  , toObject    = require('./_to-object')\n  , IE_PROTO    = require('./_shared-key')('IE_PROTO')\n  , ObjectProto = Object.prototype;\n\nmodule.exports = Object.getPrototypeOf || function(O){\n  O = toObject(O);\n  if(has(O, IE_PROTO))return O[IE_PROTO];\n  if(typeof O.constructor == 'function' && O instanceof O.constructor){\n    return O.constructor.prototype;\n  } return O instanceof Object ? ObjectProto : null;\n};","deps":{"./_has":"node_modules/babel-polyfill/node_modules/core-js/modules/_has.js","./_shared-key":"node_modules/babel-polyfill/node_modules/core-js/modules/_shared-key.js","./_to-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-object.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-keys-internal.js","source":"var has          = require('./_has')\n  , toIObject    = require('./_to-iobject')\n  , arrayIndexOf = require('./_array-includes')(false)\n  , IE_PROTO     = require('./_shared-key')('IE_PROTO');\n\nmodule.exports = function(object, names){\n  var O      = toIObject(object)\n    , i      = 0\n    , result = []\n    , key;\n  for(key in O)if(key != IE_PROTO)has(O, key) && result.push(key);\n  // Don't enum bug & hidden keys\n  while(names.length > i)if(has(O, key = names[i++])){\n    ~arrayIndexOf(result, key) || result.push(key);\n  }\n  return result;\n};","deps":{"./_array-includes":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-includes.js","./_has":"node_modules/babel-polyfill/node_modules/core-js/modules/_has.js","./_shared-key":"node_modules/babel-polyfill/node_modules/core-js/modules/_shared-key.js","./_to-iobject":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-iobject.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-keys.js","source":"var $keys       = require('./_object-keys-internal')\n  , enumBugKeys = require('./_enum-bug-keys');\n\nmodule.exports = Object.keys || function keys(O){\n  return $keys(O, enumBugKeys);\n};","deps":{"./_enum-bug-keys":"node_modules/babel-polyfill/node_modules/core-js/modules/_enum-bug-keys.js","./_object-keys-internal":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-keys-internal.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-pie.js","source":"exports.f = {}.propertyIsEnumerable;","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-sap.js","source":"var $export = require('./_export')\n  , core    = require('./_core')\n  , fails   = require('./_fails');\nmodule.exports = function(KEY, exec){\n  var fn  = (core.Object || {})[KEY] || Object[KEY]\n    , exp = {};\n  exp[KEY] = exec(fn);\n  $export($export.S + $export.F * fails(function(){ fn(1); }), 'Object', exp);\n};","deps":{"./_core":"node_modules/babel-polyfill/node_modules/core-js/modules/_core.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-to-array.js","source":"var getKeys   = require('./_object-keys')\n  , toIObject = require('./_to-iobject')\n  , isEnum    = require('./_object-pie').f;\nmodule.exports = function(isEntries){\n  return function(it){\n    var O      = toIObject(it)\n      , keys   = getKeys(O)\n      , length = keys.length\n      , i      = 0\n      , result = []\n      , key;\n    while(length > i)if(isEnum.call(O, key = keys[i++])){\n      result.push(isEntries ? [key, O[key]] : O[key]);\n    } return result;\n  };\n};","deps":{"./_object-keys":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-keys.js","./_object-pie":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-pie.js","./_to-iobject":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-iobject.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_own-keys.js","source":"var gOPN     = require('./_object-gopn')\n  , gOPS     = require('./_object-gops')\n  , anObject = require('./_an-object')\n  , Reflect  = require('./_global').Reflect;\nmodule.exports = Reflect && Reflect.ownKeys || function ownKeys(it){\n  var keys       = gOPN.f(anObject(it))\n    , getSymbols = gOPS.f;\n  return getSymbols ? keys.concat(getSymbols(it)) : keys;\n};","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_object-gopn":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopn.js","./_object-gops":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gops.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_parse-float.js","source":"var $parseFloat = require('./_global').parseFloat\n  , $trim       = require('./_string-trim').trim;\n\nmodule.exports = 1 / $parseFloat(require('./_string-ws') + '-0') !== -Infinity ? function parseFloat(str){\n  var string = $trim(String(str), 3)\n    , result = $parseFloat(string);\n  return result === 0 && string.charAt(0) == '-' ? -0 : result;\n} : $parseFloat;","deps":{"./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_string-trim":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-trim.js","./_string-ws":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-ws.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_parse-int.js","source":"var $parseInt = require('./_global').parseInt\n  , $trim     = require('./_string-trim').trim\n  , ws        = require('./_string-ws')\n  , hex       = /^[\\-+]?0[xX]/;\n\nmodule.exports = $parseInt(ws + '08') !== 8 || $parseInt(ws + '0x16') !== 22 ? function parseInt(str, radix){\n  var string = $trim(String(str), 3);\n  return $parseInt(string, (radix >>> 0) || (hex.test(string) ? 16 : 10));\n} : $parseInt;","deps":{"./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_string-trim":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-trim.js","./_string-ws":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-ws.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_partial.js","source":"'use strict';\nvar path      = require('./_path')\n  , invoke    = require('./_invoke')\n  , aFunction = require('./_a-function');\nmodule.exports = function(/* ...pargs */){\n  var fn     = aFunction(this)\n    , length = arguments.length\n    , pargs  = Array(length)\n    , i      = 0\n    , _      = path._\n    , holder = false;\n  while(length > i)if((pargs[i] = arguments[i++]) === _)holder = true;\n  return function(/* ...args */){\n    var that = this\n      , aLen = arguments.length\n      , j = 0, k = 0, args;\n    if(!holder && !aLen)return invoke(fn, pargs, that);\n    args = pargs.slice();\n    if(holder)for(;length > j; j++)if(args[j] === _)args[j] = arguments[k++];\n    while(aLen > k)args.push(arguments[k++]);\n    return invoke(fn, args, that);\n  };\n};","deps":{"./_a-function":"node_modules/babel-polyfill/node_modules/core-js/modules/_a-function.js","./_invoke":"node_modules/babel-polyfill/node_modules/core-js/modules/_invoke.js","./_path":"node_modules/babel-polyfill/node_modules/core-js/modules/_path.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_path.js","source":"module.exports = require('./_global');","deps":{"./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_property-desc.js","source":"module.exports = function(bitmap, value){\n  return {\n    enumerable  : !(bitmap & 1),\n    configurable: !(bitmap & 2),\n    writable    : !(bitmap & 4),\n    value       : value\n  };\n};","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_redefine-all.js","source":"var redefine = require('./_redefine');\nmodule.exports = function(target, src, safe){\n  for(var key in src)redefine(target, key, src[key], safe);\n  return target;\n};","deps":{"./_redefine":"node_modules/babel-polyfill/node_modules/core-js/modules/_redefine.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_redefine.js","source":"var global    = require('./_global')\n  , hide      = require('./_hide')\n  , has       = require('./_has')\n  , SRC       = require('./_uid')('src')\n  , TO_STRING = 'toString'\n  , $toString = Function[TO_STRING]\n  , TPL       = ('' + $toString).split(TO_STRING);\n\nrequire('./_core').inspectSource = function(it){\n  return $toString.call(it);\n};\n\n(module.exports = function(O, key, val, safe){\n  var isFunction = typeof val == 'function';\n  if(isFunction)has(val, 'name') || hide(val, 'name', key);\n  if(O[key] === val)return;\n  if(isFunction)has(val, SRC) || hide(val, SRC, O[key] ? '' + O[key] : TPL.join(String(key)));\n  if(O === global){\n    O[key] = val;\n  } else {\n    if(!safe){\n      delete O[key];\n      hide(O, key, val);\n    } else {\n      if(O[key])O[key] = val;\n      else hide(O, key, val);\n    }\n  }\n// add fake Function#toString for correct work wrapped methods / constructors with methods like LoDash isNative\n})(Function.prototype, TO_STRING, function toString(){\n  return typeof this == 'function' && this[SRC] || $toString.call(this);\n});","deps":{"./_core":"node_modules/babel-polyfill/node_modules/core-js/modules/_core.js","./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_has":"node_modules/babel-polyfill/node_modules/core-js/modules/_has.js","./_hide":"node_modules/babel-polyfill/node_modules/core-js/modules/_hide.js","./_uid":"node_modules/babel-polyfill/node_modules/core-js/modules/_uid.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_replacer.js","source":"module.exports = function(regExp, replace){\n  var replacer = replace === Object(replace) ? function(part){\n    return replace[part];\n  } : replace;\n  return function(it){\n    return String(it).replace(regExp, replacer);\n  };\n};","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_same-value.js","source":"module.exports = Object.is || function is(x, y){\n  return x === y ? x !== 0 || 1 / x === 1 / y : x != x && y != y;\n};","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_set-proto.js","source":"var isObject = require('./_is-object')\n  , anObject = require('./_an-object');\nvar check = function(O, proto){\n  anObject(O);\n  if(!isObject(proto) && proto !== null)throw TypeError(proto + \": can't set as prototype!\");\n};\nmodule.exports = {\n  set: Object.setPrototypeOf || ('__proto__' in {} ? // eslint-disable-line\n    function(test, buggy, set){\n      try {\n        set = require('./_ctx')(Function.call, require('./_object-gopd').f(Object.prototype, '__proto__').set, 2);\n        set(test, []);\n        buggy = !(test instanceof Array);\n      } catch(e){ buggy = true; }\n      return function setPrototypeOf(O, proto){\n        check(O, proto);\n        if(buggy)O.__proto__ = proto;\n        else set(O, proto);\n        return O;\n      };\n    }({}, false) : undefined),\n  check: check\n};","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_ctx":"node_modules/babel-polyfill/node_modules/core-js/modules/_ctx.js","./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js","./_object-gopd":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopd.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_set-species.js","source":"'use strict';\nvar global      = require('./_global')\n  , dP          = require('./_object-dp')\n  , DESCRIPTORS = require('./_descriptors')\n  , SPECIES     = require('./_wks')('species');\n\nmodule.exports = function(KEY){\n  var C = global[KEY];\n  if(DESCRIPTORS && C && !C[SPECIES])dP.f(C, SPECIES, {\n    configurable: true,\n    get: function(){ return this; }\n  });\n};","deps":{"./_descriptors":"node_modules/babel-polyfill/node_modules/core-js/modules/_descriptors.js","./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_object-dp":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dp.js","./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_set-to-string-tag.js","source":"var def = require('./_object-dp').f\n  , has = require('./_has')\n  , TAG = require('./_wks')('toStringTag');\n\nmodule.exports = function(it, tag, stat){\n  if(it && !has(it = stat ? it : it.prototype, TAG))def(it, TAG, {configurable: true, value: tag});\n};","deps":{"./_has":"node_modules/babel-polyfill/node_modules/core-js/modules/_has.js","./_object-dp":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dp.js","./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_shared-key.js","source":"var shared = require('./_shared')('keys')\n  , uid    = require('./_uid');\nmodule.exports = function(key){\n  return shared[key] || (shared[key] = uid(key));\n};","deps":{"./_shared":"node_modules/babel-polyfill/node_modules/core-js/modules/_shared.js","./_uid":"node_modules/babel-polyfill/node_modules/core-js/modules/_uid.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_shared.js","source":"var global = require('./_global')\n  , SHARED = '__core-js_shared__'\n  , store  = global[SHARED] || (global[SHARED] = {});\nmodule.exports = function(key){\n  return store[key] || (store[key] = {});\n};","deps":{"./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_species-constructor.js","source":"var anObject  = require('./_an-object')\n  , aFunction = require('./_a-function')\n  , SPECIES   = require('./_wks')('species');\nmodule.exports = function(O, D){\n  var C = anObject(O).constructor, S;\n  return C === undefined || (S = anObject(C)[SPECIES]) == undefined ? D : aFunction(S);\n};","deps":{"./_a-function":"node_modules/babel-polyfill/node_modules/core-js/modules/_a-function.js","./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_strict-method.js","source":"var fails = require('./_fails');\n\nmodule.exports = function(method, arg){\n  return !!method && fails(function(){\n    arg ? method.call(null, function(){}, 1) : method.call(null);\n  });\n};","deps":{"./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-at.js","source":"var toInteger = require('./_to-integer')\n  , defined   = require('./_defined');\n// true  -> String#at\n// false -> String#codePointAt\nmodule.exports = function(TO_STRING){\n  return function(that, pos){\n    var s = String(defined(that))\n      , i = toInteger(pos)\n      , l = s.length\n      , a, b;\n    if(i < 0 || i >= l)return TO_STRING ? '' : undefined;\n    a = s.charCodeAt(i);\n    return a < 0xd800 || a > 0xdbff || i + 1 === l || (b = s.charCodeAt(i + 1)) < 0xdc00 || b > 0xdfff\n      ? TO_STRING ? s.charAt(i) : a\n      : TO_STRING ? s.slice(i, i + 2) : (a - 0xd800 << 10) + (b - 0xdc00) + 0x10000;\n  };\n};","deps":{"./_defined":"node_modules/babel-polyfill/node_modules/core-js/modules/_defined.js","./_to-integer":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-integer.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-context.js","source":"var isRegExp = require('./_is-regexp')\n  , defined  = require('./_defined');\n\nmodule.exports = function(that, searchString, NAME){\n  if(isRegExp(searchString))throw TypeError('String#' + NAME + \" doesn't accept regex!\");\n  return String(defined(that));\n};","deps":{"./_defined":"node_modules/babel-polyfill/node_modules/core-js/modules/_defined.js","./_is-regexp":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-regexp.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-html.js","source":"var $export = require('./_export')\n  , fails   = require('./_fails')\n  , defined = require('./_defined')\n  , quot    = /\"/g;\n// B.2.3.2.1 CreateHTML(string, tag, attribute, value)\nvar createHTML = function(string, tag, attribute, value) {\n  var S  = String(defined(string))\n    , p1 = '<' + tag;\n  if(attribute !== '')p1 += ' ' + attribute + '=\"' + String(value).replace(quot, '&quot;') + '\"';\n  return p1 + '>' + S + '</' + tag + '>';\n};\nmodule.exports = function(NAME, exec){\n  var O = {};\n  O[NAME] = exec(createHTML);\n  $export($export.P + $export.F * fails(function(){\n    var test = ''[NAME]('\"');\n    return test !== test.toLowerCase() || test.split('\"').length > 3;\n  }), 'String', O);\n};","deps":{"./_defined":"node_modules/babel-polyfill/node_modules/core-js/modules/_defined.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-pad.js","source":"var toLength = require('./_to-length')\n  , repeat   = require('./_string-repeat')\n  , defined  = require('./_defined');\n\nmodule.exports = function(that, maxLength, fillString, left){\n  var S            = String(defined(that))\n    , stringLength = S.length\n    , fillStr      = fillString === undefined ? ' ' : String(fillString)\n    , intMaxLength = toLength(maxLength);\n  if(intMaxLength <= stringLength || fillStr == '')return S;\n  var fillLen = intMaxLength - stringLength\n    , stringFiller = repeat.call(fillStr, Math.ceil(fillLen / fillStr.length));\n  if(stringFiller.length > fillLen)stringFiller = stringFiller.slice(0, fillLen);\n  return left ? stringFiller + S : S + stringFiller;\n};","deps":{"./_defined":"node_modules/babel-polyfill/node_modules/core-js/modules/_defined.js","./_string-repeat":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-repeat.js","./_to-length":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-length.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-repeat.js","source":"'use strict';\nvar toInteger = require('./_to-integer')\n  , defined   = require('./_defined');\n\nmodule.exports = function repeat(count){\n  var str = String(defined(this))\n    , res = ''\n    , n   = toInteger(count);\n  if(n < 0 || n == Infinity)throw RangeError(\"Count can't be negative\");\n  for(;n > 0; (n >>>= 1) && (str += str))if(n & 1)res += str;\n  return res;\n};","deps":{"./_defined":"node_modules/babel-polyfill/node_modules/core-js/modules/_defined.js","./_to-integer":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-integer.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-trim.js","source":"var $export = require('./_export')\n  , defined = require('./_defined')\n  , fails   = require('./_fails')\n  , spaces  = require('./_string-ws')\n  , space   = '[' + spaces + ']'\n  , non     = '\\u200b\\u0085'\n  , ltrim   = RegExp('^' + space + space + '*')\n  , rtrim   = RegExp(space + space + '*$');\n\nvar exporter = function(KEY, exec, ALIAS){\n  var exp   = {};\n  var FORCE = fails(function(){\n    return !!spaces[KEY]() || non[KEY]() != non;\n  });\n  var fn = exp[KEY] = FORCE ? exec(trim) : spaces[KEY];\n  if(ALIAS)exp[ALIAS] = fn;\n  $export($export.P + $export.F * FORCE, 'String', exp);\n};\n\n// 1 -> String#trimLeft\n// 2 -> String#trimRight\n// 3 -> String#trim\nvar trim = exporter.trim = function(string, TYPE){\n  string = String(defined(string));\n  if(TYPE & 1)string = string.replace(ltrim, '');\n  if(TYPE & 2)string = string.replace(rtrim, '');\n  return string;\n};\n\nmodule.exports = exporter;","deps":{"./_defined":"node_modules/babel-polyfill/node_modules/core-js/modules/_defined.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js","./_string-ws":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-ws.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-ws.js","source":"module.exports = '\\x09\\x0A\\x0B\\x0C\\x0D\\x20\\xA0\\u1680\\u180E\\u2000\\u2001\\u2002\\u2003' +\n  '\\u2004\\u2005\\u2006\\u2007\\u2008\\u2009\\u200A\\u202F\\u205F\\u3000\\u2028\\u2029\\uFEFF';","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_task.js","source":"var ctx                = require('./_ctx')\n  , invoke             = require('./_invoke')\n  , html               = require('./_html')\n  , cel                = require('./_dom-create')\n  , global             = require('./_global')\n  , process            = global.process\n  , setTask            = global.setImmediate\n  , clearTask          = global.clearImmediate\n  , MessageChannel     = global.MessageChannel\n  , counter            = 0\n  , queue              = {}\n  , ONREADYSTATECHANGE = 'onreadystatechange'\n  , defer, channel, port;\nvar run = function(){\n  var id = +this;\n  if(queue.hasOwnProperty(id)){\n    var fn = queue[id];\n    delete queue[id];\n    fn();\n  }\n};\nvar listener = function(event){\n  run.call(event.data);\n};\n// Node.js 0.9+ & IE10+ has setImmediate, otherwise:\nif(!setTask || !clearTask){\n  setTask = function setImmediate(fn){\n    var args = [], i = 1;\n    while(arguments.length > i)args.push(arguments[i++]);\n    queue[++counter] = function(){\n      invoke(typeof fn == 'function' ? fn : Function(fn), args);\n    };\n    defer(counter);\n    return counter;\n  };\n  clearTask = function clearImmediate(id){\n    delete queue[id];\n  };\n  // Node.js 0.8-\n  if(require('./_cof')(process) == 'process'){\n    defer = function(id){\n      process.nextTick(ctx(run, id, 1));\n    };\n  // Browsers with MessageChannel, includes WebWorkers\n  } else if(MessageChannel){\n    channel = new MessageChannel;\n    port    = channel.port2;\n    channel.port1.onmessage = listener;\n    defer = ctx(port.postMessage, port, 1);\n  // Browsers with postMessage, skip WebWorkers\n  // IE8 has postMessage, but it's sync & typeof its postMessage is 'object'\n  } else if(global.addEventListener && typeof postMessage == 'function' && !global.importScripts){\n    defer = function(id){\n      global.postMessage(id + '', '*');\n    };\n    global.addEventListener('message', listener, false);\n  // IE8-\n  } else if(ONREADYSTATECHANGE in cel('script')){\n    defer = function(id){\n      html.appendChild(cel('script'))[ONREADYSTATECHANGE] = function(){\n        html.removeChild(this);\n        run.call(id);\n      };\n    };\n  // Rest old browsers\n  } else {\n    defer = function(id){\n      setTimeout(ctx(run, id, 1), 0);\n    };\n  }\n}\nmodule.exports = {\n  set:   setTask,\n  clear: clearTask\n};","deps":{"./_cof":"node_modules/babel-polyfill/node_modules/core-js/modules/_cof.js","./_ctx":"node_modules/babel-polyfill/node_modules/core-js/modules/_ctx.js","./_dom-create":"node_modules/babel-polyfill/node_modules/core-js/modules/_dom-create.js","./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_html":"node_modules/babel-polyfill/node_modules/core-js/modules/_html.js","./_invoke":"node_modules/babel-polyfill/node_modules/core-js/modules/_invoke.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-index.js","source":"var toInteger = require('./_to-integer')\n  , max       = Math.max\n  , min       = Math.min;\nmodule.exports = function(index, length){\n  index = toInteger(index);\n  return index < 0 ? max(index + length, 0) : min(index, length);\n};","deps":{"./_to-integer":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-integer.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-integer.js","source":"var ceil  = Math.ceil\n  , floor = Math.floor;\nmodule.exports = function(it){\n  return isNaN(it = +it) ? 0 : (it > 0 ? floor : ceil)(it);\n};","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-iobject.js","source":"var IObject = require('./_iobject')\n  , defined = require('./_defined');\nmodule.exports = function(it){\n  return IObject(defined(it));\n};","deps":{"./_defined":"node_modules/babel-polyfill/node_modules/core-js/modules/_defined.js","./_iobject":"node_modules/babel-polyfill/node_modules/core-js/modules/_iobject.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-length.js","source":"var toInteger = require('./_to-integer')\n  , min       = Math.min;\nmodule.exports = function(it){\n  return it > 0 ? min(toInteger(it), 0x1fffffffffffff) : 0; // pow(2, 53) - 1 == 9007199254740991\n};","deps":{"./_to-integer":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-integer.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-object.js","source":"var defined = require('./_defined');\nmodule.exports = function(it){\n  return Object(defined(it));\n};","deps":{"./_defined":"node_modules/babel-polyfill/node_modules/core-js/modules/_defined.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-primitive.js","source":"var isObject = require('./_is-object');\n// instead of the ES6 spec version, we didn't implement @@toPrimitive case\n// and the second argument - flag - preferred type is a string\nmodule.exports = function(it, S){\n  if(!isObject(it))return it;\n  var fn, val;\n  if(S && typeof (fn = it.toString) == 'function' && !isObject(val = fn.call(it)))return val;\n  if(typeof (fn = it.valueOf) == 'function' && !isObject(val = fn.call(it)))return val;\n  if(!S && typeof (fn = it.toString) == 'function' && !isObject(val = fn.call(it)))return val;\n  throw TypeError(\"Can't convert object to primitive value\");\n};","deps":{"./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_typed-array.js","source":"'use strict';\nif(require('./_descriptors')){\n  var LIBRARY             = require('./_library')\n    , global              = require('./_global')\n    , fails               = require('./_fails')\n    , $export             = require('./_export')\n    , $typed              = require('./_typed')\n    , $buffer             = require('./_typed-buffer')\n    , ctx                 = require('./_ctx')\n    , anInstance          = require('./_an-instance')\n    , propertyDesc        = require('./_property-desc')\n    , hide                = require('./_hide')\n    , redefineAll         = require('./_redefine-all')\n    , toInteger           = require('./_to-integer')\n    , toLength            = require('./_to-length')\n    , toIndex             = require('./_to-index')\n    , toPrimitive         = require('./_to-primitive')\n    , has                 = require('./_has')\n    , same                = require('./_same-value')\n    , classof             = require('./_classof')\n    , isObject            = require('./_is-object')\n    , toObject            = require('./_to-object')\n    , isArrayIter         = require('./_is-array-iter')\n    , create              = require('./_object-create')\n    , getPrototypeOf      = require('./_object-gpo')\n    , gOPN                = require('./_object-gopn').f\n    , getIterFn           = require('./core.get-iterator-method')\n    , uid                 = require('./_uid')\n    , wks                 = require('./_wks')\n    , createArrayMethod   = require('./_array-methods')\n    , createArrayIncludes = require('./_array-includes')\n    , speciesConstructor  = require('./_species-constructor')\n    , ArrayIterators      = require('./es6.array.iterator')\n    , Iterators           = require('./_iterators')\n    , $iterDetect         = require('./_iter-detect')\n    , setSpecies          = require('./_set-species')\n    , arrayFill           = require('./_array-fill')\n    , arrayCopyWithin     = require('./_array-copy-within')\n    , $DP                 = require('./_object-dp')\n    , $GOPD               = require('./_object-gopd')\n    , dP                  = $DP.f\n    , gOPD                = $GOPD.f\n    , RangeError          = global.RangeError\n    , TypeError           = global.TypeError\n    , Uint8Array          = global.Uint8Array\n    , ARRAY_BUFFER        = 'ArrayBuffer'\n    , SHARED_BUFFER       = 'Shared' + ARRAY_BUFFER\n    , BYTES_PER_ELEMENT   = 'BYTES_PER_ELEMENT'\n    , PROTOTYPE           = 'prototype'\n    , ArrayProto          = Array[PROTOTYPE]\n    , $ArrayBuffer        = $buffer.ArrayBuffer\n    , $DataView           = $buffer.DataView\n    , arrayForEach        = createArrayMethod(0)\n    , arrayFilter         = createArrayMethod(2)\n    , arraySome           = createArrayMethod(3)\n    , arrayEvery          = createArrayMethod(4)\n    , arrayFind           = createArrayMethod(5)\n    , arrayFindIndex      = createArrayMethod(6)\n    , arrayIncludes       = createArrayIncludes(true)\n    , arrayIndexOf        = createArrayIncludes(false)\n    , arrayValues         = ArrayIterators.values\n    , arrayKeys           = ArrayIterators.keys\n    , arrayEntries        = ArrayIterators.entries\n    , arrayLastIndexOf    = ArrayProto.lastIndexOf\n    , arrayReduce         = ArrayProto.reduce\n    , arrayReduceRight    = ArrayProto.reduceRight\n    , arrayJoin           = ArrayProto.join\n    , arraySort           = ArrayProto.sort\n    , arraySlice          = ArrayProto.slice\n    , arrayToString       = ArrayProto.toString\n    , arrayToLocaleString = ArrayProto.toLocaleString\n    , ITERATOR            = wks('iterator')\n    , TAG                 = wks('toStringTag')\n    , TYPED_CONSTRUCTOR   = uid('typed_constructor')\n    , DEF_CONSTRUCTOR     = uid('def_constructor')\n    , ALL_CONSTRUCTORS    = $typed.CONSTR\n    , TYPED_ARRAY         = $typed.TYPED\n    , VIEW                = $typed.VIEW\n    , WRONG_LENGTH        = 'Wrong length!';\n\n  var $map = createArrayMethod(1, function(O, length){\n    return allocate(speciesConstructor(O, O[DEF_CONSTRUCTOR]), length);\n  });\n\n  var LITTLE_ENDIAN = fails(function(){\n    return new Uint8Array(new Uint16Array([1]).buffer)[0] === 1;\n  });\n\n  var FORCED_SET = !!Uint8Array && !!Uint8Array[PROTOTYPE].set && fails(function(){\n    new Uint8Array(1).set({});\n  });\n\n  var strictToLength = function(it, SAME){\n    if(it === undefined)throw TypeError(WRONG_LENGTH);\n    var number = +it\n      , length = toLength(it);\n    if(SAME && !same(number, length))throw RangeError(WRONG_LENGTH);\n    return length;\n  };\n\n  var toOffset = function(it, BYTES){\n    var offset = toInteger(it);\n    if(offset < 0 || offset % BYTES)throw RangeError('Wrong offset!');\n    return offset;\n  };\n\n  var validate = function(it){\n    if(isObject(it) && TYPED_ARRAY in it)return it;\n    throw TypeError(it + ' is not a typed array!');\n  };\n\n  var allocate = function(C, length){\n    if(!(isObject(C) && TYPED_CONSTRUCTOR in C)){\n      throw TypeError('It is not a typed array constructor!');\n    } return new C(length);\n  };\n\n  var speciesFromList = function(O, list){\n    return fromList(speciesConstructor(O, O[DEF_CONSTRUCTOR]), list);\n  };\n\n  var fromList = function(C, list){\n    var index  = 0\n      , length = list.length\n      , result = allocate(C, length);\n    while(length > index)result[index] = list[index++];\n    return result;\n  };\n\n  var addGetter = function(it, key, internal){\n    dP(it, key, {get: function(){ return this._d[internal]; }});\n  };\n\n  var $from = function from(source /*, mapfn, thisArg */){\n    var O       = toObject(source)\n      , aLen    = arguments.length\n      , mapfn   = aLen > 1 ? arguments[1] : undefined\n      , mapping = mapfn !== undefined\n      , iterFn  = getIterFn(O)\n      , i, length, values, result, step, iterator;\n    if(iterFn != undefined && !isArrayIter(iterFn)){\n      for(iterator = iterFn.call(O), values = [], i = 0; !(step = iterator.next()).done; i++){\n        values.push(step.value);\n      } O = values;\n    }\n    if(mapping && aLen > 2)mapfn = ctx(mapfn, arguments[2], 2);\n    for(i = 0, length = toLength(O.length), result = allocate(this, length); length > i; i++){\n      result[i] = mapping ? mapfn(O[i], i) : O[i];\n    }\n    return result;\n  };\n\n  var $of = function of(/*...items*/){\n    var index  = 0\n      , length = arguments.length\n      , result = allocate(this, length);\n    while(length > index)result[index] = arguments[index++];\n    return result;\n  };\n\n  // iOS Safari 6.x fails here\n  var TO_LOCALE_BUG = !!Uint8Array && fails(function(){ arrayToLocaleString.call(new Uint8Array(1)); });\n\n  var $toLocaleString = function toLocaleString(){\n    return arrayToLocaleString.apply(TO_LOCALE_BUG ? arraySlice.call(validate(this)) : validate(this), arguments);\n  };\n\n  var proto = {\n    copyWithin: function copyWithin(target, start /*, end */){\n      return arrayCopyWithin.call(validate(this), target, start, arguments.length > 2 ? arguments[2] : undefined);\n    },\n    every: function every(callbackfn /*, thisArg */){\n      return arrayEvery(validate(this), callbackfn, arguments.length > 1 ? arguments[1] : undefined);\n    },\n    fill: function fill(value /*, start, end */){ // eslint-disable-line no-unused-vars\n      return arrayFill.apply(validate(this), arguments);\n    },\n    filter: function filter(callbackfn /*, thisArg */){\n      return speciesFromList(this, arrayFilter(validate(this), callbackfn,\n        arguments.length > 1 ? arguments[1] : undefined));\n    },\n    find: function find(predicate /*, thisArg */){\n      return arrayFind(validate(this), predicate, arguments.length > 1 ? arguments[1] : undefined);\n    },\n    findIndex: function findIndex(predicate /*, thisArg */){\n      return arrayFindIndex(validate(this), predicate, arguments.length > 1 ? arguments[1] : undefined);\n    },\n    forEach: function forEach(callbackfn /*, thisArg */){\n      arrayForEach(validate(this), callbackfn, arguments.length > 1 ? arguments[1] : undefined);\n    },\n    indexOf: function indexOf(searchElement /*, fromIndex */){\n      return arrayIndexOf(validate(this), searchElement, arguments.length > 1 ? arguments[1] : undefined);\n    },\n    includes: function includes(searchElement /*, fromIndex */){\n      return arrayIncludes(validate(this), searchElement, arguments.length > 1 ? arguments[1] : undefined);\n    },\n    join: function join(separator){ // eslint-disable-line no-unused-vars\n      return arrayJoin.apply(validate(this), arguments);\n    },\n    lastIndexOf: function lastIndexOf(searchElement /*, fromIndex */){ // eslint-disable-line no-unused-vars\n      return arrayLastIndexOf.apply(validate(this), arguments);\n    },\n    map: function map(mapfn /*, thisArg */){\n      return $map(validate(this), mapfn, arguments.length > 1 ? arguments[1] : undefined);\n    },\n    reduce: function reduce(callbackfn /*, initialValue */){ // eslint-disable-line no-unused-vars\n      return arrayReduce.apply(validate(this), arguments);\n    },\n    reduceRight: function reduceRight(callbackfn /*, initialValue */){ // eslint-disable-line no-unused-vars\n      return arrayReduceRight.apply(validate(this), arguments);\n    },\n    reverse: function reverse(){\n      var that   = this\n        , length = validate(that).length\n        , middle = Math.floor(length / 2)\n        , index  = 0\n        , value;\n      while(index < middle){\n        value         = that[index];\n        that[index++] = that[--length];\n        that[length]  = value;\n      } return that;\n    },\n    some: function some(callbackfn /*, thisArg */){\n      return arraySome(validate(this), callbackfn, arguments.length > 1 ? arguments[1] : undefined);\n    },\n    sort: function sort(comparefn){\n      return arraySort.call(validate(this), comparefn);\n    },\n    subarray: function subarray(begin, end){\n      var O      = validate(this)\n        , length = O.length\n        , $begin = toIndex(begin, length);\n      return new (speciesConstructor(O, O[DEF_CONSTRUCTOR]))(\n        O.buffer,\n        O.byteOffset + $begin * O.BYTES_PER_ELEMENT,\n        toLength((end === undefined ? length : toIndex(end, length)) - $begin)\n      );\n    }\n  };\n\n  var $slice = function slice(start, end){\n    return speciesFromList(this, arraySlice.call(validate(this), start, end));\n  };\n\n  var $set = function set(arrayLike /*, offset */){\n    validate(this);\n    var offset = toOffset(arguments[1], 1)\n      , length = this.length\n      , src    = toObject(arrayLike)\n      , len    = toLength(src.length)\n      , index  = 0;\n    if(len + offset > length)throw RangeError(WRONG_LENGTH);\n    while(index < len)this[offset + index] = src[index++];\n  };\n\n  var $iterators = {\n    entries: function entries(){\n      return arrayEntries.call(validate(this));\n    },\n    keys: function keys(){\n      return arrayKeys.call(validate(this));\n    },\n    values: function values(){\n      return arrayValues.call(validate(this));\n    }\n  };\n\n  var isTAIndex = function(target, key){\n    return isObject(target)\n      && target[TYPED_ARRAY]\n      && typeof key != 'symbol'\n      && key in target\n      && String(+key) == String(key);\n  };\n  var $getDesc = function getOwnPropertyDescriptor(target, key){\n    return isTAIndex(target, key = toPrimitive(key, true))\n      ? propertyDesc(2, target[key])\n      : gOPD(target, key);\n  };\n  var $setDesc = function defineProperty(target, key, desc){\n    if(isTAIndex(target, key = toPrimitive(key, true))\n      && isObject(desc)\n      && has(desc, 'value')\n      && !has(desc, 'get')\n      && !has(desc, 'set')\n      // TODO: add validation descriptor w/o calling accessors\n      && !desc.configurable\n      && (!has(desc, 'writable') || desc.writable)\n      && (!has(desc, 'enumerable') || desc.enumerable)\n    ){\n      target[key] = desc.value;\n      return target;\n    } else return dP(target, key, desc);\n  };\n\n  if(!ALL_CONSTRUCTORS){\n    $GOPD.f = $getDesc;\n    $DP.f   = $setDesc;\n  }\n\n  $export($export.S + $export.F * !ALL_CONSTRUCTORS, 'Object', {\n    getOwnPropertyDescriptor: $getDesc,\n    defineProperty:           $setDesc\n  });\n\n  if(fails(function(){ arrayToString.call({}); })){\n    arrayToString = arrayToLocaleString = function toString(){\n      return arrayJoin.call(this);\n    }\n  }\n\n  var $TypedArrayPrototype$ = redefineAll({}, proto);\n  redefineAll($TypedArrayPrototype$, $iterators);\n  hide($TypedArrayPrototype$, ITERATOR, $iterators.values);\n  redefineAll($TypedArrayPrototype$, {\n    slice:          $slice,\n    set:            $set,\n    constructor:    function(){ /* noop */ },\n    toString:       arrayToString,\n    toLocaleString: $toLocaleString\n  });\n  addGetter($TypedArrayPrototype$, 'buffer', 'b');\n  addGetter($TypedArrayPrototype$, 'byteOffset', 'o');\n  addGetter($TypedArrayPrototype$, 'byteLength', 'l');\n  addGetter($TypedArrayPrototype$, 'length', 'e');\n  dP($TypedArrayPrototype$, TAG, {\n    get: function(){ return this[TYPED_ARRAY]; }\n  });\n\n  module.exports = function(KEY, BYTES, wrapper, CLAMPED){\n    CLAMPED = !!CLAMPED;\n    var NAME       = KEY + (CLAMPED ? 'Clamped' : '') + 'Array'\n      , ISNT_UINT8 = NAME != 'Uint8Array'\n      , GETTER     = 'get' + KEY\n      , SETTER     = 'set' + KEY\n      , TypedArray = global[NAME]\n      , Base       = TypedArray || {}\n      , TAC        = TypedArray && getPrototypeOf(TypedArray)\n      , FORCED     = !TypedArray || !$typed.ABV\n      , O          = {}\n      , TypedArrayPrototype = TypedArray && TypedArray[PROTOTYPE];\n    var getter = function(that, index){\n      var data = that._d;\n      return data.v[GETTER](index * BYTES + data.o, LITTLE_ENDIAN);\n    };\n    var setter = function(that, index, value){\n      var data = that._d;\n      if(CLAMPED)value = (value = Math.round(value)) < 0 ? 0 : value > 0xff ? 0xff : value & 0xff;\n      data.v[SETTER](index * BYTES + data.o, value, LITTLE_ENDIAN);\n    };\n    var addElement = function(that, index){\n      dP(that, index, {\n        get: function(){\n          return getter(this, index);\n        },\n        set: function(value){\n          return setter(this, index, value);\n        },\n        enumerable: true\n      });\n    };\n    if(FORCED){\n      TypedArray = wrapper(function(that, data, $offset, $length){\n        anInstance(that, TypedArray, NAME, '_d');\n        var index  = 0\n          , offset = 0\n          , buffer, byteLength, length, klass;\n        if(!isObject(data)){\n          length     = strictToLength(data, true)\n          byteLength = length * BYTES;\n          buffer     = new $ArrayBuffer(byteLength);\n        } else if(data instanceof $ArrayBuffer || (klass = classof(data)) == ARRAY_BUFFER || klass == SHARED_BUFFER){\n          buffer = data;\n          offset = toOffset($offset, BYTES);\n          var $len = data.byteLength;\n          if($length === undefined){\n            if($len % BYTES)throw RangeError(WRONG_LENGTH);\n            byteLength = $len - offset;\n            if(byteLength < 0)throw RangeError(WRONG_LENGTH);\n          } else {\n            byteLength = toLength($length) * BYTES;\n            if(byteLength + offset > $len)throw RangeError(WRONG_LENGTH);\n          }\n          length = byteLength / BYTES;\n        } else if(TYPED_ARRAY in data){\n          return fromList(TypedArray, data);\n        } else {\n          return $from.call(TypedArray, data);\n        }\n        hide(that, '_d', {\n          b: buffer,\n          o: offset,\n          l: byteLength,\n          e: length,\n          v: new $DataView(buffer)\n        });\n        while(index < length)addElement(that, index++);\n      });\n      TypedArrayPrototype = TypedArray[PROTOTYPE] = create($TypedArrayPrototype$);\n      hide(TypedArrayPrototype, 'constructor', TypedArray);\n    } else if(!$iterDetect(function(iter){\n      // V8 works with iterators, but fails in many other cases\n      // https://code.google.com/p/v8/issues/detail?id=4552\n      new TypedArray(null); // eslint-disable-line no-new\n      new TypedArray(iter); // eslint-disable-line no-new\n    }, true)){\n      TypedArray = wrapper(function(that, data, $offset, $length){\n        anInstance(that, TypedArray, NAME);\n        var klass;\n        // `ws` module bug, temporarily remove validation length for Uint8Array\n        // https://github.com/websockets/ws/pull/645\n        if(!isObject(data))return new Base(strictToLength(data, ISNT_UINT8));\n        if(data instanceof $ArrayBuffer || (klass = classof(data)) == ARRAY_BUFFER || klass == SHARED_BUFFER){\n          return $length !== undefined\n            ? new Base(data, toOffset($offset, BYTES), $length)\n            : $offset !== undefined\n              ? new Base(data, toOffset($offset, BYTES))\n              : new Base(data);\n        }\n        if(TYPED_ARRAY in data)return fromList(TypedArray, data);\n        return $from.call(TypedArray, data);\n      });\n      arrayForEach(TAC !== Function.prototype ? gOPN(Base).concat(gOPN(TAC)) : gOPN(Base), function(key){\n        if(!(key in TypedArray))hide(TypedArray, key, Base[key]);\n      });\n      TypedArray[PROTOTYPE] = TypedArrayPrototype;\n      if(!LIBRARY)TypedArrayPrototype.constructor = TypedArray;\n    }\n    var $nativeIterator   = TypedArrayPrototype[ITERATOR]\n      , CORRECT_ITER_NAME = !!$nativeIterator && ($nativeIterator.name == 'values' || $nativeIterator.name == undefined)\n      , $iterator         = $iterators.values;\n    hide(TypedArray, TYPED_CONSTRUCTOR, true);\n    hide(TypedArrayPrototype, TYPED_ARRAY, NAME);\n    hide(TypedArrayPrototype, VIEW, true);\n    hide(TypedArrayPrototype, DEF_CONSTRUCTOR, TypedArray);\n\n    if(CLAMPED ? new TypedArray(1)[TAG] != NAME : !(TAG in TypedArrayPrototype)){\n      dP(TypedArrayPrototype, TAG, {\n        get: function(){ return NAME; }\n      });\n    }\n\n    O[NAME] = TypedArray;\n\n    $export($export.G + $export.W + $export.F * (TypedArray != Base), O);\n\n    $export($export.S, NAME, {\n      BYTES_PER_ELEMENT: BYTES,\n      from: $from,\n      of: $of\n    });\n\n    if(!(BYTES_PER_ELEMENT in TypedArrayPrototype))hide(TypedArrayPrototype, BYTES_PER_ELEMENT, BYTES);\n\n    $export($export.P, NAME, proto);\n\n    setSpecies(NAME);\n\n    $export($export.P + $export.F * FORCED_SET, NAME, {set: $set});\n\n    $export($export.P + $export.F * !CORRECT_ITER_NAME, NAME, $iterators);\n\n    $export($export.P + $export.F * (TypedArrayPrototype.toString != arrayToString), NAME, {toString: arrayToString});\n\n    $export($export.P + $export.F * fails(function(){\n      new TypedArray(1).slice();\n    }), NAME, {slice: $slice});\n\n    $export($export.P + $export.F * (fails(function(){\n      return [1, 2].toLocaleString() != new TypedArray([1, 2]).toLocaleString()\n    }) || !fails(function(){\n      TypedArrayPrototype.toLocaleString.call([1, 2]);\n    })), NAME, {toLocaleString: $toLocaleString});\n\n    Iterators[NAME] = CORRECT_ITER_NAME ? $nativeIterator : $iterator;\n    if(!LIBRARY && !CORRECT_ITER_NAME)hide(TypedArrayPrototype, ITERATOR, $iterator);\n  };\n} else module.exports = function(){ /* empty */ };","deps":{"./_an-instance":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-instance.js","./_array-copy-within":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-copy-within.js","./_array-fill":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-fill.js","./_array-includes":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-includes.js","./_array-methods":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-methods.js","./_classof":"node_modules/babel-polyfill/node_modules/core-js/modules/_classof.js","./_ctx":"node_modules/babel-polyfill/node_modules/core-js/modules/_ctx.js","./_descriptors":"node_modules/babel-polyfill/node_modules/core-js/modules/_descriptors.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js","./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_has":"node_modules/babel-polyfill/node_modules/core-js/modules/_has.js","./_hide":"node_modules/babel-polyfill/node_modules/core-js/modules/_hide.js","./_is-array-iter":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-array-iter.js","./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js","./_iter-detect":"node_modules/babel-polyfill/node_modules/core-js/modules/_iter-detect.js","./_iterators":"node_modules/babel-polyfill/node_modules/core-js/modules/_iterators.js","./_library":"node_modules/babel-polyfill/node_modules/core-js/modules/_library.js","./_object-create":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-create.js","./_object-dp":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dp.js","./_object-gopd":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopd.js","./_object-gopn":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopn.js","./_object-gpo":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gpo.js","./_property-desc":"node_modules/babel-polyfill/node_modules/core-js/modules/_property-desc.js","./_redefine-all":"node_modules/babel-polyfill/node_modules/core-js/modules/_redefine-all.js","./_same-value":"node_modules/babel-polyfill/node_modules/core-js/modules/_same-value.js","./_set-species":"node_modules/babel-polyfill/node_modules/core-js/modules/_set-species.js","./_species-constructor":"node_modules/babel-polyfill/node_modules/core-js/modules/_species-constructor.js","./_to-index":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-index.js","./_to-integer":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-integer.js","./_to-length":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-length.js","./_to-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-object.js","./_to-primitive":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-primitive.js","./_typed":"node_modules/babel-polyfill/node_modules/core-js/modules/_typed.js","./_typed-buffer":"node_modules/babel-polyfill/node_modules/core-js/modules/_typed-buffer.js","./_uid":"node_modules/babel-polyfill/node_modules/core-js/modules/_uid.js","./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js","./core.get-iterator-method":"node_modules/babel-polyfill/node_modules/core-js/modules/core.get-iterator-method.js","./es6.array.iterator":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.iterator.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_typed-buffer.js","source":"'use strict';\nvar global         = require('./_global')\n  , DESCRIPTORS    = require('./_descriptors')\n  , LIBRARY        = require('./_library')\n  , $typed         = require('./_typed')\n  , hide           = require('./_hide')\n  , redefineAll    = require('./_redefine-all')\n  , fails          = require('./_fails')\n  , anInstance     = require('./_an-instance')\n  , toInteger      = require('./_to-integer')\n  , toLength       = require('./_to-length')\n  , gOPN           = require('./_object-gopn').f\n  , dP             = require('./_object-dp').f\n  , arrayFill      = require('./_array-fill')\n  , setToStringTag = require('./_set-to-string-tag')\n  , ARRAY_BUFFER   = 'ArrayBuffer'\n  , DATA_VIEW      = 'DataView'\n  , PROTOTYPE      = 'prototype'\n  , WRONG_LENGTH   = 'Wrong length!'\n  , WRONG_INDEX    = 'Wrong index!'\n  , $ArrayBuffer   = global[ARRAY_BUFFER]\n  , $DataView      = global[DATA_VIEW]\n  , Math           = global.Math\n  , RangeError     = global.RangeError\n  , Infinity       = global.Infinity\n  , BaseBuffer     = $ArrayBuffer\n  , abs            = Math.abs\n  , pow            = Math.pow\n  , floor          = Math.floor\n  , log            = Math.log\n  , LN2            = Math.LN2\n  , BUFFER         = 'buffer'\n  , BYTE_LENGTH    = 'byteLength'\n  , BYTE_OFFSET    = 'byteOffset'\n  , $BUFFER        = DESCRIPTORS ? '_b' : BUFFER\n  , $LENGTH        = DESCRIPTORS ? '_l' : BYTE_LENGTH\n  , $OFFSET        = DESCRIPTORS ? '_o' : BYTE_OFFSET;\n\n// IEEE754 conversions based on https://github.com/feross/ieee754\nvar packIEEE754 = function(value, mLen, nBytes){\n  var buffer = Array(nBytes)\n    , eLen   = nBytes * 8 - mLen - 1\n    , eMax   = (1 << eLen) - 1\n    , eBias  = eMax >> 1\n    , rt     = mLen === 23 ? pow(2, -24) - pow(2, -77) : 0\n    , i      = 0\n    , s      = value < 0 || value === 0 && 1 / value < 0 ? 1 : 0\n    , e, m, c;\n  value = abs(value)\n  if(value != value || value === Infinity){\n    m = value != value ? 1 : 0;\n    e = eMax;\n  } else {\n    e = floor(log(value) / LN2);\n    if(value * (c = pow(2, -e)) < 1){\n      e--;\n      c *= 2;\n    }\n    if(e + eBias >= 1){\n      value += rt / c;\n    } else {\n      value += rt * pow(2, 1 - eBias);\n    }\n    if(value * c >= 2){\n      e++;\n      c /= 2;\n    }\n    if(e + eBias >= eMax){\n      m = 0;\n      e = eMax;\n    } else if(e + eBias >= 1){\n      m = (value * c - 1) * pow(2, mLen);\n      e = e + eBias;\n    } else {\n      m = value * pow(2, eBias - 1) * pow(2, mLen);\n      e = 0;\n    }\n  }\n  for(; mLen >= 8; buffer[i++] = m & 255, m /= 256, mLen -= 8);\n  e = e << mLen | m;\n  eLen += mLen;\n  for(; eLen > 0; buffer[i++] = e & 255, e /= 256, eLen -= 8);\n  buffer[--i] |= s * 128;\n  return buffer;\n};\nvar unpackIEEE754 = function(buffer, mLen, nBytes){\n  var eLen  = nBytes * 8 - mLen - 1\n    , eMax  = (1 << eLen) - 1\n    , eBias = eMax >> 1\n    , nBits = eLen - 7\n    , i     = nBytes - 1\n    , s     = buffer[i--]\n    , e     = s & 127\n    , m;\n  s >>= 7;\n  for(; nBits > 0; e = e * 256 + buffer[i], i--, nBits -= 8);\n  m = e & (1 << -nBits) - 1;\n  e >>= -nBits;\n  nBits += mLen;\n  for(; nBits > 0; m = m * 256 + buffer[i], i--, nBits -= 8);\n  if(e === 0){\n    e = 1 - eBias;\n  } else if(e === eMax){\n    return m ? NaN : s ? -Infinity : Infinity;\n  } else {\n    m = m + pow(2, mLen);\n    e = e - eBias;\n  } return (s ? -1 : 1) * m * pow(2, e - mLen);\n};\n\nvar unpackI32 = function(bytes){\n  return bytes[3] << 24 | bytes[2] << 16 | bytes[1] << 8 | bytes[0];\n};\nvar packI8 = function(it){\n  return [it & 0xff];\n};\nvar packI16 = function(it){\n  return [it & 0xff, it >> 8 & 0xff];\n};\nvar packI32 = function(it){\n  return [it & 0xff, it >> 8 & 0xff, it >> 16 & 0xff, it >> 24 & 0xff];\n};\nvar packF64 = function(it){\n  return packIEEE754(it, 52, 8);\n};\nvar packF32 = function(it){\n  return packIEEE754(it, 23, 4);\n};\n\nvar addGetter = function(C, key, internal){\n  dP(C[PROTOTYPE], key, {get: function(){ return this[internal]; }});\n};\n\nvar get = function(view, bytes, index, isLittleEndian){\n  var numIndex = +index\n    , intIndex = toInteger(numIndex);\n  if(numIndex != intIndex || intIndex < 0 || intIndex + bytes > view[$LENGTH])throw RangeError(WRONG_INDEX);\n  var store = view[$BUFFER]._b\n    , start = intIndex + view[$OFFSET]\n    , pack  = store.slice(start, start + bytes);\n  return isLittleEndian ? pack : pack.reverse();\n};\nvar set = function(view, bytes, index, conversion, value, isLittleEndian){\n  var numIndex = +index\n    , intIndex = toInteger(numIndex);\n  if(numIndex != intIndex || intIndex < 0 || intIndex + bytes > view[$LENGTH])throw RangeError(WRONG_INDEX);\n  var store = view[$BUFFER]._b\n    , start = intIndex + view[$OFFSET]\n    , pack  = conversion(+value);\n  for(var i = 0; i < bytes; i++)store[start + i] = pack[isLittleEndian ? i : bytes - i - 1];\n};\n\nvar validateArrayBufferArguments = function(that, length){\n  anInstance(that, $ArrayBuffer, ARRAY_BUFFER);\n  var numberLength = +length\n    , byteLength   = toLength(numberLength);\n  if(numberLength != byteLength)throw RangeError(WRONG_LENGTH);\n  return byteLength;\n};\n\nif(!$typed.ABV){\n  $ArrayBuffer = function ArrayBuffer(length){\n    var byteLength = validateArrayBufferArguments(this, length);\n    this._b       = arrayFill.call(Array(byteLength), 0);\n    this[$LENGTH] = byteLength;\n  };\n\n  $DataView = function DataView(buffer, byteOffset, byteLength){\n    anInstance(this, $DataView, DATA_VIEW);\n    anInstance(buffer, $ArrayBuffer, DATA_VIEW);\n    var bufferLength = buffer[$LENGTH]\n      , offset       = toInteger(byteOffset);\n    if(offset < 0 || offset > bufferLength)throw RangeError('Wrong offset!');\n    byteLength = byteLength === undefined ? bufferLength - offset : toLength(byteLength);\n    if(offset + byteLength > bufferLength)throw RangeError(WRONG_LENGTH);\n    this[$BUFFER] = buffer;\n    this[$OFFSET] = offset;\n    this[$LENGTH] = byteLength;\n  };\n\n  if(DESCRIPTORS){\n    addGetter($ArrayBuffer, BYTE_LENGTH, '_l');\n    addGetter($DataView, BUFFER, '_b');\n    addGetter($DataView, BYTE_LENGTH, '_l');\n    addGetter($DataView, BYTE_OFFSET, '_o');\n  }\n\n  redefineAll($DataView[PROTOTYPE], {\n    getInt8: function getInt8(byteOffset){\n      return get(this, 1, byteOffset)[0] << 24 >> 24;\n    },\n    getUint8: function getUint8(byteOffset){\n      return get(this, 1, byteOffset)[0];\n    },\n    getInt16: function getInt16(byteOffset /*, littleEndian */){\n      var bytes = get(this, 2, byteOffset, arguments[1]);\n      return (bytes[1] << 8 | bytes[0]) << 16 >> 16;\n    },\n    getUint16: function getUint16(byteOffset /*, littleEndian */){\n      var bytes = get(this, 2, byteOffset, arguments[1]);\n      return bytes[1] << 8 | bytes[0];\n    },\n    getInt32: function getInt32(byteOffset /*, littleEndian */){\n      return unpackI32(get(this, 4, byteOffset, arguments[1]));\n    },\n    getUint32: function getUint32(byteOffset /*, littleEndian */){\n      return unpackI32(get(this, 4, byteOffset, arguments[1])) >>> 0;\n    },\n    getFloat32: function getFloat32(byteOffset /*, littleEndian */){\n      return unpackIEEE754(get(this, 4, byteOffset, arguments[1]), 23, 4);\n    },\n    getFloat64: function getFloat64(byteOffset /*, littleEndian */){\n      return unpackIEEE754(get(this, 8, byteOffset, arguments[1]), 52, 8);\n    },\n    setInt8: function setInt8(byteOffset, value){\n      set(this, 1, byteOffset, packI8, value);\n    },\n    setUint8: function setUint8(byteOffset, value){\n      set(this, 1, byteOffset, packI8, value);\n    },\n    setInt16: function setInt16(byteOffset, value /*, littleEndian */){\n      set(this, 2, byteOffset, packI16, value, arguments[2]);\n    },\n    setUint16: function setUint16(byteOffset, value /*, littleEndian */){\n      set(this, 2, byteOffset, packI16, value, arguments[2]);\n    },\n    setInt32: function setInt32(byteOffset, value /*, littleEndian */){\n      set(this, 4, byteOffset, packI32, value, arguments[2]);\n    },\n    setUint32: function setUint32(byteOffset, value /*, littleEndian */){\n      set(this, 4, byteOffset, packI32, value, arguments[2]);\n    },\n    setFloat32: function setFloat32(byteOffset, value /*, littleEndian */){\n      set(this, 4, byteOffset, packF32, value, arguments[2]);\n    },\n    setFloat64: function setFloat64(byteOffset, value /*, littleEndian */){\n      set(this, 8, byteOffset, packF64, value, arguments[2]);\n    }\n  });\n} else {\n  if(!fails(function(){\n    new $ArrayBuffer;     // eslint-disable-line no-new\n  }) || !fails(function(){\n    new $ArrayBuffer(.5); // eslint-disable-line no-new\n  })){\n    $ArrayBuffer = function ArrayBuffer(length){\n      return new BaseBuffer(validateArrayBufferArguments(this, length));\n    };\n    var ArrayBufferProto = $ArrayBuffer[PROTOTYPE] = BaseBuffer[PROTOTYPE];\n    for(var keys = gOPN(BaseBuffer), j = 0, key; keys.length > j; ){\n      if(!((key = keys[j++]) in $ArrayBuffer))hide($ArrayBuffer, key, BaseBuffer[key]);\n    };\n    if(!LIBRARY)ArrayBufferProto.constructor = $ArrayBuffer;\n  }\n  // iOS Safari 7.x bug\n  var view = new $DataView(new $ArrayBuffer(2))\n    , $setInt8 = $DataView[PROTOTYPE].setInt8;\n  view.setInt8(0, 2147483648);\n  view.setInt8(1, 2147483649);\n  if(view.getInt8(0) || !view.getInt8(1))redefineAll($DataView[PROTOTYPE], {\n    setInt8: function setInt8(byteOffset, value){\n      $setInt8.call(this, byteOffset, value << 24 >> 24);\n    },\n    setUint8: function setUint8(byteOffset, value){\n      $setInt8.call(this, byteOffset, value << 24 >> 24);\n    }\n  }, true);\n}\nsetToStringTag($ArrayBuffer, ARRAY_BUFFER);\nsetToStringTag($DataView, DATA_VIEW);\nhide($DataView[PROTOTYPE], $typed.VIEW, true);\nexports[ARRAY_BUFFER] = $ArrayBuffer;\nexports[DATA_VIEW] = $DataView;","deps":{"./_an-instance":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-instance.js","./_array-fill":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-fill.js","./_descriptors":"node_modules/babel-polyfill/node_modules/core-js/modules/_descriptors.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js","./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_hide":"node_modules/babel-polyfill/node_modules/core-js/modules/_hide.js","./_library":"node_modules/babel-polyfill/node_modules/core-js/modules/_library.js","./_object-dp":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dp.js","./_object-gopn":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopn.js","./_redefine-all":"node_modules/babel-polyfill/node_modules/core-js/modules/_redefine-all.js","./_set-to-string-tag":"node_modules/babel-polyfill/node_modules/core-js/modules/_set-to-string-tag.js","./_to-integer":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-integer.js","./_to-length":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-length.js","./_typed":"node_modules/babel-polyfill/node_modules/core-js/modules/_typed.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_typed.js","source":"var global = require('./_global')\n  , hide   = require('./_hide')\n  , uid    = require('./_uid')\n  , TYPED  = uid('typed_array')\n  , VIEW   = uid('view')\n  , ABV    = !!(global.ArrayBuffer && global.DataView)\n  , CONSTR = ABV\n  , i = 0, l = 9, Typed;\n\nvar TypedArrayConstructors = (\n  'Int8Array,Uint8Array,Uint8ClampedArray,Int16Array,Uint16Array,Int32Array,Uint32Array,Float32Array,Float64Array'\n).split(',');\n\nwhile(i < l){\n  if(Typed = global[TypedArrayConstructors[i++]]){\n    hide(Typed.prototype, TYPED, true);\n    hide(Typed.prototype, VIEW, true);\n  } else CONSTR = false;\n}\n\nmodule.exports = {\n  ABV:    ABV,\n  CONSTR: CONSTR,\n  TYPED:  TYPED,\n  VIEW:   VIEW\n};","deps":{"./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_hide":"node_modules/babel-polyfill/node_modules/core-js/modules/_hide.js","./_uid":"node_modules/babel-polyfill/node_modules/core-js/modules/_uid.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_uid.js","source":"var id = 0\n  , px = Math.random();\nmodule.exports = function(key){\n  return 'Symbol('.concat(key === undefined ? '' : key, ')_', (++id + px).toString(36));\n};","deps":{}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks-define.js","source":"var global         = require('./_global')\n  , core           = require('./_core')\n  , LIBRARY        = require('./_library')\n  , wksExt         = require('./_wks-ext')\n  , defineProperty = require('./_object-dp').f;\nmodule.exports = function(name){\n  var $Symbol = core.Symbol || (core.Symbol = LIBRARY ? {} : global.Symbol || {});\n  if(name.charAt(0) != '_' && !(name in $Symbol))defineProperty($Symbol, name, {value: wksExt.f(name)});\n};","deps":{"./_core":"node_modules/babel-polyfill/node_modules/core-js/modules/_core.js","./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_library":"node_modules/babel-polyfill/node_modules/core-js/modules/_library.js","./_object-dp":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dp.js","./_wks-ext":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks-ext.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks-ext.js","source":"exports.f = require('./_wks');","deps":{"./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js","source":"var store      = require('./_shared')('wks')\n  , uid        = require('./_uid')\n  , Symbol     = require('./_global').Symbol\n  , USE_SYMBOL = typeof Symbol == 'function';\n\nvar $exports = module.exports = function(name){\n  return store[name] || (store[name] =\n    USE_SYMBOL && Symbol[name] || (USE_SYMBOL ? Symbol : uid)('Symbol.' + name));\n};\n\n$exports.store = store;","deps":{"./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_shared":"node_modules/babel-polyfill/node_modules/core-js/modules/_shared.js","./_uid":"node_modules/babel-polyfill/node_modules/core-js/modules/_uid.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/core.get-iterator-method.js","source":"var classof   = require('./_classof')\n  , ITERATOR  = require('./_wks')('iterator')\n  , Iterators = require('./_iterators');\nmodule.exports = require('./_core').getIteratorMethod = function(it){\n  if(it != undefined)return it[ITERATOR]\n    || it['@@iterator']\n    || Iterators[classof(it)];\n};","deps":{"./_classof":"node_modules/babel-polyfill/node_modules/core-js/modules/_classof.js","./_core":"node_modules/babel-polyfill/node_modules/core-js/modules/_core.js","./_iterators":"node_modules/babel-polyfill/node_modules/core-js/modules/_iterators.js","./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/core.regexp.escape.js","source":"var $export = require('./_export')\n  , $re     = require('./_replacer')(/[\\\\^$*+?.()|[\\]{}]/g, '\\\\$&');\n\n$export($export.S, 'RegExp', {escape: function escape(it){ return $re(it); }});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_replacer":"node_modules/babel-polyfill/node_modules/core-js/modules/_replacer.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.copy-within.js","source":"var $export = require('./_export');\n\n$export($export.P, 'Array', {copyWithin: require('./_array-copy-within')});\n\nrequire('./_add-to-unscopables')('copyWithin');","deps":{"./_add-to-unscopables":"node_modules/babel-polyfill/node_modules/core-js/modules/_add-to-unscopables.js","./_array-copy-within":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-copy-within.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.every.js","source":"'use strict';\nvar $export = require('./_export')\n  , $every  = require('./_array-methods')(4);\n\n$export($export.P + $export.F * !require('./_strict-method')([].every, true), 'Array', {\n  // 22.1.3.5 / 15.4.4.16 Array.prototype.every(callbackfn [, thisArg])\n  every: function every(callbackfn /* , thisArg */){\n    return $every(this, callbackfn, arguments[1]);\n  }\n});","deps":{"./_array-methods":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-methods.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_strict-method":"node_modules/babel-polyfill/node_modules/core-js/modules/_strict-method.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.fill.js","source":"var $export = require('./_export');\n\n$export($export.P, 'Array', {fill: require('./_array-fill')});\n\nrequire('./_add-to-unscopables')('fill');","deps":{"./_add-to-unscopables":"node_modules/babel-polyfill/node_modules/core-js/modules/_add-to-unscopables.js","./_array-fill":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-fill.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.filter.js","source":"'use strict';\nvar $export = require('./_export')\n  , $filter = require('./_array-methods')(2);\n\n$export($export.P + $export.F * !require('./_strict-method')([].filter, true), 'Array', {\n  // 22.1.3.7 / 15.4.4.20 Array.prototype.filter(callbackfn [, thisArg])\n  filter: function filter(callbackfn /* , thisArg */){\n    return $filter(this, callbackfn, arguments[1]);\n  }\n});","deps":{"./_array-methods":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-methods.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_strict-method":"node_modules/babel-polyfill/node_modules/core-js/modules/_strict-method.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.find-index.js","source":"'use strict';\n// 22.1.3.9 Array.prototype.findIndex(predicate, thisArg = undefined)\nvar $export = require('./_export')\n  , $find   = require('./_array-methods')(6)\n  , KEY     = 'findIndex'\n  , forced  = true;\n// Shouldn't skip holes\nif(KEY in [])Array(1)[KEY](function(){ forced = false; });\n$export($export.P + $export.F * forced, 'Array', {\n  findIndex: function findIndex(callbackfn/*, that = undefined */){\n    return $find(this, callbackfn, arguments.length > 1 ? arguments[1] : undefined);\n  }\n});\nrequire('./_add-to-unscopables')(KEY);","deps":{"./_add-to-unscopables":"node_modules/babel-polyfill/node_modules/core-js/modules/_add-to-unscopables.js","./_array-methods":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-methods.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.find.js","source":"'use strict';\n// 22.1.3.8 Array.prototype.find(predicate, thisArg = undefined)\nvar $export = require('./_export')\n  , $find   = require('./_array-methods')(5)\n  , KEY     = 'find'\n  , forced  = true;\n// Shouldn't skip holes\nif(KEY in [])Array(1)[KEY](function(){ forced = false; });\n$export($export.P + $export.F * forced, 'Array', {\n  find: function find(callbackfn/*, that = undefined */){\n    return $find(this, callbackfn, arguments.length > 1 ? arguments[1] : undefined);\n  }\n});\nrequire('./_add-to-unscopables')(KEY);","deps":{"./_add-to-unscopables":"node_modules/babel-polyfill/node_modules/core-js/modules/_add-to-unscopables.js","./_array-methods":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-methods.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.for-each.js","source":"'use strict';\nvar $export  = require('./_export')\n  , $forEach = require('./_array-methods')(0)\n  , STRICT   = require('./_strict-method')([].forEach, true);\n\n$export($export.P + $export.F * !STRICT, 'Array', {\n  // 22.1.3.10 / 15.4.4.18 Array.prototype.forEach(callbackfn [, thisArg])\n  forEach: function forEach(callbackfn /* , thisArg */){\n    return $forEach(this, callbackfn, arguments[1]);\n  }\n});","deps":{"./_array-methods":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-methods.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_strict-method":"node_modules/babel-polyfill/node_modules/core-js/modules/_strict-method.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.from.js","source":"'use strict';\nvar ctx            = require('./_ctx')\n  , $export        = require('./_export')\n  , toObject       = require('./_to-object')\n  , call           = require('./_iter-call')\n  , isArrayIter    = require('./_is-array-iter')\n  , toLength       = require('./_to-length')\n  , createProperty = require('./_create-property')\n  , getIterFn      = require('./core.get-iterator-method');\n\n$export($export.S + $export.F * !require('./_iter-detect')(function(iter){ Array.from(iter); }), 'Array', {\n  // 22.1.2.1 Array.from(arrayLike, mapfn = undefined, thisArg = undefined)\n  from: function from(arrayLike/*, mapfn = undefined, thisArg = undefined*/){\n    var O       = toObject(arrayLike)\n      , C       = typeof this == 'function' ? this : Array\n      , aLen    = arguments.length\n      , mapfn   = aLen > 1 ? arguments[1] : undefined\n      , mapping = mapfn !== undefined\n      , index   = 0\n      , iterFn  = getIterFn(O)\n      , length, result, step, iterator;\n    if(mapping)mapfn = ctx(mapfn, aLen > 2 ? arguments[2] : undefined, 2);\n    // if object isn't iterable or it's array with default iterator - use simple case\n    if(iterFn != undefined && !(C == Array && isArrayIter(iterFn))){\n      for(iterator = iterFn.call(O), result = new C; !(step = iterator.next()).done; index++){\n        createProperty(result, index, mapping ? call(iterator, mapfn, [step.value, index], true) : step.value);\n      }\n    } else {\n      length = toLength(O.length);\n      for(result = new C(length); length > index; index++){\n        createProperty(result, index, mapping ? mapfn(O[index], index) : O[index]);\n      }\n    }\n    result.length = index;\n    return result;\n  }\n});","deps":{"./_create-property":"node_modules/babel-polyfill/node_modules/core-js/modules/_create-property.js","./_ctx":"node_modules/babel-polyfill/node_modules/core-js/modules/_ctx.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_is-array-iter":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-array-iter.js","./_iter-call":"node_modules/babel-polyfill/node_modules/core-js/modules/_iter-call.js","./_iter-detect":"node_modules/babel-polyfill/node_modules/core-js/modules/_iter-detect.js","./_to-length":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-length.js","./_to-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-object.js","./core.get-iterator-method":"node_modules/babel-polyfill/node_modules/core-js/modules/core.get-iterator-method.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.index-of.js","source":"'use strict';\nvar $export       = require('./_export')\n  , $indexOf      = require('./_array-includes')(false)\n  , $native       = [].indexOf\n  , NEGATIVE_ZERO = !!$native && 1 / [1].indexOf(1, -0) < 0;\n\n$export($export.P + $export.F * (NEGATIVE_ZERO || !require('./_strict-method')($native)), 'Array', {\n  // 22.1.3.11 / 15.4.4.14 Array.prototype.indexOf(searchElement [, fromIndex])\n  indexOf: function indexOf(searchElement /*, fromIndex = 0 */){\n    return NEGATIVE_ZERO\n      // convert -0 to +0\n      ? $native.apply(this, arguments) || 0\n      : $indexOf(this, searchElement, arguments[1]);\n  }\n});","deps":{"./_array-includes":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-includes.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_strict-method":"node_modules/babel-polyfill/node_modules/core-js/modules/_strict-method.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.is-array.js","source":"var $export = require('./_export');\n\n$export($export.S, 'Array', {isArray: require('./_is-array')});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_is-array":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-array.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.iterator.js","source":"'use strict';\nvar addToUnscopables = require('./_add-to-unscopables')\n  , step             = require('./_iter-step')\n  , Iterators        = require('./_iterators')\n  , toIObject        = require('./_to-iobject');\n\n// 22.1.3.4 Array.prototype.entries()\n// 22.1.3.13 Array.prototype.keys()\n// 22.1.3.29 Array.prototype.values()\n// 22.1.3.30 Array.prototype[@@iterator]()\nmodule.exports = require('./_iter-define')(Array, 'Array', function(iterated, kind){\n  this._t = toIObject(iterated); // target\n  this._i = 0;                   // next index\n  this._k = kind;                // kind\n// 22.1.5.2.1 %ArrayIteratorPrototype%.next()\n}, function(){\n  var O     = this._t\n    , kind  = this._k\n    , index = this._i++;\n  if(!O || index >= O.length){\n    this._t = undefined;\n    return step(1);\n  }\n  if(kind == 'keys'  )return step(0, index);\n  if(kind == 'values')return step(0, O[index]);\n  return step(0, [index, O[index]]);\n}, 'values');\n\n// argumentsList[@@iterator] is %ArrayProto_values% (9.4.4.6, 9.4.4.7)\nIterators.Arguments = Iterators.Array;\n\naddToUnscopables('keys');\naddToUnscopables('values');\naddToUnscopables('entries');","deps":{"./_add-to-unscopables":"node_modules/babel-polyfill/node_modules/core-js/modules/_add-to-unscopables.js","./_iter-define":"node_modules/babel-polyfill/node_modules/core-js/modules/_iter-define.js","./_iter-step":"node_modules/babel-polyfill/node_modules/core-js/modules/_iter-step.js","./_iterators":"node_modules/babel-polyfill/node_modules/core-js/modules/_iterators.js","./_to-iobject":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-iobject.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.join.js","source":"'use strict';\n// 22.1.3.13 Array.prototype.join(separator)\nvar $export   = require('./_export')\n  , toIObject = require('./_to-iobject')\n  , arrayJoin = [].join;\n\n// fallback for not array-like strings\n$export($export.P + $export.F * (require('./_iobject') != Object || !require('./_strict-method')(arrayJoin)), 'Array', {\n  join: function join(separator){\n    return arrayJoin.call(toIObject(this), separator === undefined ? ',' : separator);\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_iobject":"node_modules/babel-polyfill/node_modules/core-js/modules/_iobject.js","./_strict-method":"node_modules/babel-polyfill/node_modules/core-js/modules/_strict-method.js","./_to-iobject":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-iobject.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.last-index-of.js","source":"'use strict';\nvar $export       = require('./_export')\n  , toIObject     = require('./_to-iobject')\n  , toInteger     = require('./_to-integer')\n  , toLength      = require('./_to-length')\n  , $native       = [].lastIndexOf\n  , NEGATIVE_ZERO = !!$native && 1 / [1].lastIndexOf(1, -0) < 0;\n\n$export($export.P + $export.F * (NEGATIVE_ZERO || !require('./_strict-method')($native)), 'Array', {\n  // 22.1.3.14 / 15.4.4.15 Array.prototype.lastIndexOf(searchElement [, fromIndex])\n  lastIndexOf: function lastIndexOf(searchElement /*, fromIndex = @[*-1] */){\n    // convert -0 to +0\n    if(NEGATIVE_ZERO)return $native.apply(this, arguments) || 0;\n    var O      = toIObject(this)\n      , length = toLength(O.length)\n      , index  = length - 1;\n    if(arguments.length > 1)index = Math.min(index, toInteger(arguments[1]));\n    if(index < 0)index = length + index;\n    for(;index >= 0; index--)if(index in O)if(O[index] === searchElement)return index || 0;\n    return -1;\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_strict-method":"node_modules/babel-polyfill/node_modules/core-js/modules/_strict-method.js","./_to-integer":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-integer.js","./_to-iobject":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-iobject.js","./_to-length":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-length.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.map.js","source":"'use strict';\nvar $export = require('./_export')\n  , $map    = require('./_array-methods')(1);\n\n$export($export.P + $export.F * !require('./_strict-method')([].map, true), 'Array', {\n  // 22.1.3.15 / 15.4.4.19 Array.prototype.map(callbackfn [, thisArg])\n  map: function map(callbackfn /* , thisArg */){\n    return $map(this, callbackfn, arguments[1]);\n  }\n});","deps":{"./_array-methods":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-methods.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_strict-method":"node_modules/babel-polyfill/node_modules/core-js/modules/_strict-method.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.of.js","source":"'use strict';\nvar $export        = require('./_export')\n  , createProperty = require('./_create-property');\n\n// WebKit Array.of isn't generic\n$export($export.S + $export.F * require('./_fails')(function(){\n  function F(){}\n  return !(Array.of.call(F) instanceof F);\n}), 'Array', {\n  // 22.1.2.3 Array.of( ...items)\n  of: function of(/* ...args */){\n    var index  = 0\n      , aLen   = arguments.length\n      , result = new (typeof this == 'function' ? this : Array)(aLen);\n    while(aLen > index)createProperty(result, index, arguments[index++]);\n    result.length = aLen;\n    return result;\n  }\n});","deps":{"./_create-property":"node_modules/babel-polyfill/node_modules/core-js/modules/_create-property.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.reduce-right.js","source":"'use strict';\nvar $export = require('./_export')\n  , $reduce = require('./_array-reduce');\n\n$export($export.P + $export.F * !require('./_strict-method')([].reduceRight, true), 'Array', {\n  // 22.1.3.19 / 15.4.4.22 Array.prototype.reduceRight(callbackfn [, initialValue])\n  reduceRight: function reduceRight(callbackfn /* , initialValue */){\n    return $reduce(this, callbackfn, arguments.length, arguments[1], true);\n  }\n});","deps":{"./_array-reduce":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-reduce.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_strict-method":"node_modules/babel-polyfill/node_modules/core-js/modules/_strict-method.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.reduce.js","source":"'use strict';\nvar $export = require('./_export')\n  , $reduce = require('./_array-reduce');\n\n$export($export.P + $export.F * !require('./_strict-method')([].reduce, true), 'Array', {\n  // 22.1.3.18 / 15.4.4.21 Array.prototype.reduce(callbackfn [, initialValue])\n  reduce: function reduce(callbackfn /* , initialValue */){\n    return $reduce(this, callbackfn, arguments.length, arguments[1], false);\n  }\n});","deps":{"./_array-reduce":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-reduce.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_strict-method":"node_modules/babel-polyfill/node_modules/core-js/modules/_strict-method.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.slice.js","source":"'use strict';\nvar $export    = require('./_export')\n  , html       = require('./_html')\n  , cof        = require('./_cof')\n  , toIndex    = require('./_to-index')\n  , toLength   = require('./_to-length')\n  , arraySlice = [].slice;\n\n// fallback for not array-like ES3 strings and DOM objects\n$export($export.P + $export.F * require('./_fails')(function(){\n  if(html)arraySlice.call(html);\n}), 'Array', {\n  slice: function slice(begin, end){\n    var len   = toLength(this.length)\n      , klass = cof(this);\n    end = end === undefined ? len : end;\n    if(klass == 'Array')return arraySlice.call(this, begin, end);\n    var start  = toIndex(begin, len)\n      , upTo   = toIndex(end, len)\n      , size   = toLength(upTo - start)\n      , cloned = Array(size)\n      , i      = 0;\n    for(; i < size; i++)cloned[i] = klass == 'String'\n      ? this.charAt(start + i)\n      : this[start + i];\n    return cloned;\n  }\n});","deps":{"./_cof":"node_modules/babel-polyfill/node_modules/core-js/modules/_cof.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js","./_html":"node_modules/babel-polyfill/node_modules/core-js/modules/_html.js","./_to-index":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-index.js","./_to-length":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-length.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.some.js","source":"'use strict';\nvar $export = require('./_export')\n  , $some   = require('./_array-methods')(3);\n\n$export($export.P + $export.F * !require('./_strict-method')([].some, true), 'Array', {\n  // 22.1.3.23 / 15.4.4.17 Array.prototype.some(callbackfn [, thisArg])\n  some: function some(callbackfn /* , thisArg */){\n    return $some(this, callbackfn, arguments[1]);\n  }\n});","deps":{"./_array-methods":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-methods.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_strict-method":"node_modules/babel-polyfill/node_modules/core-js/modules/_strict-method.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.sort.js","source":"'use strict';\nvar $export   = require('./_export')\n  , aFunction = require('./_a-function')\n  , toObject  = require('./_to-object')\n  , fails     = require('./_fails')\n  , $sort     = [].sort\n  , test      = [1, 2, 3];\n\n$export($export.P + $export.F * (fails(function(){\n  // IE8-\n  test.sort(undefined);\n}) || !fails(function(){\n  // V8 bug\n  test.sort(null);\n  // Old WebKit\n}) || !require('./_strict-method')($sort)), 'Array', {\n  // 22.1.3.25 Array.prototype.sort(comparefn)\n  sort: function sort(comparefn){\n    return comparefn === undefined\n      ? $sort.call(toObject(this))\n      : $sort.call(toObject(this), aFunction(comparefn));\n  }\n});","deps":{"./_a-function":"node_modules/babel-polyfill/node_modules/core-js/modules/_a-function.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js","./_strict-method":"node_modules/babel-polyfill/node_modules/core-js/modules/_strict-method.js","./_to-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-object.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.species.js","source":"require('./_set-species')('Array');","deps":{"./_set-species":"node_modules/babel-polyfill/node_modules/core-js/modules/_set-species.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.date.now.js","source":"var $export = require('./_export');\n\n$export($export.S, 'Date', {now: function(){ return new Date().getTime(); }});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.date.to-iso-string.js","source":"'use strict';\n// 20.3.4.36 / 15.9.5.43 Date.prototype.toISOString()\nvar $export = require('./_export')\n  , fails   = require('./_fails')\n  , getTime = Date.prototype.getTime;\n\nvar lz = function(num){\n  return num > 9 ? num : '0' + num;\n};\n\n// PhantomJS / old WebKit has a broken implementations\n$export($export.P + $export.F * (fails(function(){\n  return new Date(-5e13 - 1).toISOString() != '0385-07-25T07:06:39.999Z';\n}) || !fails(function(){\n  new Date(NaN).toISOString();\n})), 'Date', {\n  toISOString: function toISOString(){\n    if(!isFinite(getTime.call(this)))throw RangeError('Invalid time value');\n    var d = this\n      , y = d.getUTCFullYear()\n      , m = d.getUTCMilliseconds()\n      , s = y < 0 ? '-' : y > 9999 ? '+' : '';\n    return s + ('00000' + Math.abs(y)).slice(s ? -6 : -4) +\n      '-' + lz(d.getUTCMonth() + 1) + '-' + lz(d.getUTCDate()) +\n      'T' + lz(d.getUTCHours()) + ':' + lz(d.getUTCMinutes()) +\n      ':' + lz(d.getUTCSeconds()) + '.' + (m > 99 ? m : '0' + lz(m)) + 'Z';\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.date.to-json.js","source":"'use strict';\nvar $export     = require('./_export')\n  , toObject    = require('./_to-object')\n  , toPrimitive = require('./_to-primitive');\n\n$export($export.P + $export.F * require('./_fails')(function(){\n  return new Date(NaN).toJSON() !== null || Date.prototype.toJSON.call({toISOString: function(){ return 1; }}) !== 1;\n}), 'Date', {\n  toJSON: function toJSON(key){\n    var O  = toObject(this)\n      , pv = toPrimitive(O);\n    return typeof pv == 'number' && !isFinite(pv) ? null : O.toISOString();\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js","./_to-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-object.js","./_to-primitive":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-primitive.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.date.to-primitive.js","source":"var TO_PRIMITIVE = require('./_wks')('toPrimitive')\n  , proto        = Date.prototype;\n\nif(!(TO_PRIMITIVE in proto))require('./_hide')(proto, TO_PRIMITIVE, require('./_date-to-primitive'));","deps":{"./_date-to-primitive":"node_modules/babel-polyfill/node_modules/core-js/modules/_date-to-primitive.js","./_hide":"node_modules/babel-polyfill/node_modules/core-js/modules/_hide.js","./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.date.to-string.js","source":"var DateProto    = Date.prototype\n  , INVALID_DATE = 'Invalid Date'\n  , TO_STRING    = 'toString'\n  , $toString    = DateProto[TO_STRING]\n  , getTime      = DateProto.getTime;\nif(new Date(NaN) + '' != INVALID_DATE){\n  require('./_redefine')(DateProto, TO_STRING, function toString(){\n    var value = getTime.call(this);\n    return value === value ? $toString.call(this) : INVALID_DATE;\n  });\n}","deps":{"./_redefine":"node_modules/babel-polyfill/node_modules/core-js/modules/_redefine.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.function.bind.js","source":"var $export = require('./_export');\n\n$export($export.P, 'Function', {bind: require('./_bind')});","deps":{"./_bind":"node_modules/babel-polyfill/node_modules/core-js/modules/_bind.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.function.has-instance.js","source":"'use strict';\nvar isObject       = require('./_is-object')\n  , getPrototypeOf = require('./_object-gpo')\n  , HAS_INSTANCE   = require('./_wks')('hasInstance')\n  , FunctionProto  = Function.prototype;\n// 19.2.3.6 Function.prototype[@@hasInstance](V)\nif(!(HAS_INSTANCE in FunctionProto))require('./_object-dp').f(FunctionProto, HAS_INSTANCE, {value: function(O){\n  if(typeof this != 'function' || !isObject(O))return false;\n  if(!isObject(this.prototype))return O instanceof this;\n  // for environment w/o native `@@hasInstance` logic enough `instanceof`, but add this:\n  while(O = getPrototypeOf(O))if(this.prototype === O)return true;\n  return false;\n}});","deps":{"./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js","./_object-dp":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dp.js","./_object-gpo":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gpo.js","./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.function.name.js","source":"var dP         = require('./_object-dp').f\n  , createDesc = require('./_property-desc')\n  , has        = require('./_has')\n  , FProto     = Function.prototype\n  , nameRE     = /^\\s*function ([^ (]*)/\n  , NAME       = 'name';\n\nvar isExtensible = Object.isExtensible || function(){\n  return true;\n};\n\n// 19.2.4.2 name\nNAME in FProto || require('./_descriptors') && dP(FProto, NAME, {\n  configurable: true,\n  get: function(){\n    try {\n      var that = this\n        , name = ('' + that).match(nameRE)[1];\n      has(that, NAME) || !isExtensible(that) || dP(that, NAME, createDesc(5, name));\n      return name;\n    } catch(e){\n      return '';\n    }\n  }\n});","deps":{"./_descriptors":"node_modules/babel-polyfill/node_modules/core-js/modules/_descriptors.js","./_has":"node_modules/babel-polyfill/node_modules/core-js/modules/_has.js","./_object-dp":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dp.js","./_property-desc":"node_modules/babel-polyfill/node_modules/core-js/modules/_property-desc.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.map.js","source":"'use strict';\nvar strong = require('./_collection-strong');\n\n// 23.1 Map Objects\nmodule.exports = require('./_collection')('Map', function(get){\n  return function Map(){ return get(this, arguments.length > 0 ? arguments[0] : undefined); };\n}, {\n  // 23.1.3.6 Map.prototype.get(key)\n  get: function get(key){\n    var entry = strong.getEntry(this, key);\n    return entry && entry.v;\n  },\n  // 23.1.3.9 Map.prototype.set(key, value)\n  set: function set(key, value){\n    return strong.def(this, key === 0 ? 0 : key, value);\n  }\n}, strong, true);","deps":{"./_collection":"node_modules/babel-polyfill/node_modules/core-js/modules/_collection.js","./_collection-strong":"node_modules/babel-polyfill/node_modules/core-js/modules/_collection-strong.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.acosh.js","source":"var $export = require('./_export')\n  , log1p   = require('./_math-log1p')\n  , sqrt    = Math.sqrt\n  , $acosh  = Math.acosh;\n\n$export($export.S + $export.F * !($acosh\n  // V8 bug: https://code.google.com/p/v8/issues/detail?id=3509\n  && Math.floor($acosh(Number.MAX_VALUE)) == 710\n  // Tor Browser bug: Math.acosh(Infinity) -> NaN \n  && $acosh(Infinity) == Infinity\n), 'Math', {\n  acosh: function acosh(x){\n    return (x = +x) < 1 ? NaN : x > 94906265.62425156\n      ? Math.log(x) + Math.LN2\n      : log1p(x - 1 + sqrt(x - 1) * sqrt(x + 1));\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_math-log1p":"node_modules/babel-polyfill/node_modules/core-js/modules/_math-log1p.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.asinh.js","source":"var $export = require('./_export')\n  , $asinh  = Math.asinh;\n\nfunction asinh(x){\n  return !isFinite(x = +x) || x == 0 ? x : x < 0 ? -asinh(-x) : Math.log(x + Math.sqrt(x * x + 1));\n}\n\n// Tor Browser bug: Math.asinh(0) -> -0 \n$export($export.S + $export.F * !($asinh && 1 / $asinh(0) > 0), 'Math', {asinh: asinh});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.atanh.js","source":"var $export = require('./_export')\n  , $atanh  = Math.atanh;\n\n// Tor Browser bug: Math.atanh(-0) -> 0 \n$export($export.S + $export.F * !($atanh && 1 / $atanh(-0) < 0), 'Math', {\n  atanh: function atanh(x){\n    return (x = +x) == 0 ? x : Math.log((1 + x) / (1 - x)) / 2;\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.cbrt.js","source":"var $export = require('./_export')\n  , sign    = require('./_math-sign');\n\n$export($export.S, 'Math', {\n  cbrt: function cbrt(x){\n    return sign(x = +x) * Math.pow(Math.abs(x), 1 / 3);\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_math-sign":"node_modules/babel-polyfill/node_modules/core-js/modules/_math-sign.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.clz32.js","source":"var $export = require('./_export');\n\n$export($export.S, 'Math', {\n  clz32: function clz32(x){\n    return (x >>>= 0) ? 31 - Math.floor(Math.log(x + 0.5) * Math.LOG2E) : 32;\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.cosh.js","source":"var $export = require('./_export')\n  , exp     = Math.exp;\n\n$export($export.S, 'Math', {\n  cosh: function cosh(x){\n    return (exp(x = +x) + exp(-x)) / 2;\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.expm1.js","source":"var $export = require('./_export')\n  , $expm1  = require('./_math-expm1');\n\n$export($export.S + $export.F * ($expm1 != Math.expm1), 'Math', {expm1: $expm1});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_math-expm1":"node_modules/babel-polyfill/node_modules/core-js/modules/_math-expm1.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.fround.js","source":"var $export   = require('./_export')\n  , sign      = require('./_math-sign')\n  , pow       = Math.pow\n  , EPSILON   = pow(2, -52)\n  , EPSILON32 = pow(2, -23)\n  , MAX32     = pow(2, 127) * (2 - EPSILON32)\n  , MIN32     = pow(2, -126);\n\nvar roundTiesToEven = function(n){\n  return n + 1 / EPSILON - 1 / EPSILON;\n};\n\n\n$export($export.S, 'Math', {\n  fround: function fround(x){\n    var $abs  = Math.abs(x)\n      , $sign = sign(x)\n      , a, result;\n    if($abs < MIN32)return $sign * roundTiesToEven($abs / MIN32 / EPSILON32) * MIN32 * EPSILON32;\n    a = (1 + EPSILON32 / EPSILON) * $abs;\n    result = a - (a - $abs);\n    if(result > MAX32 || result != result)return $sign * Infinity;\n    return $sign * result;\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_math-sign":"node_modules/babel-polyfill/node_modules/core-js/modules/_math-sign.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.hypot.js","source":"var $export = require('./_export')\n  , abs     = Math.abs;\n\n$export($export.S, 'Math', {\n  hypot: function hypot(value1, value2){ // eslint-disable-line no-unused-vars\n    var sum  = 0\n      , i    = 0\n      , aLen = arguments.length\n      , larg = 0\n      , arg, div;\n    while(i < aLen){\n      arg = abs(arguments[i++]);\n      if(larg < arg){\n        div  = larg / arg;\n        sum  = sum * div * div + 1;\n        larg = arg;\n      } else if(arg > 0){\n        div  = arg / larg;\n        sum += div * div;\n      } else sum += arg;\n    }\n    return larg === Infinity ? Infinity : larg * Math.sqrt(sum);\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.imul.js","source":"var $export = require('./_export')\n  , $imul   = Math.imul;\n\n// some WebKit versions fails with big numbers, some has wrong arity\n$export($export.S + $export.F * require('./_fails')(function(){\n  return $imul(0xffffffff, 5) != -5 || $imul.length != 2;\n}), 'Math', {\n  imul: function imul(x, y){\n    var UINT16 = 0xffff\n      , xn = +x\n      , yn = +y\n      , xl = UINT16 & xn\n      , yl = UINT16 & yn;\n    return 0 | xl * yl + ((UINT16 & xn >>> 16) * yl + xl * (UINT16 & yn >>> 16) << 16 >>> 0);\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.log10.js","source":"var $export = require('./_export');\n\n$export($export.S, 'Math', {\n  log10: function log10(x){\n    return Math.log(x) / Math.LN10;\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.log1p.js","source":"var $export = require('./_export');\n\n$export($export.S, 'Math', {log1p: require('./_math-log1p')});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_math-log1p":"node_modules/babel-polyfill/node_modules/core-js/modules/_math-log1p.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.log2.js","source":"var $export = require('./_export');\n\n$export($export.S, 'Math', {\n  log2: function log2(x){\n    return Math.log(x) / Math.LN2;\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.sign.js","source":"var $export = require('./_export');\n\n$export($export.S, 'Math', {sign: require('./_math-sign')});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_math-sign":"node_modules/babel-polyfill/node_modules/core-js/modules/_math-sign.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.sinh.js","source":"var $export = require('./_export')\n  , expm1   = require('./_math-expm1')\n  , exp     = Math.exp;\n\n// V8 near Chromium 38 has a problem with very small numbers\n$export($export.S + $export.F * require('./_fails')(function(){\n  return !Math.sinh(-2e-17) != -2e-17;\n}), 'Math', {\n  sinh: function sinh(x){\n    return Math.abs(x = +x) < 1\n      ? (expm1(x) - expm1(-x)) / 2\n      : (exp(x - 1) - exp(-x - 1)) * (Math.E / 2);\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js","./_math-expm1":"node_modules/babel-polyfill/node_modules/core-js/modules/_math-expm1.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.tanh.js","source":"var $export = require('./_export')\n  , expm1   = require('./_math-expm1')\n  , exp     = Math.exp;\n\n$export($export.S, 'Math', {\n  tanh: function tanh(x){\n    var a = expm1(x = +x)\n      , b = expm1(-x);\n    return a == Infinity ? 1 : b == Infinity ? -1 : (a - b) / (exp(x) + exp(-x));\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_math-expm1":"node_modules/babel-polyfill/node_modules/core-js/modules/_math-expm1.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.trunc.js","source":"var $export = require('./_export');\n\n$export($export.S, 'Math', {\n  trunc: function trunc(it){\n    return (it > 0 ? Math.floor : Math.ceil)(it);\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.constructor.js","source":"'use strict';\nvar global            = require('./_global')\n  , has               = require('./_has')\n  , cof               = require('./_cof')\n  , inheritIfRequired = require('./_inherit-if-required')\n  , toPrimitive       = require('./_to-primitive')\n  , fails             = require('./_fails')\n  , gOPN              = require('./_object-gopn').f\n  , gOPD              = require('./_object-gopd').f\n  , dP                = require('./_object-dp').f\n  , $trim             = require('./_string-trim').trim\n  , NUMBER            = 'Number'\n  , $Number           = global[NUMBER]\n  , Base              = $Number\n  , proto             = $Number.prototype\n  // Opera ~12 has broken Object#toString\n  , BROKEN_COF        = cof(require('./_object-create')(proto)) == NUMBER\n  , TRIM              = 'trim' in String.prototype;\n\n// 7.1.3 ToNumber(argument)\nvar toNumber = function(argument){\n  var it = toPrimitive(argument, false);\n  if(typeof it == 'string' && it.length > 2){\n    it = TRIM ? it.trim() : $trim(it, 3);\n    var first = it.charCodeAt(0)\n      , third, radix, maxCode;\n    if(first === 43 || first === 45){\n      third = it.charCodeAt(2);\n      if(third === 88 || third === 120)return NaN; // Number('+0x1') should be NaN, old V8 fix\n    } else if(first === 48){\n      switch(it.charCodeAt(1)){\n        case 66 : case 98  : radix = 2; maxCode = 49; break; // fast equal /^0b[01]+$/i\n        case 79 : case 111 : radix = 8; maxCode = 55; break; // fast equal /^0o[0-7]+$/i\n        default : return +it;\n      }\n      for(var digits = it.slice(2), i = 0, l = digits.length, code; i < l; i++){\n        code = digits.charCodeAt(i);\n        // parseInt parses a string to a first unavailable symbol\n        // but ToNumber should return NaN if a string contains unavailable symbols\n        if(code < 48 || code > maxCode)return NaN;\n      } return parseInt(digits, radix);\n    }\n  } return +it;\n};\n\nif(!$Number(' 0o1') || !$Number('0b1') || $Number('+0x1')){\n  $Number = function Number(value){\n    var it = arguments.length < 1 ? 0 : value\n      , that = this;\n    return that instanceof $Number\n      // check on 1..constructor(foo) case\n      && (BROKEN_COF ? fails(function(){ proto.valueOf.call(that); }) : cof(that) != NUMBER)\n        ? inheritIfRequired(new Base(toNumber(it)), that, $Number) : toNumber(it);\n  };\n  for(var keys = require('./_descriptors') ? gOPN(Base) : (\n    // ES3:\n    'MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,' +\n    // ES6 (in case, if modules with ES6 Number statics required before):\n    'EPSILON,isFinite,isInteger,isNaN,isSafeInteger,MAX_SAFE_INTEGER,' +\n    'MIN_SAFE_INTEGER,parseFloat,parseInt,isInteger'\n  ).split(','), j = 0, key; keys.length > j; j++){\n    if(has(Base, key = keys[j]) && !has($Number, key)){\n      dP($Number, key, gOPD(Base, key));\n    }\n  }\n  $Number.prototype = proto;\n  proto.constructor = $Number;\n  require('./_redefine')(global, NUMBER, $Number);\n}","deps":{"./_cof":"node_modules/babel-polyfill/node_modules/core-js/modules/_cof.js","./_descriptors":"node_modules/babel-polyfill/node_modules/core-js/modules/_descriptors.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js","./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_has":"node_modules/babel-polyfill/node_modules/core-js/modules/_has.js","./_inherit-if-required":"node_modules/babel-polyfill/node_modules/core-js/modules/_inherit-if-required.js","./_object-create":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-create.js","./_object-dp":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dp.js","./_object-gopd":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopd.js","./_object-gopn":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopn.js","./_redefine":"node_modules/babel-polyfill/node_modules/core-js/modules/_redefine.js","./_string-trim":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-trim.js","./_to-primitive":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-primitive.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.epsilon.js","source":"var $export = require('./_export');\n\n$export($export.S, 'Number', {EPSILON: Math.pow(2, -52)});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.is-finite.js","source":"var $export   = require('./_export')\n  , _isFinite = require('./_global').isFinite;\n\n$export($export.S, 'Number', {\n  isFinite: function isFinite(it){\n    return typeof it == 'number' && _isFinite(it);\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.is-integer.js","source":"var $export = require('./_export');\n\n$export($export.S, 'Number', {isInteger: require('./_is-integer')});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_is-integer":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-integer.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.is-nan.js","source":"var $export = require('./_export');\n\n$export($export.S, 'Number', {\n  isNaN: function isNaN(number){\n    return number != number;\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.is-safe-integer.js","source":"var $export   = require('./_export')\n  , isInteger = require('./_is-integer')\n  , abs       = Math.abs;\n\n$export($export.S, 'Number', {\n  isSafeInteger: function isSafeInteger(number){\n    return isInteger(number) && abs(number) <= 0x1fffffffffffff;\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_is-integer":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-integer.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.max-safe-integer.js","source":"var $export = require('./_export');\n\n$export($export.S, 'Number', {MAX_SAFE_INTEGER: 0x1fffffffffffff});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.min-safe-integer.js","source":"var $export = require('./_export');\n\n$export($export.S, 'Number', {MIN_SAFE_INTEGER: -0x1fffffffffffff});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.parse-float.js","source":"var $export     = require('./_export')\n  , $parseFloat = require('./_parse-float');\n// 20.1.2.12 Number.parseFloat(string)\n$export($export.S + $export.F * (Number.parseFloat != $parseFloat), 'Number', {parseFloat: $parseFloat});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_parse-float":"node_modules/babel-polyfill/node_modules/core-js/modules/_parse-float.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.parse-int.js","source":"var $export   = require('./_export')\n  , $parseInt = require('./_parse-int');\n// 20.1.2.13 Number.parseInt(string, radix)\n$export($export.S + $export.F * (Number.parseInt != $parseInt), 'Number', {parseInt: $parseInt});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_parse-int":"node_modules/babel-polyfill/node_modules/core-js/modules/_parse-int.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.to-fixed.js","source":"'use strict';\nvar $export      = require('./_export')\n  , toInteger    = require('./_to-integer')\n  , aNumberValue = require('./_a-number-value')\n  , repeat       = require('./_string-repeat')\n  , $toFixed     = 1..toFixed\n  , floor        = Math.floor\n  , data         = [0, 0, 0, 0, 0, 0]\n  , ERROR        = 'Number.toFixed: incorrect invocation!'\n  , ZERO         = '0';\n\nvar multiply = function(n, c){\n  var i  = -1\n    , c2 = c;\n  while(++i < 6){\n    c2 += n * data[i];\n    data[i] = c2 % 1e7;\n    c2 = floor(c2 / 1e7);\n  }\n};\nvar divide = function(n){\n  var i = 6\n    , c = 0;\n  while(--i >= 0){\n    c += data[i];\n    data[i] = floor(c / n);\n    c = (c % n) * 1e7;\n  }\n};\nvar numToString = function(){\n  var i = 6\n    , s = '';\n  while(--i >= 0){\n    if(s !== '' || i === 0 || data[i] !== 0){\n      var t = String(data[i]);\n      s = s === '' ? t : s + repeat.call(ZERO, 7 - t.length) + t;\n    }\n  } return s;\n};\nvar pow = function(x, n, acc){\n  return n === 0 ? acc : n % 2 === 1 ? pow(x, n - 1, acc * x) : pow(x * x, n / 2, acc);\n};\nvar log = function(x){\n  var n  = 0\n    , x2 = x;\n  while(x2 >= 4096){\n    n += 12;\n    x2 /= 4096;\n  }\n  while(x2 >= 2){\n    n  += 1;\n    x2 /= 2;\n  } return n;\n};\n\n$export($export.P + $export.F * (!!$toFixed && (\n  0.00008.toFixed(3) !== '0.000' ||\n  0.9.toFixed(0) !== '1' ||\n  1.255.toFixed(2) !== '1.25' ||\n  1000000000000000128..toFixed(0) !== '1000000000000000128'\n) || !require('./_fails')(function(){\n  // V8 ~ Android 4.3-\n  $toFixed.call({});\n})), 'Number', {\n  toFixed: function toFixed(fractionDigits){\n    var x = aNumberValue(this, ERROR)\n      , f = toInteger(fractionDigits)\n      , s = ''\n      , m = ZERO\n      , e, z, j, k;\n    if(f < 0 || f > 20)throw RangeError(ERROR);\n    if(x != x)return 'NaN';\n    if(x <= -1e21 || x >= 1e21)return String(x);\n    if(x < 0){\n      s = '-';\n      x = -x;\n    }\n    if(x > 1e-21){\n      e = log(x * pow(2, 69, 1)) - 69;\n      z = e < 0 ? x * pow(2, -e, 1) : x / pow(2, e, 1);\n      z *= 0x10000000000000;\n      e = 52 - e;\n      if(e > 0){\n        multiply(0, z);\n        j = f;\n        while(j >= 7){\n          multiply(1e7, 0);\n          j -= 7;\n        }\n        multiply(pow(10, j, 1), 0);\n        j = e - 1;\n        while(j >= 23){\n          divide(1 << 23);\n          j -= 23;\n        }\n        divide(1 << j);\n        multiply(1, 1);\n        divide(2);\n        m = numToString();\n      } else {\n        multiply(0, z);\n        multiply(1 << -e, 0);\n        m = numToString() + repeat.call(ZERO, f);\n      }\n    }\n    if(f > 0){\n      k = m.length;\n      m = s + (k <= f ? '0.' + repeat.call(ZERO, f - k) + m : m.slice(0, k - f) + '.' + m.slice(k - f));\n    } else {\n      m = s + m;\n    } return m;\n  }\n});","deps":{"./_a-number-value":"node_modules/babel-polyfill/node_modules/core-js/modules/_a-number-value.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js","./_string-repeat":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-repeat.js","./_to-integer":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-integer.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.to-precision.js","source":"'use strict';\nvar $export      = require('./_export')\n  , $fails       = require('./_fails')\n  , aNumberValue = require('./_a-number-value')\n  , $toPrecision = 1..toPrecision;\n\n$export($export.P + $export.F * ($fails(function(){\n  // IE7-\n  return $toPrecision.call(1, undefined) !== '1';\n}) || !$fails(function(){\n  // V8 ~ Android 4.3-\n  $toPrecision.call({});\n})), 'Number', {\n  toPrecision: function toPrecision(precision){\n    var that = aNumberValue(this, 'Number#toPrecision: incorrect invocation!');\n    return precision === undefined ? $toPrecision.call(that) : $toPrecision.call(that, precision); \n  }\n});","deps":{"./_a-number-value":"node_modules/babel-polyfill/node_modules/core-js/modules/_a-number-value.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.assign.js","source":"var $export = require('./_export');\n\n$export($export.S + $export.F, 'Object', {assign: require('./_object-assign')});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_object-assign":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-assign.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.create.js","source":"var $export = require('./_export')\n// 19.1.2.2 / 15.2.3.5 Object.create(O [, Properties])\n$export($export.S, 'Object', {create: require('./_object-create')});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_object-create":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-create.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.define-properties.js","source":"var $export = require('./_export');\n// 19.1.2.3 / 15.2.3.7 Object.defineProperties(O, Properties)\n$export($export.S + $export.F * !require('./_descriptors'), 'Object', {defineProperties: require('./_object-dps')});","deps":{"./_descriptors":"node_modules/babel-polyfill/node_modules/core-js/modules/_descriptors.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_object-dps":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dps.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.define-property.js","source":"var $export = require('./_export');\n// 19.1.2.4 / 15.2.3.6 Object.defineProperty(O, P, Attributes)\n$export($export.S + $export.F * !require('./_descriptors'), 'Object', {defineProperty: require('./_object-dp').f});","deps":{"./_descriptors":"node_modules/babel-polyfill/node_modules/core-js/modules/_descriptors.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_object-dp":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dp.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.freeze.js","source":"var isObject = require('./_is-object')\n  , meta     = require('./_meta').onFreeze;\n\nrequire('./_object-sap')('freeze', function($freeze){\n  return function freeze(it){\n    return $freeze && isObject(it) ? $freeze(meta(it)) : it;\n  };\n});","deps":{"./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js","./_meta":"node_modules/babel-polyfill/node_modules/core-js/modules/_meta.js","./_object-sap":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-sap.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.get-own-property-descriptor.js","source":"var toIObject                 = require('./_to-iobject')\n  , $getOwnPropertyDescriptor = require('./_object-gopd').f;\n\nrequire('./_object-sap')('getOwnPropertyDescriptor', function(){\n  return function getOwnPropertyDescriptor(it, key){\n    return $getOwnPropertyDescriptor(toIObject(it), key);\n  };\n});","deps":{"./_object-gopd":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopd.js","./_object-sap":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-sap.js","./_to-iobject":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-iobject.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.get-own-property-names.js","source":"require('./_object-sap')('getOwnPropertyNames', function(){\n  return require('./_object-gopn-ext').f;\n});","deps":{"./_object-gopn-ext":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopn-ext.js","./_object-sap":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-sap.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.get-prototype-of.js","source":"var toObject        = require('./_to-object')\n  , $getPrototypeOf = require('./_object-gpo');\n\nrequire('./_object-sap')('getPrototypeOf', function(){\n  return function getPrototypeOf(it){\n    return $getPrototypeOf(toObject(it));\n  };\n});","deps":{"./_object-gpo":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gpo.js","./_object-sap":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-sap.js","./_to-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-object.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.is-extensible.js","source":"var isObject = require('./_is-object');\n\nrequire('./_object-sap')('isExtensible', function($isExtensible){\n  return function isExtensible(it){\n    return isObject(it) ? $isExtensible ? $isExtensible(it) : true : false;\n  };\n});","deps":{"./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js","./_object-sap":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-sap.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.is-frozen.js","source":"var isObject = require('./_is-object');\n\nrequire('./_object-sap')('isFrozen', function($isFrozen){\n  return function isFrozen(it){\n    return isObject(it) ? $isFrozen ? $isFrozen(it) : false : true;\n  };\n});","deps":{"./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js","./_object-sap":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-sap.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.is-sealed.js","source":"var isObject = require('./_is-object');\n\nrequire('./_object-sap')('isSealed', function($isSealed){\n  return function isSealed(it){\n    return isObject(it) ? $isSealed ? $isSealed(it) : false : true;\n  };\n});","deps":{"./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js","./_object-sap":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-sap.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.is.js","source":"var $export = require('./_export');\n$export($export.S, 'Object', {is: require('./_same-value')});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_same-value":"node_modules/babel-polyfill/node_modules/core-js/modules/_same-value.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.keys.js","source":"var toObject = require('./_to-object')\n  , $keys    = require('./_object-keys');\n\nrequire('./_object-sap')('keys', function(){\n  return function keys(it){\n    return $keys(toObject(it));\n  };\n});","deps":{"./_object-keys":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-keys.js","./_object-sap":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-sap.js","./_to-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-object.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.prevent-extensions.js","source":"var isObject = require('./_is-object')\n  , meta     = require('./_meta').onFreeze;\n\nrequire('./_object-sap')('preventExtensions', function($preventExtensions){\n  return function preventExtensions(it){\n    return $preventExtensions && isObject(it) ? $preventExtensions(meta(it)) : it;\n  };\n});","deps":{"./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js","./_meta":"node_modules/babel-polyfill/node_modules/core-js/modules/_meta.js","./_object-sap":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-sap.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.seal.js","source":"var isObject = require('./_is-object')\n  , meta     = require('./_meta').onFreeze;\n\nrequire('./_object-sap')('seal', function($seal){\n  return function seal(it){\n    return $seal && isObject(it) ? $seal(meta(it)) : it;\n  };\n});","deps":{"./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js","./_meta":"node_modules/babel-polyfill/node_modules/core-js/modules/_meta.js","./_object-sap":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-sap.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.set-prototype-of.js","source":"var $export = require('./_export');\n$export($export.S, 'Object', {setPrototypeOf: require('./_set-proto').set});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_set-proto":"node_modules/babel-polyfill/node_modules/core-js/modules/_set-proto.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.to-string.js","source":"'use strict';\n// 19.1.3.6 Object.prototype.toString()\nvar classof = require('./_classof')\n  , test    = {};\ntest[require('./_wks')('toStringTag')] = 'z';\nif(test + '' != '[object z]'){\n  require('./_redefine')(Object.prototype, 'toString', function toString(){\n    return '[object ' + classof(this) + ']';\n  }, true);\n}","deps":{"./_classof":"node_modules/babel-polyfill/node_modules/core-js/modules/_classof.js","./_redefine":"node_modules/babel-polyfill/node_modules/core-js/modules/_redefine.js","./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.parse-float.js","source":"var $export     = require('./_export')\n  , $parseFloat = require('./_parse-float');\n// 18.2.4 parseFloat(string)\n$export($export.G + $export.F * (parseFloat != $parseFloat), {parseFloat: $parseFloat});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_parse-float":"node_modules/babel-polyfill/node_modules/core-js/modules/_parse-float.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.parse-int.js","source":"var $export   = require('./_export')\n  , $parseInt = require('./_parse-int');\n// 18.2.5 parseInt(string, radix)\n$export($export.G + $export.F * (parseInt != $parseInt), {parseInt: $parseInt});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_parse-int":"node_modules/babel-polyfill/node_modules/core-js/modules/_parse-int.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.promise.js","source":"'use strict';\nvar LIBRARY            = require('./_library')\n  , global             = require('./_global')\n  , ctx                = require('./_ctx')\n  , classof            = require('./_classof')\n  , $export            = require('./_export')\n  , isObject           = require('./_is-object')\n  , aFunction          = require('./_a-function')\n  , anInstance         = require('./_an-instance')\n  , forOf              = require('./_for-of')\n  , speciesConstructor = require('./_species-constructor')\n  , task               = require('./_task').set\n  , microtask          = require('./_microtask')()\n  , PROMISE            = 'Promise'\n  , TypeError          = global.TypeError\n  , process            = global.process\n  , $Promise           = global[PROMISE]\n  , process            = global.process\n  , isNode             = classof(process) == 'process'\n  , empty              = function(){ /* empty */ }\n  , Internal, GenericPromiseCapability, Wrapper;\n\nvar USE_NATIVE = !!function(){\n  try {\n    // correct subclassing with @@species support\n    var promise     = $Promise.resolve(1)\n      , FakePromise = (promise.constructor = {})[require('./_wks')('species')] = function(exec){ exec(empty, empty); };\n    // unhandled rejections tracking support, NodeJS Promise without it fails @@species test\n    return (isNode || typeof PromiseRejectionEvent == 'function') && promise.then(empty) instanceof FakePromise;\n  } catch(e){ /* empty */ }\n}();\n\n// helpers\nvar sameConstructor = function(a, b){\n  // with library wrapper special case\n  return a === b || a === $Promise && b === Wrapper;\n};\nvar isThenable = function(it){\n  var then;\n  return isObject(it) && typeof (then = it.then) == 'function' ? then : false;\n};\nvar newPromiseCapability = function(C){\n  return sameConstructor($Promise, C)\n    ? new PromiseCapability(C)\n    : new GenericPromiseCapability(C);\n};\nvar PromiseCapability = GenericPromiseCapability = function(C){\n  var resolve, reject;\n  this.promise = new C(function($$resolve, $$reject){\n    if(resolve !== undefined || reject !== undefined)throw TypeError('Bad Promise constructor');\n    resolve = $$resolve;\n    reject  = $$reject;\n  });\n  this.resolve = aFunction(resolve);\n  this.reject  = aFunction(reject);\n};\nvar perform = function(exec){\n  try {\n    exec();\n  } catch(e){\n    return {error: e};\n  }\n};\nvar notify = function(promise, isReject){\n  if(promise._n)return;\n  promise._n = true;\n  var chain = promise._c;\n  microtask(function(){\n    var value = promise._v\n      , ok    = promise._s == 1\n      , i     = 0;\n    var run = function(reaction){\n      var handler = ok ? reaction.ok : reaction.fail\n        , resolve = reaction.resolve\n        , reject  = reaction.reject\n        , domain  = reaction.domain\n        , result, then;\n      try {\n        if(handler){\n          if(!ok){\n            if(promise._h == 2)onHandleUnhandled(promise);\n            promise._h = 1;\n          }\n          if(handler === true)result = value;\n          else {\n            if(domain)domain.enter();\n            result = handler(value);\n            if(domain)domain.exit();\n          }\n          if(result === reaction.promise){\n            reject(TypeError('Promise-chain cycle'));\n          } else if(then = isThenable(result)){\n            then.call(result, resolve, reject);\n          } else resolve(result);\n        } else reject(value);\n      } catch(e){\n        reject(e);\n      }\n    };\n    while(chain.length > i)run(chain[i++]); // variable length - can't use forEach\n    promise._c = [];\n    promise._n = false;\n    if(isReject && !promise._h)onUnhandled(promise);\n  });\n};\nvar onUnhandled = function(promise){\n  task.call(global, function(){\n    var value = promise._v\n      , abrupt, handler, console;\n    if(isUnhandled(promise)){\n      abrupt = perform(function(){\n        if(isNode){\n          process.emit('unhandledRejection', value, promise);\n        } else if(handler = global.onunhandledrejection){\n          handler({promise: promise, reason: value});\n        } else if((console = global.console) && console.error){\n          console.error('Unhandled promise rejection', value);\n        }\n      });\n      // Browsers should not trigger `rejectionHandled` event if it was handled here, NodeJS - should\n      promise._h = isNode || isUnhandled(promise) ? 2 : 1;\n    } promise._a = undefined;\n    if(abrupt)throw abrupt.error;\n  });\n};\nvar isUnhandled = function(promise){\n  if(promise._h == 1)return false;\n  var chain = promise._a || promise._c\n    , i     = 0\n    , reaction;\n  while(chain.length > i){\n    reaction = chain[i++];\n    if(reaction.fail || !isUnhandled(reaction.promise))return false;\n  } return true;\n};\nvar onHandleUnhandled = function(promise){\n  task.call(global, function(){\n    var handler;\n    if(isNode){\n      process.emit('rejectionHandled', promise);\n    } else if(handler = global.onrejectionhandled){\n      handler({promise: promise, reason: promise._v});\n    }\n  });\n};\nvar $reject = function(value){\n  var promise = this;\n  if(promise._d)return;\n  promise._d = true;\n  promise = promise._w || promise; // unwrap\n  promise._v = value;\n  promise._s = 2;\n  if(!promise._a)promise._a = promise._c.slice();\n  notify(promise, true);\n};\nvar $resolve = function(value){\n  var promise = this\n    , then;\n  if(promise._d)return;\n  promise._d = true;\n  promise = promise._w || promise; // unwrap\n  try {\n    if(promise === value)throw TypeError(\"Promise can't be resolved itself\");\n    if(then = isThenable(value)){\n      microtask(function(){\n        var wrapper = {_w: promise, _d: false}; // wrap\n        try {\n          then.call(value, ctx($resolve, wrapper, 1), ctx($reject, wrapper, 1));\n        } catch(e){\n          $reject.call(wrapper, e);\n        }\n      });\n    } else {\n      promise._v = value;\n      promise._s = 1;\n      notify(promise, false);\n    }\n  } catch(e){\n    $reject.call({_w: promise, _d: false}, e); // wrap\n  }\n};\n\n// constructor polyfill\nif(!USE_NATIVE){\n  // 25.4.3.1 Promise(executor)\n  $Promise = function Promise(executor){\n    anInstance(this, $Promise, PROMISE, '_h');\n    aFunction(executor);\n    Internal.call(this);\n    try {\n      executor(ctx($resolve, this, 1), ctx($reject, this, 1));\n    } catch(err){\n      $reject.call(this, err);\n    }\n  };\n  Internal = function Promise(executor){\n    this._c = [];             // <- awaiting reactions\n    this._a = undefined;      // <- checked in isUnhandled reactions\n    this._s = 0;              // <- state\n    this._d = false;          // <- done\n    this._v = undefined;      // <- value\n    this._h = 0;              // <- rejection state, 0 - default, 1 - handled, 2 - unhandled\n    this._n = false;          // <- notify\n  };\n  Internal.prototype = require('./_redefine-all')($Promise.prototype, {\n    // 25.4.5.3 Promise.prototype.then(onFulfilled, onRejected)\n    then: function then(onFulfilled, onRejected){\n      var reaction    = newPromiseCapability(speciesConstructor(this, $Promise));\n      reaction.ok     = typeof onFulfilled == 'function' ? onFulfilled : true;\n      reaction.fail   = typeof onRejected == 'function' && onRejected;\n      reaction.domain = isNode ? process.domain : undefined;\n      this._c.push(reaction);\n      if(this._a)this._a.push(reaction);\n      if(this._s)notify(this, false);\n      return reaction.promise;\n    },\n    // 25.4.5.1 Promise.prototype.catch(onRejected)\n    'catch': function(onRejected){\n      return this.then(undefined, onRejected);\n    }\n  });\n  PromiseCapability = function(){\n    var promise  = new Internal;\n    this.promise = promise;\n    this.resolve = ctx($resolve, promise, 1);\n    this.reject  = ctx($reject, promise, 1);\n  };\n}\n\n$export($export.G + $export.W + $export.F * !USE_NATIVE, {Promise: $Promise});\nrequire('./_set-to-string-tag')($Promise, PROMISE);\nrequire('./_set-species')(PROMISE);\nWrapper = require('./_core')[PROMISE];\n\n// statics\n$export($export.S + $export.F * !USE_NATIVE, PROMISE, {\n  // 25.4.4.5 Promise.reject(r)\n  reject: function reject(r){\n    var capability = newPromiseCapability(this)\n      , $$reject   = capability.reject;\n    $$reject(r);\n    return capability.promise;\n  }\n});\n$export($export.S + $export.F * (LIBRARY || !USE_NATIVE), PROMISE, {\n  // 25.4.4.6 Promise.resolve(x)\n  resolve: function resolve(x){\n    // instanceof instead of internal slot check because we should fix it without replacement native Promise core\n    if(x instanceof $Promise && sameConstructor(x.constructor, this))return x;\n    var capability = newPromiseCapability(this)\n      , $$resolve  = capability.resolve;\n    $$resolve(x);\n    return capability.promise;\n  }\n});\n$export($export.S + $export.F * !(USE_NATIVE && require('./_iter-detect')(function(iter){\n  $Promise.all(iter)['catch'](empty);\n})), PROMISE, {\n  // 25.4.4.1 Promise.all(iterable)\n  all: function all(iterable){\n    var C          = this\n      , capability = newPromiseCapability(C)\n      , resolve    = capability.resolve\n      , reject     = capability.reject;\n    var abrupt = perform(function(){\n      var values    = []\n        , index     = 0\n        , remaining = 1;\n      forOf(iterable, false, function(promise){\n        var $index        = index++\n          , alreadyCalled = false;\n        values.push(undefined);\n        remaining++;\n        C.resolve(promise).then(function(value){\n          if(alreadyCalled)return;\n          alreadyCalled  = true;\n          values[$index] = value;\n          --remaining || resolve(values);\n        }, reject);\n      });\n      --remaining || resolve(values);\n    });\n    if(abrupt)reject(abrupt.error);\n    return capability.promise;\n  },\n  // 25.4.4.4 Promise.race(iterable)\n  race: function race(iterable){\n    var C          = this\n      , capability = newPromiseCapability(C)\n      , reject     = capability.reject;\n    var abrupt = perform(function(){\n      forOf(iterable, false, function(promise){\n        C.resolve(promise).then(capability.resolve, reject);\n      });\n    });\n    if(abrupt)reject(abrupt.error);\n    return capability.promise;\n  }\n});","deps":{"./_a-function":"node_modules/babel-polyfill/node_modules/core-js/modules/_a-function.js","./_an-instance":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-instance.js","./_classof":"node_modules/babel-polyfill/node_modules/core-js/modules/_classof.js","./_core":"node_modules/babel-polyfill/node_modules/core-js/modules/_core.js","./_ctx":"node_modules/babel-polyfill/node_modules/core-js/modules/_ctx.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_for-of":"node_modules/babel-polyfill/node_modules/core-js/modules/_for-of.js","./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js","./_iter-detect":"node_modules/babel-polyfill/node_modules/core-js/modules/_iter-detect.js","./_library":"node_modules/babel-polyfill/node_modules/core-js/modules/_library.js","./_microtask":"node_modules/babel-polyfill/node_modules/core-js/modules/_microtask.js","./_redefine-all":"node_modules/babel-polyfill/node_modules/core-js/modules/_redefine-all.js","./_set-species":"node_modules/babel-polyfill/node_modules/core-js/modules/_set-species.js","./_set-to-string-tag":"node_modules/babel-polyfill/node_modules/core-js/modules/_set-to-string-tag.js","./_species-constructor":"node_modules/babel-polyfill/node_modules/core-js/modules/_species-constructor.js","./_task":"node_modules/babel-polyfill/node_modules/core-js/modules/_task.js","./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.apply.js","source":"var $export   = require('./_export')\n  , aFunction = require('./_a-function')\n  , anObject  = require('./_an-object')\n  , rApply    = (require('./_global').Reflect || {}).apply\n  , fApply    = Function.apply;\n// MS Edge argumentsList argument is optional\n$export($export.S + $export.F * !require('./_fails')(function(){\n  rApply(function(){});\n}), 'Reflect', {\n  apply: function apply(target, thisArgument, argumentsList){\n    var T = aFunction(target)\n      , L = anObject(argumentsList);\n    return rApply ? rApply(T, thisArgument, L) : fApply.call(T, thisArgument, L);\n  }\n});","deps":{"./_a-function":"node_modules/babel-polyfill/node_modules/core-js/modules/_a-function.js","./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js","./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.construct.js","source":"var $export    = require('./_export')\n  , create     = require('./_object-create')\n  , aFunction  = require('./_a-function')\n  , anObject   = require('./_an-object')\n  , isObject   = require('./_is-object')\n  , fails      = require('./_fails')\n  , bind       = require('./_bind')\n  , rConstruct = (require('./_global').Reflect || {}).construct;\n\n// MS Edge supports only 2 arguments and argumentsList argument is optional\n// FF Nightly sets third argument as `new.target`, but does not create `this` from it\nvar NEW_TARGET_BUG = fails(function(){\n  function F(){}\n  return !(rConstruct(function(){}, [], F) instanceof F);\n});\nvar ARGS_BUG = !fails(function(){\n  rConstruct(function(){});\n});\n\n$export($export.S + $export.F * (NEW_TARGET_BUG || ARGS_BUG), 'Reflect', {\n  construct: function construct(Target, args /*, newTarget*/){\n    aFunction(Target);\n    anObject(args);\n    var newTarget = arguments.length < 3 ? Target : aFunction(arguments[2]);\n    if(ARGS_BUG && !NEW_TARGET_BUG)return rConstruct(Target, args, newTarget);\n    if(Target == newTarget){\n      // w/o altered newTarget, optimization for 0-4 arguments\n      switch(args.length){\n        case 0: return new Target;\n        case 1: return new Target(args[0]);\n        case 2: return new Target(args[0], args[1]);\n        case 3: return new Target(args[0], args[1], args[2]);\n        case 4: return new Target(args[0], args[1], args[2], args[3]);\n      }\n      // w/o altered newTarget, lot of arguments case\n      var $args = [null];\n      $args.push.apply($args, args);\n      return new (bind.apply(Target, $args));\n    }\n    // with altered newTarget, not support built-in constructors\n    var proto    = newTarget.prototype\n      , instance = create(isObject(proto) ? proto : Object.prototype)\n      , result   = Function.apply.call(Target, instance, args);\n    return isObject(result) ? result : instance;\n  }\n});","deps":{"./_a-function":"node_modules/babel-polyfill/node_modules/core-js/modules/_a-function.js","./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_bind":"node_modules/babel-polyfill/node_modules/core-js/modules/_bind.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js","./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js","./_object-create":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-create.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.define-property.js","source":"var dP          = require('./_object-dp')\n  , $export     = require('./_export')\n  , anObject    = require('./_an-object')\n  , toPrimitive = require('./_to-primitive');\n\n// MS Edge has broken Reflect.defineProperty - throwing instead of returning false\n$export($export.S + $export.F * require('./_fails')(function(){\n  Reflect.defineProperty(dP.f({}, 1, {value: 1}), 1, {value: 2});\n}), 'Reflect', {\n  defineProperty: function defineProperty(target, propertyKey, attributes){\n    anObject(target);\n    propertyKey = toPrimitive(propertyKey, true);\n    anObject(attributes);\n    try {\n      dP.f(target, propertyKey, attributes);\n      return true;\n    } catch(e){\n      return false;\n    }\n  }\n});","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js","./_object-dp":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dp.js","./_to-primitive":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-primitive.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.delete-property.js","source":"var $export  = require('./_export')\n  , gOPD     = require('./_object-gopd').f\n  , anObject = require('./_an-object');\n\n$export($export.S, 'Reflect', {\n  deleteProperty: function deleteProperty(target, propertyKey){\n    var desc = gOPD(anObject(target), propertyKey);\n    return desc && !desc.configurable ? false : delete target[propertyKey];\n  }\n});","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_object-gopd":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopd.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.enumerate.js","source":"'use strict';\n// 26.1.5 Reflect.enumerate(target)\nvar $export  = require('./_export')\n  , anObject = require('./_an-object');\nvar Enumerate = function(iterated){\n  this._t = anObject(iterated); // target\n  this._i = 0;                  // next index\n  var keys = this._k = []       // keys\n    , key;\n  for(key in iterated)keys.push(key);\n};\nrequire('./_iter-create')(Enumerate, 'Object', function(){\n  var that = this\n    , keys = that._k\n    , key;\n  do {\n    if(that._i >= keys.length)return {value: undefined, done: true};\n  } while(!((key = keys[that._i++]) in that._t));\n  return {value: key, done: false};\n});\n\n$export($export.S, 'Reflect', {\n  enumerate: function enumerate(target){\n    return new Enumerate(target);\n  }\n});","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_iter-create":"node_modules/babel-polyfill/node_modules/core-js/modules/_iter-create.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.get-own-property-descriptor.js","source":"var gOPD     = require('./_object-gopd')\n  , $export  = require('./_export')\n  , anObject = require('./_an-object');\n\n$export($export.S, 'Reflect', {\n  getOwnPropertyDescriptor: function getOwnPropertyDescriptor(target, propertyKey){\n    return gOPD.f(anObject(target), propertyKey);\n  }\n});","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_object-gopd":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopd.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.get-prototype-of.js","source":"var $export  = require('./_export')\n  , getProto = require('./_object-gpo')\n  , anObject = require('./_an-object');\n\n$export($export.S, 'Reflect', {\n  getPrototypeOf: function getPrototypeOf(target){\n    return getProto(anObject(target));\n  }\n});","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_object-gpo":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gpo.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.get.js","source":"var gOPD           = require('./_object-gopd')\n  , getPrototypeOf = require('./_object-gpo')\n  , has            = require('./_has')\n  , $export        = require('./_export')\n  , isObject       = require('./_is-object')\n  , anObject       = require('./_an-object');\n\nfunction get(target, propertyKey/*, receiver*/){\n  var receiver = arguments.length < 3 ? target : arguments[2]\n    , desc, proto;\n  if(anObject(target) === receiver)return target[propertyKey];\n  if(desc = gOPD.f(target, propertyKey))return has(desc, 'value')\n    ? desc.value\n    : desc.get !== undefined\n      ? desc.get.call(receiver)\n      : undefined;\n  if(isObject(proto = getPrototypeOf(target)))return get(proto, propertyKey, receiver);\n}\n\n$export($export.S, 'Reflect', {get: get});","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_has":"node_modules/babel-polyfill/node_modules/core-js/modules/_has.js","./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js","./_object-gopd":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopd.js","./_object-gpo":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gpo.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.has.js","source":"var $export = require('./_export');\n\n$export($export.S, 'Reflect', {\n  has: function has(target, propertyKey){\n    return propertyKey in target;\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.is-extensible.js","source":"var $export       = require('./_export')\n  , anObject      = require('./_an-object')\n  , $isExtensible = Object.isExtensible;\n\n$export($export.S, 'Reflect', {\n  isExtensible: function isExtensible(target){\n    anObject(target);\n    return $isExtensible ? $isExtensible(target) : true;\n  }\n});","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.own-keys.js","source":"var $export = require('./_export');\n\n$export($export.S, 'Reflect', {ownKeys: require('./_own-keys')});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_own-keys":"node_modules/babel-polyfill/node_modules/core-js/modules/_own-keys.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.prevent-extensions.js","source":"var $export            = require('./_export')\n  , anObject           = require('./_an-object')\n  , $preventExtensions = Object.preventExtensions;\n\n$export($export.S, 'Reflect', {\n  preventExtensions: function preventExtensions(target){\n    anObject(target);\n    try {\n      if($preventExtensions)$preventExtensions(target);\n      return true;\n    } catch(e){\n      return false;\n    }\n  }\n});","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.set-prototype-of.js","source":"var $export  = require('./_export')\n  , setProto = require('./_set-proto');\n\nif(setProto)$export($export.S, 'Reflect', {\n  setPrototypeOf: function setPrototypeOf(target, proto){\n    setProto.check(target, proto);\n    try {\n      setProto.set(target, proto);\n      return true;\n    } catch(e){\n      return false;\n    }\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_set-proto":"node_modules/babel-polyfill/node_modules/core-js/modules/_set-proto.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.set.js","source":"var dP             = require('./_object-dp')\n  , gOPD           = require('./_object-gopd')\n  , getPrototypeOf = require('./_object-gpo')\n  , has            = require('./_has')\n  , $export        = require('./_export')\n  , createDesc     = require('./_property-desc')\n  , anObject       = require('./_an-object')\n  , isObject       = require('./_is-object');\n\nfunction set(target, propertyKey, V/*, receiver*/){\n  var receiver = arguments.length < 4 ? target : arguments[3]\n    , ownDesc  = gOPD.f(anObject(target), propertyKey)\n    , existingDescriptor, proto;\n  if(!ownDesc){\n    if(isObject(proto = getPrototypeOf(target))){\n      return set(proto, propertyKey, V, receiver);\n    }\n    ownDesc = createDesc(0);\n  }\n  if(has(ownDesc, 'value')){\n    if(ownDesc.writable === false || !isObject(receiver))return false;\n    existingDescriptor = gOPD.f(receiver, propertyKey) || createDesc(0);\n    existingDescriptor.value = V;\n    dP.f(receiver, propertyKey, existingDescriptor);\n    return true;\n  }\n  return ownDesc.set === undefined ? false : (ownDesc.set.call(receiver, V), true);\n}\n\n$export($export.S, 'Reflect', {set: set});","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_has":"node_modules/babel-polyfill/node_modules/core-js/modules/_has.js","./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js","./_object-dp":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dp.js","./_object-gopd":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopd.js","./_object-gpo":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gpo.js","./_property-desc":"node_modules/babel-polyfill/node_modules/core-js/modules/_property-desc.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.regexp.constructor.js","source":"var global            = require('./_global')\n  , inheritIfRequired = require('./_inherit-if-required')\n  , dP                = require('./_object-dp').f\n  , gOPN              = require('./_object-gopn').f\n  , isRegExp          = require('./_is-regexp')\n  , $flags            = require('./_flags')\n  , $RegExp           = global.RegExp\n  , Base              = $RegExp\n  , proto             = $RegExp.prototype\n  , re1               = /a/g\n  , re2               = /a/g\n  // \"new\" creates a new object, old webkit buggy here\n  , CORRECT_NEW       = new $RegExp(re1) !== re1;\n\nif(require('./_descriptors') && (!CORRECT_NEW || require('./_fails')(function(){\n  re2[require('./_wks')('match')] = false;\n  // RegExp constructor can alter flags and IsRegExp works correct with @@match\n  return $RegExp(re1) != re1 || $RegExp(re2) == re2 || $RegExp(re1, 'i') != '/a/i';\n}))){\n  $RegExp = function RegExp(p, f){\n    var tiRE = this instanceof $RegExp\n      , piRE = isRegExp(p)\n      , fiU  = f === undefined;\n    return !tiRE && piRE && p.constructor === $RegExp && fiU ? p\n      : inheritIfRequired(CORRECT_NEW\n        ? new Base(piRE && !fiU ? p.source : p, f)\n        : Base((piRE = p instanceof $RegExp) ? p.source : p, piRE && fiU ? $flags.call(p) : f)\n      , tiRE ? this : proto, $RegExp);\n  };\n  var proxy = function(key){\n    key in $RegExp || dP($RegExp, key, {\n      configurable: true,\n      get: function(){ return Base[key]; },\n      set: function(it){ Base[key] = it; }\n    });\n  };\n  for(var keys = gOPN(Base), i = 0; keys.length > i; )proxy(keys[i++]);\n  proto.constructor = $RegExp;\n  $RegExp.prototype = proto;\n  require('./_redefine')(global, 'RegExp', $RegExp);\n}\n\nrequire('./_set-species')('RegExp');","deps":{"./_descriptors":"node_modules/babel-polyfill/node_modules/core-js/modules/_descriptors.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js","./_flags":"node_modules/babel-polyfill/node_modules/core-js/modules/_flags.js","./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_inherit-if-required":"node_modules/babel-polyfill/node_modules/core-js/modules/_inherit-if-required.js","./_is-regexp":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-regexp.js","./_object-dp":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dp.js","./_object-gopn":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopn.js","./_redefine":"node_modules/babel-polyfill/node_modules/core-js/modules/_redefine.js","./_set-species":"node_modules/babel-polyfill/node_modules/core-js/modules/_set-species.js","./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.regexp.flags.js","source":"if(require('./_descriptors') && /./g.flags != 'g')require('./_object-dp').f(RegExp.prototype, 'flags', {\n  configurable: true,\n  get: require('./_flags')\n});","deps":{"./_descriptors":"node_modules/babel-polyfill/node_modules/core-js/modules/_descriptors.js","./_flags":"node_modules/babel-polyfill/node_modules/core-js/modules/_flags.js","./_object-dp":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dp.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.regexp.match.js","source":"require('./_fix-re-wks')('match', 1, function(defined, MATCH, $match){\n  // 21.1.3.11 String.prototype.match(regexp)\n  return [function match(regexp){\n    'use strict';\n    var O  = defined(this)\n      , fn = regexp == undefined ? undefined : regexp[MATCH];\n    return fn !== undefined ? fn.call(regexp, O) : new RegExp(regexp)[MATCH](String(O));\n  }, $match];\n});","deps":{"./_fix-re-wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_fix-re-wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.regexp.replace.js","source":"require('./_fix-re-wks')('replace', 2, function(defined, REPLACE, $replace){\n  // 21.1.3.14 String.prototype.replace(searchValue, replaceValue)\n  return [function replace(searchValue, replaceValue){\n    'use strict';\n    var O  = defined(this)\n      , fn = searchValue == undefined ? undefined : searchValue[REPLACE];\n    return fn !== undefined\n      ? fn.call(searchValue, O, replaceValue)\n      : $replace.call(String(O), searchValue, replaceValue);\n  }, $replace];\n});","deps":{"./_fix-re-wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_fix-re-wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.regexp.search.js","source":"require('./_fix-re-wks')('search', 1, function(defined, SEARCH, $search){\n  // 21.1.3.15 String.prototype.search(regexp)\n  return [function search(regexp){\n    'use strict';\n    var O  = defined(this)\n      , fn = regexp == undefined ? undefined : regexp[SEARCH];\n    return fn !== undefined ? fn.call(regexp, O) : new RegExp(regexp)[SEARCH](String(O));\n  }, $search];\n});","deps":{"./_fix-re-wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_fix-re-wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.regexp.split.js","source":"require('./_fix-re-wks')('split', 2, function(defined, SPLIT, $split){\n  'use strict';\n  var isRegExp   = require('./_is-regexp')\n    , _split     = $split\n    , $push      = [].push\n    , $SPLIT     = 'split'\n    , LENGTH     = 'length'\n    , LAST_INDEX = 'lastIndex';\n  if(\n    'abbc'[$SPLIT](/(b)*/)[1] == 'c' ||\n    'test'[$SPLIT](/(?:)/, -1)[LENGTH] != 4 ||\n    'ab'[$SPLIT](/(?:ab)*/)[LENGTH] != 2 ||\n    '.'[$SPLIT](/(.?)(.?)/)[LENGTH] != 4 ||\n    '.'[$SPLIT](/()()/)[LENGTH] > 1 ||\n    ''[$SPLIT](/.?/)[LENGTH]\n  ){\n    var NPCG = /()??/.exec('')[1] === undefined; // nonparticipating capturing group\n    // based on es5-shim implementation, need to rework it\n    $split = function(separator, limit){\n      var string = String(this);\n      if(separator === undefined && limit === 0)return [];\n      // If `separator` is not a regex, use native split\n      if(!isRegExp(separator))return _split.call(string, separator, limit);\n      var output = [];\n      var flags = (separator.ignoreCase ? 'i' : '') +\n                  (separator.multiline ? 'm' : '') +\n                  (separator.unicode ? 'u' : '') +\n                  (separator.sticky ? 'y' : '');\n      var lastLastIndex = 0;\n      var splitLimit = limit === undefined ? 4294967295 : limit >>> 0;\n      // Make `global` and avoid `lastIndex` issues by working with a copy\n      var separatorCopy = new RegExp(separator.source, flags + 'g');\n      var separator2, match, lastIndex, lastLength, i;\n      // Doesn't need flags gy, but they don't hurt\n      if(!NPCG)separator2 = new RegExp('^' + separatorCopy.source + '$(?!\\\\s)', flags);\n      while(match = separatorCopy.exec(string)){\n        // `separatorCopy.lastIndex` is not reliable cross-browser\n        lastIndex = match.index + match[0][LENGTH];\n        if(lastIndex > lastLastIndex){\n          output.push(string.slice(lastLastIndex, match.index));\n          // Fix browsers whose `exec` methods don't consistently return `undefined` for NPCG\n          if(!NPCG && match[LENGTH] > 1)match[0].replace(separator2, function(){\n            for(i = 1; i < arguments[LENGTH] - 2; i++)if(arguments[i] === undefined)match[i] = undefined;\n          });\n          if(match[LENGTH] > 1 && match.index < string[LENGTH])$push.apply(output, match.slice(1));\n          lastLength = match[0][LENGTH];\n          lastLastIndex = lastIndex;\n          if(output[LENGTH] >= splitLimit)break;\n        }\n        if(separatorCopy[LAST_INDEX] === match.index)separatorCopy[LAST_INDEX]++; // Avoid an infinite loop\n      }\n      if(lastLastIndex === string[LENGTH]){\n        if(lastLength || !separatorCopy.test(''))output.push('');\n      } else output.push(string.slice(lastLastIndex));\n      return output[LENGTH] > splitLimit ? output.slice(0, splitLimit) : output;\n    };\n  // Chakra, V8\n  } else if('0'[$SPLIT](undefined, 0)[LENGTH]){\n    $split = function(separator, limit){\n      return separator === undefined && limit === 0 ? [] : _split.call(this, separator, limit);\n    };\n  }\n  // 21.1.3.17 String.prototype.split(separator, limit)\n  return [function split(separator, limit){\n    var O  = defined(this)\n      , fn = separator == undefined ? undefined : separator[SPLIT];\n    return fn !== undefined ? fn.call(separator, O, limit) : $split.call(String(O), separator, limit);\n  }, $split];\n});","deps":{"./_fix-re-wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_fix-re-wks.js","./_is-regexp":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-regexp.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.regexp.to-string.js","source":"'use strict';\nrequire('./es6.regexp.flags');\nvar anObject    = require('./_an-object')\n  , $flags      = require('./_flags')\n  , DESCRIPTORS = require('./_descriptors')\n  , TO_STRING   = 'toString'\n  , $toString   = /./[TO_STRING];\n\nvar define = function(fn){\n  require('./_redefine')(RegExp.prototype, TO_STRING, fn, true);\n};\n\n// 21.2.5.14 RegExp.prototype.toString()\nif(require('./_fails')(function(){ return $toString.call({source: 'a', flags: 'b'}) != '/a/b'; })){\n  define(function toString(){\n    var R = anObject(this);\n    return '/'.concat(R.source, '/',\n      'flags' in R ? R.flags : !DESCRIPTORS && R instanceof RegExp ? $flags.call(R) : undefined);\n  });\n// FF44- RegExp#toString has a wrong name\n} else if($toString.name != TO_STRING){\n  define(function toString(){\n    return $toString.call(this);\n  });\n}","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_descriptors":"node_modules/babel-polyfill/node_modules/core-js/modules/_descriptors.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js","./_flags":"node_modules/babel-polyfill/node_modules/core-js/modules/_flags.js","./_redefine":"node_modules/babel-polyfill/node_modules/core-js/modules/_redefine.js","./es6.regexp.flags":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.regexp.flags.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.set.js","source":"'use strict';\nvar strong = require('./_collection-strong');\n\n// 23.2 Set Objects\nmodule.exports = require('./_collection')('Set', function(get){\n  return function Set(){ return get(this, arguments.length > 0 ? arguments[0] : undefined); };\n}, {\n  // 23.2.3.1 Set.prototype.add(value)\n  add: function add(value){\n    return strong.def(this, value = value === 0 ? 0 : value, value);\n  }\n}, strong);","deps":{"./_collection":"node_modules/babel-polyfill/node_modules/core-js/modules/_collection.js","./_collection-strong":"node_modules/babel-polyfill/node_modules/core-js/modules/_collection-strong.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.anchor.js","source":"'use strict';\n// B.2.3.2 String.prototype.anchor(name)\nrequire('./_string-html')('anchor', function(createHTML){\n  return function anchor(name){\n    return createHTML(this, 'a', 'name', name);\n  }\n});","deps":{"./_string-html":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-html.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.big.js","source":"'use strict';\n// B.2.3.3 String.prototype.big()\nrequire('./_string-html')('big', function(createHTML){\n  return function big(){\n    return createHTML(this, 'big', '', '');\n  }\n});","deps":{"./_string-html":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-html.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.blink.js","source":"'use strict';\n// B.2.3.4 String.prototype.blink()\nrequire('./_string-html')('blink', function(createHTML){\n  return function blink(){\n    return createHTML(this, 'blink', '', '');\n  }\n});","deps":{"./_string-html":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-html.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.bold.js","source":"'use strict';\n// B.2.3.5 String.prototype.bold()\nrequire('./_string-html')('bold', function(createHTML){\n  return function bold(){\n    return createHTML(this, 'b', '', '');\n  }\n});","deps":{"./_string-html":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-html.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.code-point-at.js","source":"'use strict';\nvar $export = require('./_export')\n  , $at     = require('./_string-at')(false);\n$export($export.P, 'String', {\n  // 21.1.3.3 String.prototype.codePointAt(pos)\n  codePointAt: function codePointAt(pos){\n    return $at(this, pos);\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_string-at":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-at.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.ends-with.js","source":"'use strict';\nvar $export   = require('./_export')\n  , toLength  = require('./_to-length')\n  , context   = require('./_string-context')\n  , ENDS_WITH = 'endsWith'\n  , $endsWith = ''[ENDS_WITH];\n\n$export($export.P + $export.F * require('./_fails-is-regexp')(ENDS_WITH), 'String', {\n  endsWith: function endsWith(searchString /*, endPosition = @length */){\n    var that = context(this, searchString, ENDS_WITH)\n      , endPosition = arguments.length > 1 ? arguments[1] : undefined\n      , len    = toLength(that.length)\n      , end    = endPosition === undefined ? len : Math.min(toLength(endPosition), len)\n      , search = String(searchString);\n    return $endsWith\n      ? $endsWith.call(that, search, end)\n      : that.slice(end - search.length, end) === search;\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_fails-is-regexp":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails-is-regexp.js","./_string-context":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-context.js","./_to-length":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-length.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.fixed.js","source":"'use strict';\n// B.2.3.6 String.prototype.fixed()\nrequire('./_string-html')('fixed', function(createHTML){\n  return function fixed(){\n    return createHTML(this, 'tt', '', '');\n  }\n});","deps":{"./_string-html":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-html.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.fontcolor.js","source":"'use strict';\n// B.2.3.7 String.prototype.fontcolor(color)\nrequire('./_string-html')('fontcolor', function(createHTML){\n  return function fontcolor(color){\n    return createHTML(this, 'font', 'color', color);\n  }\n});","deps":{"./_string-html":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-html.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.fontsize.js","source":"'use strict';\n// B.2.3.8 String.prototype.fontsize(size)\nrequire('./_string-html')('fontsize', function(createHTML){\n  return function fontsize(size){\n    return createHTML(this, 'font', 'size', size);\n  }\n});","deps":{"./_string-html":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-html.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.from-code-point.js","source":"var $export        = require('./_export')\n  , toIndex        = require('./_to-index')\n  , fromCharCode   = String.fromCharCode\n  , $fromCodePoint = String.fromCodePoint;\n\n// length should be 1, old FF problem\n$export($export.S + $export.F * (!!$fromCodePoint && $fromCodePoint.length != 1), 'String', {\n  // 21.1.2.2 String.fromCodePoint(...codePoints)\n  fromCodePoint: function fromCodePoint(x){ // eslint-disable-line no-unused-vars\n    var res  = []\n      , aLen = arguments.length\n      , i    = 0\n      , code;\n    while(aLen > i){\n      code = +arguments[i++];\n      if(toIndex(code, 0x10ffff) !== code)throw RangeError(code + ' is not a valid code point');\n      res.push(code < 0x10000\n        ? fromCharCode(code)\n        : fromCharCode(((code -= 0x10000) >> 10) + 0xd800, code % 0x400 + 0xdc00)\n      );\n    } return res.join('');\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_to-index":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-index.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.includes.js","source":"'use strict';\nvar $export  = require('./_export')\n  , context  = require('./_string-context')\n  , INCLUDES = 'includes';\n\n$export($export.P + $export.F * require('./_fails-is-regexp')(INCLUDES), 'String', {\n  includes: function includes(searchString /*, position = 0 */){\n    return !!~context(this, searchString, INCLUDES)\n      .indexOf(searchString, arguments.length > 1 ? arguments[1] : undefined);\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_fails-is-regexp":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails-is-regexp.js","./_string-context":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-context.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.italics.js","source":"'use strict';\n// B.2.3.9 String.prototype.italics()\nrequire('./_string-html')('italics', function(createHTML){\n  return function italics(){\n    return createHTML(this, 'i', '', '');\n  }\n});","deps":{"./_string-html":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-html.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.iterator.js","source":"'use strict';\nvar $at  = require('./_string-at')(true);\n\n// 21.1.3.27 String.prototype[@@iterator]()\nrequire('./_iter-define')(String, 'String', function(iterated){\n  this._t = String(iterated); // target\n  this._i = 0;                // next index\n// 21.1.5.2.1 %StringIteratorPrototype%.next()\n}, function(){\n  var O     = this._t\n    , index = this._i\n    , point;\n  if(index >= O.length)return {value: undefined, done: true};\n  point = $at(O, index);\n  this._i += point.length;\n  return {value: point, done: false};\n});","deps":{"./_iter-define":"node_modules/babel-polyfill/node_modules/core-js/modules/_iter-define.js","./_string-at":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-at.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.link.js","source":"'use strict';\n// B.2.3.10 String.prototype.link(url)\nrequire('./_string-html')('link', function(createHTML){\n  return function link(url){\n    return createHTML(this, 'a', 'href', url);\n  }\n});","deps":{"./_string-html":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-html.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.raw.js","source":"var $export   = require('./_export')\n  , toIObject = require('./_to-iobject')\n  , toLength  = require('./_to-length');\n\n$export($export.S, 'String', {\n  // 21.1.2.4 String.raw(callSite, ...substitutions)\n  raw: function raw(callSite){\n    var tpl  = toIObject(callSite.raw)\n      , len  = toLength(tpl.length)\n      , aLen = arguments.length\n      , res  = []\n      , i    = 0;\n    while(len > i){\n      res.push(String(tpl[i++]));\n      if(i < aLen)res.push(String(arguments[i]));\n    } return res.join('');\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_to-iobject":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-iobject.js","./_to-length":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-length.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.repeat.js","source":"var $export = require('./_export');\n\n$export($export.P, 'String', {\n  // 21.1.3.13 String.prototype.repeat(count)\n  repeat: require('./_string-repeat')\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_string-repeat":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-repeat.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.small.js","source":"'use strict';\n// B.2.3.11 String.prototype.small()\nrequire('./_string-html')('small', function(createHTML){\n  return function small(){\n    return createHTML(this, 'small', '', '');\n  }\n});","deps":{"./_string-html":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-html.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.starts-with.js","source":"'use strict';\nvar $export     = require('./_export')\n  , toLength    = require('./_to-length')\n  , context     = require('./_string-context')\n  , STARTS_WITH = 'startsWith'\n  , $startsWith = ''[STARTS_WITH];\n\n$export($export.P + $export.F * require('./_fails-is-regexp')(STARTS_WITH), 'String', {\n  startsWith: function startsWith(searchString /*, position = 0 */){\n    var that   = context(this, searchString, STARTS_WITH)\n      , index  = toLength(Math.min(arguments.length > 1 ? arguments[1] : undefined, that.length))\n      , search = String(searchString);\n    return $startsWith\n      ? $startsWith.call(that, search, index)\n      : that.slice(index, index + search.length) === search;\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_fails-is-regexp":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails-is-regexp.js","./_string-context":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-context.js","./_to-length":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-length.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.strike.js","source":"'use strict';\n// B.2.3.12 String.prototype.strike()\nrequire('./_string-html')('strike', function(createHTML){\n  return function strike(){\n    return createHTML(this, 'strike', '', '');\n  }\n});","deps":{"./_string-html":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-html.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.sub.js","source":"'use strict';\n// B.2.3.13 String.prototype.sub()\nrequire('./_string-html')('sub', function(createHTML){\n  return function sub(){\n    return createHTML(this, 'sub', '', '');\n  }\n});","deps":{"./_string-html":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-html.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.sup.js","source":"'use strict';\n// B.2.3.14 String.prototype.sup()\nrequire('./_string-html')('sup', function(createHTML){\n  return function sup(){\n    return createHTML(this, 'sup', '', '');\n  }\n});","deps":{"./_string-html":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-html.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.trim.js","source":"'use strict';\n// 21.1.3.25 String.prototype.trim()\nrequire('./_string-trim')('trim', function($trim){\n  return function trim(){\n    return $trim(this, 3);\n  };\n});","deps":{"./_string-trim":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-trim.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.symbol.js","source":"'use strict';\n// ECMAScript 6 symbols shim\nvar global         = require('./_global')\n  , has            = require('./_has')\n  , DESCRIPTORS    = require('./_descriptors')\n  , $export        = require('./_export')\n  , redefine       = require('./_redefine')\n  , META           = require('./_meta').KEY\n  , $fails         = require('./_fails')\n  , shared         = require('./_shared')\n  , setToStringTag = require('./_set-to-string-tag')\n  , uid            = require('./_uid')\n  , wks            = require('./_wks')\n  , wksExt         = require('./_wks-ext')\n  , wksDefine      = require('./_wks-define')\n  , keyOf          = require('./_keyof')\n  , enumKeys       = require('./_enum-keys')\n  , isArray        = require('./_is-array')\n  , anObject       = require('./_an-object')\n  , toIObject      = require('./_to-iobject')\n  , toPrimitive    = require('./_to-primitive')\n  , createDesc     = require('./_property-desc')\n  , _create        = require('./_object-create')\n  , gOPNExt        = require('./_object-gopn-ext')\n  , $GOPD          = require('./_object-gopd')\n  , $DP            = require('./_object-dp')\n  , $keys          = require('./_object-keys')\n  , gOPD           = $GOPD.f\n  , dP             = $DP.f\n  , gOPN           = gOPNExt.f\n  , $Symbol        = global.Symbol\n  , $JSON          = global.JSON\n  , _stringify     = $JSON && $JSON.stringify\n  , PROTOTYPE      = 'prototype'\n  , HIDDEN         = wks('_hidden')\n  , TO_PRIMITIVE   = wks('toPrimitive')\n  , isEnum         = {}.propertyIsEnumerable\n  , SymbolRegistry = shared('symbol-registry')\n  , AllSymbols     = shared('symbols')\n  , OPSymbols      = shared('op-symbols')\n  , ObjectProto    = Object[PROTOTYPE]\n  , USE_NATIVE     = typeof $Symbol == 'function'\n  , QObject        = global.QObject;\n// Don't use setters in Qt Script, https://github.com/zloirock/core-js/issues/173\nvar setter = !QObject || !QObject[PROTOTYPE] || !QObject[PROTOTYPE].findChild;\n\n// fallback for old Android, https://code.google.com/p/v8/issues/detail?id=687\nvar setSymbolDesc = DESCRIPTORS && $fails(function(){\n  return _create(dP({}, 'a', {\n    get: function(){ return dP(this, 'a', {value: 7}).a; }\n  })).a != 7;\n}) ? function(it, key, D){\n  var protoDesc = gOPD(ObjectProto, key);\n  if(protoDesc)delete ObjectProto[key];\n  dP(it, key, D);\n  if(protoDesc && it !== ObjectProto)dP(ObjectProto, key, protoDesc);\n} : dP;\n\nvar wrap = function(tag){\n  var sym = AllSymbols[tag] = _create($Symbol[PROTOTYPE]);\n  sym._k = tag;\n  return sym;\n};\n\nvar isSymbol = USE_NATIVE && typeof $Symbol.iterator == 'symbol' ? function(it){\n  return typeof it == 'symbol';\n} : function(it){\n  return it instanceof $Symbol;\n};\n\nvar $defineProperty = function defineProperty(it, key, D){\n  if(it === ObjectProto)$defineProperty(OPSymbols, key, D);\n  anObject(it);\n  key = toPrimitive(key, true);\n  anObject(D);\n  if(has(AllSymbols, key)){\n    if(!D.enumerable){\n      if(!has(it, HIDDEN))dP(it, HIDDEN, createDesc(1, {}));\n      it[HIDDEN][key] = true;\n    } else {\n      if(has(it, HIDDEN) && it[HIDDEN][key])it[HIDDEN][key] = false;\n      D = _create(D, {enumerable: createDesc(0, false)});\n    } return setSymbolDesc(it, key, D);\n  } return dP(it, key, D);\n};\nvar $defineProperties = function defineProperties(it, P){\n  anObject(it);\n  var keys = enumKeys(P = toIObject(P))\n    , i    = 0\n    , l = keys.length\n    , key;\n  while(l > i)$defineProperty(it, key = keys[i++], P[key]);\n  return it;\n};\nvar $create = function create(it, P){\n  return P === undefined ? _create(it) : $defineProperties(_create(it), P);\n};\nvar $propertyIsEnumerable = function propertyIsEnumerable(key){\n  var E = isEnum.call(this, key = toPrimitive(key, true));\n  if(this === ObjectProto && has(AllSymbols, key) && !has(OPSymbols, key))return false;\n  return E || !has(this, key) || !has(AllSymbols, key) || has(this, HIDDEN) && this[HIDDEN][key] ? E : true;\n};\nvar $getOwnPropertyDescriptor = function getOwnPropertyDescriptor(it, key){\n  it  = toIObject(it);\n  key = toPrimitive(key, true);\n  if(it === ObjectProto && has(AllSymbols, key) && !has(OPSymbols, key))return;\n  var D = gOPD(it, key);\n  if(D && has(AllSymbols, key) && !(has(it, HIDDEN) && it[HIDDEN][key]))D.enumerable = true;\n  return D;\n};\nvar $getOwnPropertyNames = function getOwnPropertyNames(it){\n  var names  = gOPN(toIObject(it))\n    , result = []\n    , i      = 0\n    , key;\n  while(names.length > i){\n    if(!has(AllSymbols, key = names[i++]) && key != HIDDEN && key != META)result.push(key);\n  } return result;\n};\nvar $getOwnPropertySymbols = function getOwnPropertySymbols(it){\n  var IS_OP  = it === ObjectProto\n    , names  = gOPN(IS_OP ? OPSymbols : toIObject(it))\n    , result = []\n    , i      = 0\n    , key;\n  while(names.length > i){\n    if(has(AllSymbols, key = names[i++]) && (IS_OP ? has(ObjectProto, key) : true))result.push(AllSymbols[key]);\n  } return result;\n};\n\n// 19.4.1.1 Symbol([description])\nif(!USE_NATIVE){\n  $Symbol = function Symbol(){\n    if(this instanceof $Symbol)throw TypeError('Symbol is not a constructor!');\n    var tag = uid(arguments.length > 0 ? arguments[0] : undefined);\n    var $set = function(value){\n      if(this === ObjectProto)$set.call(OPSymbols, value);\n      if(has(this, HIDDEN) && has(this[HIDDEN], tag))this[HIDDEN][tag] = false;\n      setSymbolDesc(this, tag, createDesc(1, value));\n    };\n    if(DESCRIPTORS && setter)setSymbolDesc(ObjectProto, tag, {configurable: true, set: $set});\n    return wrap(tag);\n  };\n  redefine($Symbol[PROTOTYPE], 'toString', function toString(){\n    return this._k;\n  });\n\n  $GOPD.f = $getOwnPropertyDescriptor;\n  $DP.f   = $defineProperty;\n  require('./_object-gopn').f = gOPNExt.f = $getOwnPropertyNames;\n  require('./_object-pie').f  = $propertyIsEnumerable;\n  require('./_object-gops').f = $getOwnPropertySymbols;\n\n  if(DESCRIPTORS && !require('./_library')){\n    redefine(ObjectProto, 'propertyIsEnumerable', $propertyIsEnumerable, true);\n  }\n\n  wksExt.f = function(name){\n    return wrap(wks(name));\n  }\n}\n\n$export($export.G + $export.W + $export.F * !USE_NATIVE, {Symbol: $Symbol});\n\nfor(var symbols = (\n  // 19.4.2.2, 19.4.2.3, 19.4.2.4, 19.4.2.6, 19.4.2.8, 19.4.2.9, 19.4.2.10, 19.4.2.11, 19.4.2.12, 19.4.2.13, 19.4.2.14\n  'hasInstance,isConcatSpreadable,iterator,match,replace,search,species,split,toPrimitive,toStringTag,unscopables'\n).split(','), i = 0; symbols.length > i; )wks(symbols[i++]);\n\nfor(var symbols = $keys(wks.store), i = 0; symbols.length > i; )wksDefine(symbols[i++]);\n\n$export($export.S + $export.F * !USE_NATIVE, 'Symbol', {\n  // 19.4.2.1 Symbol.for(key)\n  'for': function(key){\n    return has(SymbolRegistry, key += '')\n      ? SymbolRegistry[key]\n      : SymbolRegistry[key] = $Symbol(key);\n  },\n  // 19.4.2.5 Symbol.keyFor(sym)\n  keyFor: function keyFor(key){\n    if(isSymbol(key))return keyOf(SymbolRegistry, key);\n    throw TypeError(key + ' is not a symbol!');\n  },\n  useSetter: function(){ setter = true; },\n  useSimple: function(){ setter = false; }\n});\n\n$export($export.S + $export.F * !USE_NATIVE, 'Object', {\n  // 19.1.2.2 Object.create(O [, Properties])\n  create: $create,\n  // 19.1.2.4 Object.defineProperty(O, P, Attributes)\n  defineProperty: $defineProperty,\n  // 19.1.2.3 Object.defineProperties(O, Properties)\n  defineProperties: $defineProperties,\n  // 19.1.2.6 Object.getOwnPropertyDescriptor(O, P)\n  getOwnPropertyDescriptor: $getOwnPropertyDescriptor,\n  // 19.1.2.7 Object.getOwnPropertyNames(O)\n  getOwnPropertyNames: $getOwnPropertyNames,\n  // 19.1.2.8 Object.getOwnPropertySymbols(O)\n  getOwnPropertySymbols: $getOwnPropertySymbols\n});\n\n// 24.3.2 JSON.stringify(value [, replacer [, space]])\n$JSON && $export($export.S + $export.F * (!USE_NATIVE || $fails(function(){\n  var S = $Symbol();\n  // MS Edge converts symbol values to JSON as {}\n  // WebKit converts symbol values to JSON as null\n  // V8 throws on boxed symbols\n  return _stringify([S]) != '[null]' || _stringify({a: S}) != '{}' || _stringify(Object(S)) != '{}';\n})), 'JSON', {\n  stringify: function stringify(it){\n    if(it === undefined || isSymbol(it))return; // IE8 returns string on undefined\n    var args = [it]\n      , i    = 1\n      , replacer, $replacer;\n    while(arguments.length > i)args.push(arguments[i++]);\n    replacer = args[1];\n    if(typeof replacer == 'function')$replacer = replacer;\n    if($replacer || !isArray(replacer))replacer = function(key, value){\n      if($replacer)value = $replacer.call(this, key, value);\n      if(!isSymbol(value))return value;\n    };\n    args[1] = replacer;\n    return _stringify.apply($JSON, args);\n  }\n});\n\n// 19.4.3.4 Symbol.prototype[@@toPrimitive](hint)\n$Symbol[PROTOTYPE][TO_PRIMITIVE] || require('./_hide')($Symbol[PROTOTYPE], TO_PRIMITIVE, $Symbol[PROTOTYPE].valueOf);\n// 19.4.3.5 Symbol.prototype[@@toStringTag]\nsetToStringTag($Symbol, 'Symbol');\n// 20.2.1.9 Math[@@toStringTag]\nsetToStringTag(Math, 'Math', true);\n// 24.3.3 JSON[@@toStringTag]\nsetToStringTag(global.JSON, 'JSON', true);","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_descriptors":"node_modules/babel-polyfill/node_modules/core-js/modules/_descriptors.js","./_enum-keys":"node_modules/babel-polyfill/node_modules/core-js/modules/_enum-keys.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js","./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_has":"node_modules/babel-polyfill/node_modules/core-js/modules/_has.js","./_hide":"node_modules/babel-polyfill/node_modules/core-js/modules/_hide.js","./_is-array":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-array.js","./_keyof":"node_modules/babel-polyfill/node_modules/core-js/modules/_keyof.js","./_library":"node_modules/babel-polyfill/node_modules/core-js/modules/_library.js","./_meta":"node_modules/babel-polyfill/node_modules/core-js/modules/_meta.js","./_object-create":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-create.js","./_object-dp":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dp.js","./_object-gopd":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopd.js","./_object-gopn":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopn.js","./_object-gopn-ext":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopn-ext.js","./_object-gops":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gops.js","./_object-keys":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-keys.js","./_object-pie":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-pie.js","./_property-desc":"node_modules/babel-polyfill/node_modules/core-js/modules/_property-desc.js","./_redefine":"node_modules/babel-polyfill/node_modules/core-js/modules/_redefine.js","./_set-to-string-tag":"node_modules/babel-polyfill/node_modules/core-js/modules/_set-to-string-tag.js","./_shared":"node_modules/babel-polyfill/node_modules/core-js/modules/_shared.js","./_to-iobject":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-iobject.js","./_to-primitive":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-primitive.js","./_uid":"node_modules/babel-polyfill/node_modules/core-js/modules/_uid.js","./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js","./_wks-define":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks-define.js","./_wks-ext":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks-ext.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.typed.array-buffer.js","source":"'use strict';\nvar $export      = require('./_export')\n  , $typed       = require('./_typed')\n  , buffer       = require('./_typed-buffer')\n  , anObject     = require('./_an-object')\n  , toIndex      = require('./_to-index')\n  , toLength     = require('./_to-length')\n  , isObject     = require('./_is-object')\n  , ArrayBuffer  = require('./_global').ArrayBuffer\n  , speciesConstructor = require('./_species-constructor')\n  , $ArrayBuffer = buffer.ArrayBuffer\n  , $DataView    = buffer.DataView\n  , $isView      = $typed.ABV && ArrayBuffer.isView\n  , $slice       = $ArrayBuffer.prototype.slice\n  , VIEW         = $typed.VIEW\n  , ARRAY_BUFFER = 'ArrayBuffer';\n\n$export($export.G + $export.W + $export.F * (ArrayBuffer !== $ArrayBuffer), {ArrayBuffer: $ArrayBuffer});\n\n$export($export.S + $export.F * !$typed.CONSTR, ARRAY_BUFFER, {\n  // 24.1.3.1 ArrayBuffer.isView(arg)\n  isView: function isView(it){\n    return $isView && $isView(it) || isObject(it) && VIEW in it;\n  }\n});\n\n$export($export.P + $export.U + $export.F * require('./_fails')(function(){\n  return !new $ArrayBuffer(2).slice(1, undefined).byteLength;\n}), ARRAY_BUFFER, {\n  // 24.1.4.3 ArrayBuffer.prototype.slice(start, end)\n  slice: function slice(start, end){\n    if($slice !== undefined && end === undefined)return $slice.call(anObject(this), start); // FF fix\n    var len    = anObject(this).byteLength\n      , first  = toIndex(start, len)\n      , final  = toIndex(end === undefined ? len : end, len)\n      , result = new (speciesConstructor(this, $ArrayBuffer))(toLength(final - first))\n      , viewS  = new $DataView(this)\n      , viewT  = new $DataView(result)\n      , index  = 0;\n    while(first < final){\n      viewT.setUint8(index++, viewS.getUint8(first++));\n    } return result;\n  }\n});\n\nrequire('./_set-species')(ARRAY_BUFFER);","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_fails":"node_modules/babel-polyfill/node_modules/core-js/modules/_fails.js","./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js","./_set-species":"node_modules/babel-polyfill/node_modules/core-js/modules/_set-species.js","./_species-constructor":"node_modules/babel-polyfill/node_modules/core-js/modules/_species-constructor.js","./_to-index":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-index.js","./_to-length":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-length.js","./_typed":"node_modules/babel-polyfill/node_modules/core-js/modules/_typed.js","./_typed-buffer":"node_modules/babel-polyfill/node_modules/core-js/modules/_typed-buffer.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.typed.data-view.js","source":"var $export = require('./_export');\n$export($export.G + $export.W + $export.F * !require('./_typed').ABV, {\n  DataView: require('./_typed-buffer').DataView\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_typed":"node_modules/babel-polyfill/node_modules/core-js/modules/_typed.js","./_typed-buffer":"node_modules/babel-polyfill/node_modules/core-js/modules/_typed-buffer.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.typed.float32-array.js","source":"require('./_typed-array')('Float32', 4, function(init){\n  return function Float32Array(data, byteOffset, length){\n    return init(this, data, byteOffset, length);\n  };\n});","deps":{"./_typed-array":"node_modules/babel-polyfill/node_modules/core-js/modules/_typed-array.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.typed.float64-array.js","source":"require('./_typed-array')('Float64', 8, function(init){\n  return function Float64Array(data, byteOffset, length){\n    return init(this, data, byteOffset, length);\n  };\n});","deps":{"./_typed-array":"node_modules/babel-polyfill/node_modules/core-js/modules/_typed-array.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.typed.int16-array.js","source":"require('./_typed-array')('Int16', 2, function(init){\n  return function Int16Array(data, byteOffset, length){\n    return init(this, data, byteOffset, length);\n  };\n});","deps":{"./_typed-array":"node_modules/babel-polyfill/node_modules/core-js/modules/_typed-array.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.typed.int32-array.js","source":"require('./_typed-array')('Int32', 4, function(init){\n  return function Int32Array(data, byteOffset, length){\n    return init(this, data, byteOffset, length);\n  };\n});","deps":{"./_typed-array":"node_modules/babel-polyfill/node_modules/core-js/modules/_typed-array.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.typed.int8-array.js","source":"require('./_typed-array')('Int8', 1, function(init){\n  return function Int8Array(data, byteOffset, length){\n    return init(this, data, byteOffset, length);\n  };\n});","deps":{"./_typed-array":"node_modules/babel-polyfill/node_modules/core-js/modules/_typed-array.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.typed.uint16-array.js","source":"require('./_typed-array')('Uint16', 2, function(init){\n  return function Uint16Array(data, byteOffset, length){\n    return init(this, data, byteOffset, length);\n  };\n});","deps":{"./_typed-array":"node_modules/babel-polyfill/node_modules/core-js/modules/_typed-array.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.typed.uint32-array.js","source":"require('./_typed-array')('Uint32', 4, function(init){\n  return function Uint32Array(data, byteOffset, length){\n    return init(this, data, byteOffset, length);\n  };\n});","deps":{"./_typed-array":"node_modules/babel-polyfill/node_modules/core-js/modules/_typed-array.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.typed.uint8-array.js","source":"require('./_typed-array')('Uint8', 1, function(init){\n  return function Uint8Array(data, byteOffset, length){\n    return init(this, data, byteOffset, length);\n  };\n});","deps":{"./_typed-array":"node_modules/babel-polyfill/node_modules/core-js/modules/_typed-array.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.typed.uint8-clamped-array.js","source":"require('./_typed-array')('Uint8', 1, function(init){\n  return function Uint8ClampedArray(data, byteOffset, length){\n    return init(this, data, byteOffset, length);\n  };\n}, true);","deps":{"./_typed-array":"node_modules/babel-polyfill/node_modules/core-js/modules/_typed-array.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.weak-map.js","source":"'use strict';\nvar each         = require('./_array-methods')(0)\n  , redefine     = require('./_redefine')\n  , meta         = require('./_meta')\n  , assign       = require('./_object-assign')\n  , weak         = require('./_collection-weak')\n  , isObject     = require('./_is-object')\n  , getWeak      = meta.getWeak\n  , isExtensible = Object.isExtensible\n  , uncaughtFrozenStore = weak.ufstore\n  , tmp          = {}\n  , InternalMap;\n\nvar wrapper = function(get){\n  return function WeakMap(){\n    return get(this, arguments.length > 0 ? arguments[0] : undefined);\n  };\n};\n\nvar methods = {\n  // 23.3.3.3 WeakMap.prototype.get(key)\n  get: function get(key){\n    if(isObject(key)){\n      var data = getWeak(key);\n      if(data === true)return uncaughtFrozenStore(this).get(key);\n      return data ? data[this._i] : undefined;\n    }\n  },\n  // 23.3.3.5 WeakMap.prototype.set(key, value)\n  set: function set(key, value){\n    return weak.def(this, key, value);\n  }\n};\n\n// 23.3 WeakMap Objects\nvar $WeakMap = module.exports = require('./_collection')('WeakMap', wrapper, methods, weak, true, true);\n\n// IE11 WeakMap frozen keys fix\nif(new $WeakMap().set((Object.freeze || Object)(tmp), 7).get(tmp) != 7){\n  InternalMap = weak.getConstructor(wrapper);\n  assign(InternalMap.prototype, methods);\n  meta.NEED = true;\n  each(['delete', 'has', 'get', 'set'], function(key){\n    var proto  = $WeakMap.prototype\n      , method = proto[key];\n    redefine(proto, key, function(a, b){\n      // store frozen objects on internal weakmap shim\n      if(isObject(a) && !isExtensible(a)){\n        if(!this._f)this._f = new InternalMap;\n        var result = this._f[key](a, b);\n        return key == 'set' ? this : result;\n      // store all the rest on native weakmap\n      } return method.call(this, a, b);\n    });\n  });\n}","deps":{"./_array-methods":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-methods.js","./_collection":"node_modules/babel-polyfill/node_modules/core-js/modules/_collection.js","./_collection-weak":"node_modules/babel-polyfill/node_modules/core-js/modules/_collection-weak.js","./_is-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-object.js","./_meta":"node_modules/babel-polyfill/node_modules/core-js/modules/_meta.js","./_object-assign":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-assign.js","./_redefine":"node_modules/babel-polyfill/node_modules/core-js/modules/_redefine.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.weak-set.js","source":"'use strict';\nvar weak = require('./_collection-weak');\n\n// 23.4 WeakSet Objects\nrequire('./_collection')('WeakSet', function(get){\n  return function WeakSet(){ return get(this, arguments.length > 0 ? arguments[0] : undefined); };\n}, {\n  // 23.4.3.1 WeakSet.prototype.add(value)\n  add: function add(value){\n    return weak.def(this, value, true);\n  }\n}, weak, false, true);","deps":{"./_collection":"node_modules/babel-polyfill/node_modules/core-js/modules/_collection.js","./_collection-weak":"node_modules/babel-polyfill/node_modules/core-js/modules/_collection-weak.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.array.includes.js","source":"'use strict';\n// https://github.com/tc39/Array.prototype.includes\nvar $export   = require('./_export')\n  , $includes = require('./_array-includes')(true);\n\n$export($export.P, 'Array', {\n  includes: function includes(el /*, fromIndex = 0 */){\n    return $includes(this, el, arguments.length > 1 ? arguments[1] : undefined);\n  }\n});\n\nrequire('./_add-to-unscopables')('includes');","deps":{"./_add-to-unscopables":"node_modules/babel-polyfill/node_modules/core-js/modules/_add-to-unscopables.js","./_array-includes":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-includes.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.asap.js","source":"var $export   = require('./_export')\n  , microtask = require('./_microtask')()\n  , process   = require('./_global').process\n  , isNode    = require('./_cof')(process) == 'process';\n\n$export($export.G, {\n  asap: function asap(fn){\n    var domain = isNode && process.domain;\n    microtask(domain ? domain.bind(fn) : fn);\n  }\n});","deps":{"./_cof":"node_modules/babel-polyfill/node_modules/core-js/modules/_cof.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_microtask":"node_modules/babel-polyfill/node_modules/core-js/modules/_microtask.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.error.is-error.js","source":"var $export = require('./_export')\n  , cof     = require('./_cof');\n\n$export($export.S, 'Error', {\n  isError: function isError(it){\n    return cof(it) === 'Error';\n  }\n});","deps":{"./_cof":"node_modules/babel-polyfill/node_modules/core-js/modules/_cof.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.map.to-json.js","source":"var $export  = require('./_export');\n\n$export($export.P + $export.R, 'Map', {toJSON: require('./_collection-to-json')('Map')});","deps":{"./_collection-to-json":"node_modules/babel-polyfill/node_modules/core-js/modules/_collection-to-json.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.math.iaddh.js","source":"var $export = require('./_export');\n\n$export($export.S, 'Math', {\n  iaddh: function iaddh(x0, x1, y0, y1){\n    var $x0 = x0 >>> 0\n      , $x1 = x1 >>> 0\n      , $y0 = y0 >>> 0;\n    return $x1 + (y1 >>> 0) + (($x0 & $y0 | ($x0 | $y0) & ~($x0 + $y0 >>> 0)) >>> 31) | 0;\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.math.imulh.js","source":"var $export = require('./_export');\n\n$export($export.S, 'Math', {\n  imulh: function imulh(u, v){\n    var UINT16 = 0xffff\n      , $u = +u\n      , $v = +v\n      , u0 = $u & UINT16\n      , v0 = $v & UINT16\n      , u1 = $u >> 16\n      , v1 = $v >> 16\n      , t  = (u1 * v0 >>> 0) + (u0 * v0 >>> 16);\n    return u1 * v1 + (t >> 16) + ((u0 * v1 >>> 0) + (t & UINT16) >> 16);\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.math.isubh.js","source":"var $export = require('./_export');\n\n$export($export.S, 'Math', {\n  isubh: function isubh(x0, x1, y0, y1){\n    var $x0 = x0 >>> 0\n      , $x1 = x1 >>> 0\n      , $y0 = y0 >>> 0;\n    return $x1 - (y1 >>> 0) - ((~$x0 & $y0 | ~($x0 ^ $y0) & $x0 - $y0 >>> 0) >>> 31) | 0;\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.math.umulh.js","source":"var $export = require('./_export');\n\n$export($export.S, 'Math', {\n  umulh: function umulh(u, v){\n    var UINT16 = 0xffff\n      , $u = +u\n      , $v = +v\n      , u0 = $u & UINT16\n      , v0 = $v & UINT16\n      , u1 = $u >>> 16\n      , v1 = $v >>> 16\n      , t  = (u1 * v0 >>> 0) + (u0 * v0 >>> 16);\n    return u1 * v1 + (t >>> 16) + ((u0 * v1 >>> 0) + (t & UINT16) >>> 16);\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.object.define-getter.js","source":"'use strict';\nvar $export         = require('./_export')\n  , toObject        = require('./_to-object')\n  , aFunction       = require('./_a-function')\n  , $defineProperty = require('./_object-dp');\n\n// B.2.2.2 Object.prototype.__defineGetter__(P, getter)\nrequire('./_descriptors') && $export($export.P + require('./_object-forced-pam'), 'Object', {\n  __defineGetter__: function __defineGetter__(P, getter){\n    $defineProperty.f(toObject(this), P, {get: aFunction(getter), enumerable: true, configurable: true});\n  }\n});","deps":{"./_a-function":"node_modules/babel-polyfill/node_modules/core-js/modules/_a-function.js","./_descriptors":"node_modules/babel-polyfill/node_modules/core-js/modules/_descriptors.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_object-dp":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dp.js","./_object-forced-pam":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-forced-pam.js","./_to-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-object.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.object.define-setter.js","source":"'use strict';\nvar $export         = require('./_export')\n  , toObject        = require('./_to-object')\n  , aFunction       = require('./_a-function')\n  , $defineProperty = require('./_object-dp');\n\n// B.2.2.3 Object.prototype.__defineSetter__(P, setter)\nrequire('./_descriptors') && $export($export.P + require('./_object-forced-pam'), 'Object', {\n  __defineSetter__: function __defineSetter__(P, setter){\n    $defineProperty.f(toObject(this), P, {set: aFunction(setter), enumerable: true, configurable: true});\n  }\n});","deps":{"./_a-function":"node_modules/babel-polyfill/node_modules/core-js/modules/_a-function.js","./_descriptors":"node_modules/babel-polyfill/node_modules/core-js/modules/_descriptors.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_object-dp":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-dp.js","./_object-forced-pam":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-forced-pam.js","./_to-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-object.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.object.entries.js","source":"var $export  = require('./_export')\n  , $entries = require('./_object-to-array')(true);\n\n$export($export.S, 'Object', {\n  entries: function entries(it){\n    return $entries(it);\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_object-to-array":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-to-array.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.object.get-own-property-descriptors.js","source":"var $export        = require('./_export')\n  , ownKeys        = require('./_own-keys')\n  , toIObject      = require('./_to-iobject')\n  , gOPD           = require('./_object-gopd')\n  , createProperty = require('./_create-property');\n\n$export($export.S, 'Object', {\n  getOwnPropertyDescriptors: function getOwnPropertyDescriptors(object){\n    var O       = toIObject(object)\n      , getDesc = gOPD.f\n      , keys    = ownKeys(O)\n      , result  = {}\n      , i       = 0\n      , key;\n    while(keys.length > i)createProperty(result, key = keys[i++], getDesc(O, key));\n    return result;\n  }\n});","deps":{"./_create-property":"node_modules/babel-polyfill/node_modules/core-js/modules/_create-property.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_object-gopd":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopd.js","./_own-keys":"node_modules/babel-polyfill/node_modules/core-js/modules/_own-keys.js","./_to-iobject":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-iobject.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.object.lookup-getter.js","source":"'use strict';\nvar $export                  = require('./_export')\n  , toObject                 = require('./_to-object')\n  , toPrimitive              = require('./_to-primitive')\n  , getPrototypeOf           = require('./_object-gpo')\n  , getOwnPropertyDescriptor = require('./_object-gopd').f;\n\n// B.2.2.4 Object.prototype.__lookupGetter__(P)\nrequire('./_descriptors') && $export($export.P + require('./_object-forced-pam'), 'Object', {\n  __lookupGetter__: function __lookupGetter__(P){\n    var O = toObject(this)\n      , K = toPrimitive(P, true)\n      , D;\n    do {\n      if(D = getOwnPropertyDescriptor(O, K))return D.get;\n    } while(O = getPrototypeOf(O));\n  }\n});","deps":{"./_descriptors":"node_modules/babel-polyfill/node_modules/core-js/modules/_descriptors.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_object-forced-pam":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-forced-pam.js","./_object-gopd":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopd.js","./_object-gpo":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gpo.js","./_to-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-object.js","./_to-primitive":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-primitive.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.object.lookup-setter.js","source":"'use strict';\nvar $export                  = require('./_export')\n  , toObject                 = require('./_to-object')\n  , toPrimitive              = require('./_to-primitive')\n  , getPrototypeOf           = require('./_object-gpo')\n  , getOwnPropertyDescriptor = require('./_object-gopd').f;\n\n// B.2.2.5 Object.prototype.__lookupSetter__(P)\nrequire('./_descriptors') && $export($export.P + require('./_object-forced-pam'), 'Object', {\n  __lookupSetter__: function __lookupSetter__(P){\n    var O = toObject(this)\n      , K = toPrimitive(P, true)\n      , D;\n    do {\n      if(D = getOwnPropertyDescriptor(O, K))return D.set;\n    } while(O = getPrototypeOf(O));\n  }\n});","deps":{"./_descriptors":"node_modules/babel-polyfill/node_modules/core-js/modules/_descriptors.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_object-forced-pam":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-forced-pam.js","./_object-gopd":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gopd.js","./_object-gpo":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gpo.js","./_to-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-object.js","./_to-primitive":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-primitive.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.object.values.js","source":"var $export = require('./_export')\n  , $values = require('./_object-to-array')(false);\n\n$export($export.S, 'Object', {\n  values: function values(it){\n    return $values(it);\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_object-to-array":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-to-array.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.observable.js","source":"'use strict';\n// https://github.com/zenparsing/es-observable\nvar $export     = require('./_export')\n  , global      = require('./_global')\n  , core        = require('./_core')\n  , microtask   = require('./_microtask')()\n  , OBSERVABLE  = require('./_wks')('observable')\n  , aFunction   = require('./_a-function')\n  , anObject    = require('./_an-object')\n  , anInstance  = require('./_an-instance')\n  , redefineAll = require('./_redefine-all')\n  , hide        = require('./_hide')\n  , forOf       = require('./_for-of')\n  , RETURN      = forOf.RETURN;\n\nvar getMethod = function(fn){\n  return fn == null ? undefined : aFunction(fn);\n};\n\nvar cleanupSubscription = function(subscription){\n  var cleanup = subscription._c;\n  if(cleanup){\n    subscription._c = undefined;\n    cleanup();\n  }\n};\n\nvar subscriptionClosed = function(subscription){\n  return subscription._o === undefined;\n};\n\nvar closeSubscription = function(subscription){\n  if(!subscriptionClosed(subscription)){\n    subscription._o = undefined;\n    cleanupSubscription(subscription);\n  }\n};\n\nvar Subscription = function(observer, subscriber){\n  anObject(observer);\n  this._c = undefined;\n  this._o = observer;\n  observer = new SubscriptionObserver(this);\n  try {\n    var cleanup      = subscriber(observer)\n      , subscription = cleanup;\n    if(cleanup != null){\n      if(typeof cleanup.unsubscribe === 'function')cleanup = function(){ subscription.unsubscribe(); };\n      else aFunction(cleanup);\n      this._c = cleanup;\n    }\n  } catch(e){\n    observer.error(e);\n    return;\n  } if(subscriptionClosed(this))cleanupSubscription(this);\n};\n\nSubscription.prototype = redefineAll({}, {\n  unsubscribe: function unsubscribe(){ closeSubscription(this); }\n});\n\nvar SubscriptionObserver = function(subscription){\n  this._s = subscription;\n};\n\nSubscriptionObserver.prototype = redefineAll({}, {\n  next: function next(value){\n    var subscription = this._s;\n    if(!subscriptionClosed(subscription)){\n      var observer = subscription._o;\n      try {\n        var m = getMethod(observer.next);\n        if(m)return m.call(observer, value);\n      } catch(e){\n        try {\n          closeSubscription(subscription);\n        } finally {\n          throw e;\n        }\n      }\n    }\n  },\n  error: function error(value){\n    var subscription = this._s;\n    if(subscriptionClosed(subscription))throw value;\n    var observer = subscription._o;\n    subscription._o = undefined;\n    try {\n      var m = getMethod(observer.error);\n      if(!m)throw value;\n      value = m.call(observer, value);\n    } catch(e){\n      try {\n        cleanupSubscription(subscription);\n      } finally {\n        throw e;\n      }\n    } cleanupSubscription(subscription);\n    return value;\n  },\n  complete: function complete(value){\n    var subscription = this._s;\n    if(!subscriptionClosed(subscription)){\n      var observer = subscription._o;\n      subscription._o = undefined;\n      try {\n        var m = getMethod(observer.complete);\n        value = m ? m.call(observer, value) : undefined;\n      } catch(e){\n        try {\n          cleanupSubscription(subscription);\n        } finally {\n          throw e;\n        }\n      } cleanupSubscription(subscription);\n      return value;\n    }\n  }\n});\n\nvar $Observable = function Observable(subscriber){\n  anInstance(this, $Observable, 'Observable', '_f')._f = aFunction(subscriber);\n};\n\nredefineAll($Observable.prototype, {\n  subscribe: function subscribe(observer){\n    return new Subscription(observer, this._f);\n  },\n  forEach: function forEach(fn){\n    var that = this;\n    return new (core.Promise || global.Promise)(function(resolve, reject){\n      aFunction(fn);\n      var subscription = that.subscribe({\n        next : function(value){\n          try {\n            return fn(value);\n          } catch(e){\n            reject(e);\n            subscription.unsubscribe();\n          }\n        },\n        error: reject,\n        complete: resolve\n      });\n    });\n  }\n});\n\nredefineAll($Observable, {\n  from: function from(x){\n    var C = typeof this === 'function' ? this : $Observable;\n    var method = getMethod(anObject(x)[OBSERVABLE]);\n    if(method){\n      var observable = anObject(method.call(x));\n      return observable.constructor === C ? observable : new C(function(observer){\n        return observable.subscribe(observer);\n      });\n    }\n    return new C(function(observer){\n      var done = false;\n      microtask(function(){\n        if(!done){\n          try {\n            if(forOf(x, false, function(it){\n              observer.next(it);\n              if(done)return RETURN;\n            }) === RETURN)return;\n          } catch(e){\n            if(done)throw e;\n            observer.error(e);\n            return;\n          } observer.complete();\n        }\n      });\n      return function(){ done = true; };\n    });\n  },\n  of: function of(){\n    for(var i = 0, l = arguments.length, items = Array(l); i < l;)items[i] = arguments[i++];\n    return new (typeof this === 'function' ? this : $Observable)(function(observer){\n      var done = false;\n      microtask(function(){\n        if(!done){\n          for(var i = 0; i < items.length; ++i){\n            observer.next(items[i]);\n            if(done)return;\n          } observer.complete();\n        }\n      });\n      return function(){ done = true; };\n    });\n  }\n});\n\nhide($Observable.prototype, OBSERVABLE, function(){ return this; });\n\n$export($export.G, {Observable: $Observable});\n\nrequire('./_set-species')('Observable');","deps":{"./_a-function":"node_modules/babel-polyfill/node_modules/core-js/modules/_a-function.js","./_an-instance":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-instance.js","./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_core":"node_modules/babel-polyfill/node_modules/core-js/modules/_core.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_for-of":"node_modules/babel-polyfill/node_modules/core-js/modules/_for-of.js","./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_hide":"node_modules/babel-polyfill/node_modules/core-js/modules/_hide.js","./_microtask":"node_modules/babel-polyfill/node_modules/core-js/modules/_microtask.js","./_redefine-all":"node_modules/babel-polyfill/node_modules/core-js/modules/_redefine-all.js","./_set-species":"node_modules/babel-polyfill/node_modules/core-js/modules/_set-species.js","./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.reflect.define-metadata.js","source":"var metadata                  = require('./_metadata')\n  , anObject                  = require('./_an-object')\n  , toMetaKey                 = metadata.key\n  , ordinaryDefineOwnMetadata = metadata.set;\n\nmetadata.exp({defineMetadata: function defineMetadata(metadataKey, metadataValue, target, targetKey){\n  ordinaryDefineOwnMetadata(metadataKey, metadataValue, anObject(target), toMetaKey(targetKey));\n}});","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_metadata":"node_modules/babel-polyfill/node_modules/core-js/modules/_metadata.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.reflect.delete-metadata.js","source":"var metadata               = require('./_metadata')\n  , anObject               = require('./_an-object')\n  , toMetaKey              = metadata.key\n  , getOrCreateMetadataMap = metadata.map\n  , store                  = metadata.store;\n\nmetadata.exp({deleteMetadata: function deleteMetadata(metadataKey, target /*, targetKey */){\n  var targetKey   = arguments.length < 3 ? undefined : toMetaKey(arguments[2])\n    , metadataMap = getOrCreateMetadataMap(anObject(target), targetKey, false);\n  if(metadataMap === undefined || !metadataMap['delete'](metadataKey))return false;\n  if(metadataMap.size)return true;\n  var targetMetadata = store.get(target);\n  targetMetadata['delete'](targetKey);\n  return !!targetMetadata.size || store['delete'](target);\n}});","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_metadata":"node_modules/babel-polyfill/node_modules/core-js/modules/_metadata.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.reflect.get-metadata-keys.js","source":"var Set                     = require('./es6.set')\n  , from                    = require('./_array-from-iterable')\n  , metadata                = require('./_metadata')\n  , anObject                = require('./_an-object')\n  , getPrototypeOf          = require('./_object-gpo')\n  , ordinaryOwnMetadataKeys = metadata.keys\n  , toMetaKey               = metadata.key;\n\nvar ordinaryMetadataKeys = function(O, P){\n  var oKeys  = ordinaryOwnMetadataKeys(O, P)\n    , parent = getPrototypeOf(O);\n  if(parent === null)return oKeys;\n  var pKeys  = ordinaryMetadataKeys(parent, P);\n  return pKeys.length ? oKeys.length ? from(new Set(oKeys.concat(pKeys))) : pKeys : oKeys;\n};\n\nmetadata.exp({getMetadataKeys: function getMetadataKeys(target /*, targetKey */){\n  return ordinaryMetadataKeys(anObject(target), arguments.length < 2 ? undefined : toMetaKey(arguments[1]));\n}});","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_array-from-iterable":"node_modules/babel-polyfill/node_modules/core-js/modules/_array-from-iterable.js","./_metadata":"node_modules/babel-polyfill/node_modules/core-js/modules/_metadata.js","./_object-gpo":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gpo.js","./es6.set":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.set.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.reflect.get-metadata.js","source":"var metadata               = require('./_metadata')\n  , anObject               = require('./_an-object')\n  , getPrototypeOf         = require('./_object-gpo')\n  , ordinaryHasOwnMetadata = metadata.has\n  , ordinaryGetOwnMetadata = metadata.get\n  , toMetaKey              = metadata.key;\n\nvar ordinaryGetMetadata = function(MetadataKey, O, P){\n  var hasOwn = ordinaryHasOwnMetadata(MetadataKey, O, P);\n  if(hasOwn)return ordinaryGetOwnMetadata(MetadataKey, O, P);\n  var parent = getPrototypeOf(O);\n  return parent !== null ? ordinaryGetMetadata(MetadataKey, parent, P) : undefined;\n};\n\nmetadata.exp({getMetadata: function getMetadata(metadataKey, target /*, targetKey */){\n  return ordinaryGetMetadata(metadataKey, anObject(target), arguments.length < 3 ? undefined : toMetaKey(arguments[2]));\n}});","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_metadata":"node_modules/babel-polyfill/node_modules/core-js/modules/_metadata.js","./_object-gpo":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gpo.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.reflect.get-own-metadata-keys.js","source":"var metadata                = require('./_metadata')\n  , anObject                = require('./_an-object')\n  , ordinaryOwnMetadataKeys = metadata.keys\n  , toMetaKey               = metadata.key;\n\nmetadata.exp({getOwnMetadataKeys: function getOwnMetadataKeys(target /*, targetKey */){\n  return ordinaryOwnMetadataKeys(anObject(target), arguments.length < 2 ? undefined : toMetaKey(arguments[1]));\n}});","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_metadata":"node_modules/babel-polyfill/node_modules/core-js/modules/_metadata.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.reflect.get-own-metadata.js","source":"var metadata               = require('./_metadata')\n  , anObject               = require('./_an-object')\n  , ordinaryGetOwnMetadata = metadata.get\n  , toMetaKey              = metadata.key;\n\nmetadata.exp({getOwnMetadata: function getOwnMetadata(metadataKey, target /*, targetKey */){\n  return ordinaryGetOwnMetadata(metadataKey, anObject(target)\n    , arguments.length < 3 ? undefined : toMetaKey(arguments[2]));\n}});","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_metadata":"node_modules/babel-polyfill/node_modules/core-js/modules/_metadata.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.reflect.has-metadata.js","source":"var metadata               = require('./_metadata')\n  , anObject               = require('./_an-object')\n  , getPrototypeOf         = require('./_object-gpo')\n  , ordinaryHasOwnMetadata = metadata.has\n  , toMetaKey              = metadata.key;\n\nvar ordinaryHasMetadata = function(MetadataKey, O, P){\n  var hasOwn = ordinaryHasOwnMetadata(MetadataKey, O, P);\n  if(hasOwn)return true;\n  var parent = getPrototypeOf(O);\n  return parent !== null ? ordinaryHasMetadata(MetadataKey, parent, P) : false;\n};\n\nmetadata.exp({hasMetadata: function hasMetadata(metadataKey, target /*, targetKey */){\n  return ordinaryHasMetadata(metadataKey, anObject(target), arguments.length < 3 ? undefined : toMetaKey(arguments[2]));\n}});","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_metadata":"node_modules/babel-polyfill/node_modules/core-js/modules/_metadata.js","./_object-gpo":"node_modules/babel-polyfill/node_modules/core-js/modules/_object-gpo.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.reflect.has-own-metadata.js","source":"var metadata               = require('./_metadata')\n  , anObject               = require('./_an-object')\n  , ordinaryHasOwnMetadata = metadata.has\n  , toMetaKey              = metadata.key;\n\nmetadata.exp({hasOwnMetadata: function hasOwnMetadata(metadataKey, target /*, targetKey */){\n  return ordinaryHasOwnMetadata(metadataKey, anObject(target)\n    , arguments.length < 3 ? undefined : toMetaKey(arguments[2]));\n}});","deps":{"./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_metadata":"node_modules/babel-polyfill/node_modules/core-js/modules/_metadata.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.reflect.metadata.js","source":"var metadata                  = require('./_metadata')\n  , anObject                  = require('./_an-object')\n  , aFunction                 = require('./_a-function')\n  , toMetaKey                 = metadata.key\n  , ordinaryDefineOwnMetadata = metadata.set;\n\nmetadata.exp({metadata: function metadata(metadataKey, metadataValue){\n  return function decorator(target, targetKey){\n    ordinaryDefineOwnMetadata(\n      metadataKey, metadataValue,\n      (targetKey !== undefined ? anObject : aFunction)(target),\n      toMetaKey(targetKey)\n    );\n  };\n}});","deps":{"./_a-function":"node_modules/babel-polyfill/node_modules/core-js/modules/_a-function.js","./_an-object":"node_modules/babel-polyfill/node_modules/core-js/modules/_an-object.js","./_metadata":"node_modules/babel-polyfill/node_modules/core-js/modules/_metadata.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.set.to-json.js","source":"var $export  = require('./_export');\n\n$export($export.P + $export.R, 'Set', {toJSON: require('./_collection-to-json')('Set')});","deps":{"./_collection-to-json":"node_modules/babel-polyfill/node_modules/core-js/modules/_collection-to-json.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.string.at.js","source":"'use strict';\n// https://github.com/mathiasbynens/String.prototype.at\nvar $export = require('./_export')\n  , $at     = require('./_string-at')(true);\n\n$export($export.P, 'String', {\n  at: function at(pos){\n    return $at(this, pos);\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_string-at":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-at.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.string.match-all.js","source":"'use strict';\n// https://tc39.github.io/String.prototype.matchAll/\nvar $export     = require('./_export')\n  , defined     = require('./_defined')\n  , toLength    = require('./_to-length')\n  , isRegExp    = require('./_is-regexp')\n  , getFlags    = require('./_flags')\n  , RegExpProto = RegExp.prototype;\n\nvar $RegExpStringIterator = function(regexp, string){\n  this._r = regexp;\n  this._s = string;\n};\n\nrequire('./_iter-create')($RegExpStringIterator, 'RegExp String', function next(){\n  var match = this._r.exec(this._s);\n  return {value: match, done: match === null};\n});\n\n$export($export.P, 'String', {\n  matchAll: function matchAll(regexp){\n    defined(this);\n    if(!isRegExp(regexp))throw TypeError(regexp + ' is not a regexp!');\n    var S     = String(this)\n      , flags = 'flags' in RegExpProto ? String(regexp.flags) : getFlags.call(regexp)\n      , rx    = new RegExp(regexp.source, ~flags.indexOf('g') ? flags : 'g' + flags);\n    rx.lastIndex = toLength(regexp.lastIndex);\n    return new $RegExpStringIterator(rx, S);\n  }\n});","deps":{"./_defined":"node_modules/babel-polyfill/node_modules/core-js/modules/_defined.js","./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_flags":"node_modules/babel-polyfill/node_modules/core-js/modules/_flags.js","./_is-regexp":"node_modules/babel-polyfill/node_modules/core-js/modules/_is-regexp.js","./_iter-create":"node_modules/babel-polyfill/node_modules/core-js/modules/_iter-create.js","./_to-length":"node_modules/babel-polyfill/node_modules/core-js/modules/_to-length.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.string.pad-end.js","source":"'use strict';\n// https://github.com/tc39/proposal-string-pad-start-end\nvar $export = require('./_export')\n  , $pad    = require('./_string-pad');\n\n$export($export.P, 'String', {\n  padEnd: function padEnd(maxLength /*, fillString = ' ' */){\n    return $pad(this, maxLength, arguments.length > 1 ? arguments[1] : undefined, false);\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_string-pad":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-pad.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.string.pad-start.js","source":"'use strict';\n// https://github.com/tc39/proposal-string-pad-start-end\nvar $export = require('./_export')\n  , $pad    = require('./_string-pad');\n\n$export($export.P, 'String', {\n  padStart: function padStart(maxLength /*, fillString = ' ' */){\n    return $pad(this, maxLength, arguments.length > 1 ? arguments[1] : undefined, true);\n  }\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_string-pad":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-pad.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.string.trim-left.js","source":"'use strict';\n// https://github.com/sebmarkbage/ecmascript-string-left-right-trim\nrequire('./_string-trim')('trimLeft', function($trim){\n  return function trimLeft(){\n    return $trim(this, 1);\n  };\n}, 'trimStart');","deps":{"./_string-trim":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-trim.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.string.trim-right.js","source":"'use strict';\n// https://github.com/sebmarkbage/ecmascript-string-left-right-trim\nrequire('./_string-trim')('trimRight', function($trim){\n  return function trimRight(){\n    return $trim(this, 2);\n  };\n}, 'trimEnd');","deps":{"./_string-trim":"node_modules/babel-polyfill/node_modules/core-js/modules/_string-trim.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.symbol.async-iterator.js","source":"require('./_wks-define')('asyncIterator');","deps":{"./_wks-define":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks-define.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.symbol.observable.js","source":"require('./_wks-define')('observable');","deps":{"./_wks-define":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks-define.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.system.global.js","source":"var $export = require('./_export');\n\n$export($export.S, 'System', {global: require('./_global')});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/web.dom.iterable.js","source":"var $iterators    = require('./es6.array.iterator')\n  , redefine      = require('./_redefine')\n  , global        = require('./_global')\n  , hide          = require('./_hide')\n  , Iterators     = require('./_iterators')\n  , wks           = require('./_wks')\n  , ITERATOR      = wks('iterator')\n  , TO_STRING_TAG = wks('toStringTag')\n  , ArrayValues   = Iterators.Array;\n\nfor(var collections = ['NodeList', 'DOMTokenList', 'MediaList', 'StyleSheetList', 'CSSRuleList'], i = 0; i < 5; i++){\n  var NAME       = collections[i]\n    , Collection = global[NAME]\n    , proto      = Collection && Collection.prototype\n    , key;\n  if(proto){\n    if(!proto[ITERATOR])hide(proto, ITERATOR, ArrayValues);\n    if(!proto[TO_STRING_TAG])hide(proto, TO_STRING_TAG, NAME);\n    Iterators[NAME] = ArrayValues;\n    for(key in $iterators)if(!proto[key])redefine(proto, key, $iterators[key], true);\n  }\n}","deps":{"./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_hide":"node_modules/babel-polyfill/node_modules/core-js/modules/_hide.js","./_iterators":"node_modules/babel-polyfill/node_modules/core-js/modules/_iterators.js","./_redefine":"node_modules/babel-polyfill/node_modules/core-js/modules/_redefine.js","./_wks":"node_modules/babel-polyfill/node_modules/core-js/modules/_wks.js","./es6.array.iterator":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.iterator.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/web.immediate.js","source":"var $export = require('./_export')\n  , $task   = require('./_task');\n$export($export.G + $export.B, {\n  setImmediate:   $task.set,\n  clearImmediate: $task.clear\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_task":"node_modules/babel-polyfill/node_modules/core-js/modules/_task.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/modules/web.timers.js","source":"var global     = require('./_global')\n  , $export    = require('./_export')\n  , invoke     = require('./_invoke')\n  , partial    = require('./_partial')\n  , navigator  = global.navigator\n  , MSIE       = !!navigator && /MSIE .\\./.test(navigator.userAgent); // <- dirty ie9- check\nvar wrap = function(set){\n  return MSIE ? function(fn, time /*, ...args */){\n    return set(invoke(\n      partial,\n      [].slice.call(arguments, 2),\n      typeof fn == 'function' ? fn : Function(fn)\n    ), time);\n  } : set;\n};\n$export($export.G + $export.B + $export.F * MSIE, {\n  setTimeout:  wrap(global.setTimeout),\n  setInterval: wrap(global.setInterval)\n});","deps":{"./_export":"node_modules/babel-polyfill/node_modules/core-js/modules/_export.js","./_global":"node_modules/babel-polyfill/node_modules/core-js/modules/_global.js","./_invoke":"node_modules/babel-polyfill/node_modules/core-js/modules/_invoke.js","./_partial":"node_modules/babel-polyfill/node_modules/core-js/modules/_partial.js"}},{"id":"node_modules/babel-polyfill/node_modules/core-js/shim.js","source":"require('./modules/es6.symbol');\nrequire('./modules/es6.object.create');\nrequire('./modules/es6.object.define-property');\nrequire('./modules/es6.object.define-properties');\nrequire('./modules/es6.object.get-own-property-descriptor');\nrequire('./modules/es6.object.get-prototype-of');\nrequire('./modules/es6.object.keys');\nrequire('./modules/es6.object.get-own-property-names');\nrequire('./modules/es6.object.freeze');\nrequire('./modules/es6.object.seal');\nrequire('./modules/es6.object.prevent-extensions');\nrequire('./modules/es6.object.is-frozen');\nrequire('./modules/es6.object.is-sealed');\nrequire('./modules/es6.object.is-extensible');\nrequire('./modules/es6.object.assign');\nrequire('./modules/es6.object.is');\nrequire('./modules/es6.object.set-prototype-of');\nrequire('./modules/es6.object.to-string');\nrequire('./modules/es6.function.bind');\nrequire('./modules/es6.function.name');\nrequire('./modules/es6.function.has-instance');\nrequire('./modules/es6.parse-int');\nrequire('./modules/es6.parse-float');\nrequire('./modules/es6.number.constructor');\nrequire('./modules/es6.number.to-fixed');\nrequire('./modules/es6.number.to-precision');\nrequire('./modules/es6.number.epsilon');\nrequire('./modules/es6.number.is-finite');\nrequire('./modules/es6.number.is-integer');\nrequire('./modules/es6.number.is-nan');\nrequire('./modules/es6.number.is-safe-integer');\nrequire('./modules/es6.number.max-safe-integer');\nrequire('./modules/es6.number.min-safe-integer');\nrequire('./modules/es6.number.parse-float');\nrequire('./modules/es6.number.parse-int');\nrequire('./modules/es6.math.acosh');\nrequire('./modules/es6.math.asinh');\nrequire('./modules/es6.math.atanh');\nrequire('./modules/es6.math.cbrt');\nrequire('./modules/es6.math.clz32');\nrequire('./modules/es6.math.cosh');\nrequire('./modules/es6.math.expm1');\nrequire('./modules/es6.math.fround');\nrequire('./modules/es6.math.hypot');\nrequire('./modules/es6.math.imul');\nrequire('./modules/es6.math.log10');\nrequire('./modules/es6.math.log1p');\nrequire('./modules/es6.math.log2');\nrequire('./modules/es6.math.sign');\nrequire('./modules/es6.math.sinh');\nrequire('./modules/es6.math.tanh');\nrequire('./modules/es6.math.trunc');\nrequire('./modules/es6.string.from-code-point');\nrequire('./modules/es6.string.raw');\nrequire('./modules/es6.string.trim');\nrequire('./modules/es6.string.iterator');\nrequire('./modules/es6.string.code-point-at');\nrequire('./modules/es6.string.ends-with');\nrequire('./modules/es6.string.includes');\nrequire('./modules/es6.string.repeat');\nrequire('./modules/es6.string.starts-with');\nrequire('./modules/es6.string.anchor');\nrequire('./modules/es6.string.big');\nrequire('./modules/es6.string.blink');\nrequire('./modules/es6.string.bold');\nrequire('./modules/es6.string.fixed');\nrequire('./modules/es6.string.fontcolor');\nrequire('./modules/es6.string.fontsize');\nrequire('./modules/es6.string.italics');\nrequire('./modules/es6.string.link');\nrequire('./modules/es6.string.small');\nrequire('./modules/es6.string.strike');\nrequire('./modules/es6.string.sub');\nrequire('./modules/es6.string.sup');\nrequire('./modules/es6.date.now');\nrequire('./modules/es6.date.to-json');\nrequire('./modules/es6.date.to-iso-string');\nrequire('./modules/es6.date.to-string');\nrequire('./modules/es6.date.to-primitive');\nrequire('./modules/es6.array.is-array');\nrequire('./modules/es6.array.from');\nrequire('./modules/es6.array.of');\nrequire('./modules/es6.array.join');\nrequire('./modules/es6.array.slice');\nrequire('./modules/es6.array.sort');\nrequire('./modules/es6.array.for-each');\nrequire('./modules/es6.array.map');\nrequire('./modules/es6.array.filter');\nrequire('./modules/es6.array.some');\nrequire('./modules/es6.array.every');\nrequire('./modules/es6.array.reduce');\nrequire('./modules/es6.array.reduce-right');\nrequire('./modules/es6.array.index-of');\nrequire('./modules/es6.array.last-index-of');\nrequire('./modules/es6.array.copy-within');\nrequire('./modules/es6.array.fill');\nrequire('./modules/es6.array.find');\nrequire('./modules/es6.array.find-index');\nrequire('./modules/es6.array.species');\nrequire('./modules/es6.array.iterator');\nrequire('./modules/es6.regexp.constructor');\nrequire('./modules/es6.regexp.to-string');\nrequire('./modules/es6.regexp.flags');\nrequire('./modules/es6.regexp.match');\nrequire('./modules/es6.regexp.replace');\nrequire('./modules/es6.regexp.search');\nrequire('./modules/es6.regexp.split');\nrequire('./modules/es6.promise');\nrequire('./modules/es6.map');\nrequire('./modules/es6.set');\nrequire('./modules/es6.weak-map');\nrequire('./modules/es6.weak-set');\nrequire('./modules/es6.typed.array-buffer');\nrequire('./modules/es6.typed.data-view');\nrequire('./modules/es6.typed.int8-array');\nrequire('./modules/es6.typed.uint8-array');\nrequire('./modules/es6.typed.uint8-clamped-array');\nrequire('./modules/es6.typed.int16-array');\nrequire('./modules/es6.typed.uint16-array');\nrequire('./modules/es6.typed.int32-array');\nrequire('./modules/es6.typed.uint32-array');\nrequire('./modules/es6.typed.float32-array');\nrequire('./modules/es6.typed.float64-array');\nrequire('./modules/es6.reflect.apply');\nrequire('./modules/es6.reflect.construct');\nrequire('./modules/es6.reflect.define-property');\nrequire('./modules/es6.reflect.delete-property');\nrequire('./modules/es6.reflect.enumerate');\nrequire('./modules/es6.reflect.get');\nrequire('./modules/es6.reflect.get-own-property-descriptor');\nrequire('./modules/es6.reflect.get-prototype-of');\nrequire('./modules/es6.reflect.has');\nrequire('./modules/es6.reflect.is-extensible');\nrequire('./modules/es6.reflect.own-keys');\nrequire('./modules/es6.reflect.prevent-extensions');\nrequire('./modules/es6.reflect.set');\nrequire('./modules/es6.reflect.set-prototype-of');\nrequire('./modules/es7.array.includes');\nrequire('./modules/es7.string.at');\nrequire('./modules/es7.string.pad-start');\nrequire('./modules/es7.string.pad-end');\nrequire('./modules/es7.string.trim-left');\nrequire('./modules/es7.string.trim-right');\nrequire('./modules/es7.string.match-all');\nrequire('./modules/es7.symbol.async-iterator');\nrequire('./modules/es7.symbol.observable');\nrequire('./modules/es7.object.get-own-property-descriptors');\nrequire('./modules/es7.object.values');\nrequire('./modules/es7.object.entries');\nrequire('./modules/es7.object.define-getter');\nrequire('./modules/es7.object.define-setter');\nrequire('./modules/es7.object.lookup-getter');\nrequire('./modules/es7.object.lookup-setter');\nrequire('./modules/es7.map.to-json');\nrequire('./modules/es7.set.to-json');\nrequire('./modules/es7.system.global');\nrequire('./modules/es7.error.is-error');\nrequire('./modules/es7.math.iaddh');\nrequire('./modules/es7.math.isubh');\nrequire('./modules/es7.math.imulh');\nrequire('./modules/es7.math.umulh');\nrequire('./modules/es7.reflect.define-metadata');\nrequire('./modules/es7.reflect.delete-metadata');\nrequire('./modules/es7.reflect.get-metadata');\nrequire('./modules/es7.reflect.get-metadata-keys');\nrequire('./modules/es7.reflect.get-own-metadata');\nrequire('./modules/es7.reflect.get-own-metadata-keys');\nrequire('./modules/es7.reflect.has-metadata');\nrequire('./modules/es7.reflect.has-own-metadata');\nrequire('./modules/es7.reflect.metadata');\nrequire('./modules/es7.asap');\nrequire('./modules/es7.observable');\nrequire('./modules/web.timers');\nrequire('./modules/web.immediate');\nrequire('./modules/web.dom.iterable');\nmodule.exports = require('./modules/_core');","deps":{"./modules/_core":"node_modules/babel-polyfill/node_modules/core-js/modules/_core.js","./modules/es6.array.copy-within":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.copy-within.js","./modules/es6.array.every":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.every.js","./modules/es6.array.fill":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.fill.js","./modules/es6.array.filter":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.filter.js","./modules/es6.array.find":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.find.js","./modules/es6.array.find-index":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.find-index.js","./modules/es6.array.for-each":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.for-each.js","./modules/es6.array.from":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.from.js","./modules/es6.array.index-of":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.index-of.js","./modules/es6.array.is-array":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.is-array.js","./modules/es6.array.iterator":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.iterator.js","./modules/es6.array.join":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.join.js","./modules/es6.array.last-index-of":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.last-index-of.js","./modules/es6.array.map":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.map.js","./modules/es6.array.of":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.of.js","./modules/es6.array.reduce":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.reduce.js","./modules/es6.array.reduce-right":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.reduce-right.js","./modules/es6.array.slice":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.slice.js","./modules/es6.array.some":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.some.js","./modules/es6.array.sort":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.sort.js","./modules/es6.array.species":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.array.species.js","./modules/es6.date.now":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.date.now.js","./modules/es6.date.to-iso-string":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.date.to-iso-string.js","./modules/es6.date.to-json":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.date.to-json.js","./modules/es6.date.to-primitive":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.date.to-primitive.js","./modules/es6.date.to-string":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.date.to-string.js","./modules/es6.function.bind":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.function.bind.js","./modules/es6.function.has-instance":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.function.has-instance.js","./modules/es6.function.name":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.function.name.js","./modules/es6.map":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.map.js","./modules/es6.math.acosh":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.acosh.js","./modules/es6.math.asinh":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.asinh.js","./modules/es6.math.atanh":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.atanh.js","./modules/es6.math.cbrt":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.cbrt.js","./modules/es6.math.clz32":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.clz32.js","./modules/es6.math.cosh":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.cosh.js","./modules/es6.math.expm1":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.expm1.js","./modules/es6.math.fround":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.fround.js","./modules/es6.math.hypot":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.hypot.js","./modules/es6.math.imul":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.imul.js","./modules/es6.math.log10":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.log10.js","./modules/es6.math.log1p":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.log1p.js","./modules/es6.math.log2":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.log2.js","./modules/es6.math.sign":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.sign.js","./modules/es6.math.sinh":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.sinh.js","./modules/es6.math.tanh":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.tanh.js","./modules/es6.math.trunc":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.math.trunc.js","./modules/es6.number.constructor":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.constructor.js","./modules/es6.number.epsilon":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.epsilon.js","./modules/es6.number.is-finite":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.is-finite.js","./modules/es6.number.is-integer":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.is-integer.js","./modules/es6.number.is-nan":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.is-nan.js","./modules/es6.number.is-safe-integer":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.is-safe-integer.js","./modules/es6.number.max-safe-integer":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.max-safe-integer.js","./modules/es6.number.min-safe-integer":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.min-safe-integer.js","./modules/es6.number.parse-float":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.parse-float.js","./modules/es6.number.parse-int":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.parse-int.js","./modules/es6.number.to-fixed":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.to-fixed.js","./modules/es6.number.to-precision":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.number.to-precision.js","./modules/es6.object.assign":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.assign.js","./modules/es6.object.create":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.create.js","./modules/es6.object.define-properties":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.define-properties.js","./modules/es6.object.define-property":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.define-property.js","./modules/es6.object.freeze":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.freeze.js","./modules/es6.object.get-own-property-descriptor":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.get-own-property-descriptor.js","./modules/es6.object.get-own-property-names":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.get-own-property-names.js","./modules/es6.object.get-prototype-of":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.get-prototype-of.js","./modules/es6.object.is":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.is.js","./modules/es6.object.is-extensible":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.is-extensible.js","./modules/es6.object.is-frozen":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.is-frozen.js","./modules/es6.object.is-sealed":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.is-sealed.js","./modules/es6.object.keys":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.keys.js","./modules/es6.object.prevent-extensions":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.prevent-extensions.js","./modules/es6.object.seal":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.seal.js","./modules/es6.object.set-prototype-of":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.set-prototype-of.js","./modules/es6.object.to-string":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.object.to-string.js","./modules/es6.parse-float":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.parse-float.js","./modules/es6.parse-int":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.parse-int.js","./modules/es6.promise":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.promise.js","./modules/es6.reflect.apply":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.apply.js","./modules/es6.reflect.construct":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.construct.js","./modules/es6.reflect.define-property":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.define-property.js","./modules/es6.reflect.delete-property":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.delete-property.js","./modules/es6.reflect.enumerate":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.enumerate.js","./modules/es6.reflect.get":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.get.js","./modules/es6.reflect.get-own-property-descriptor":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.get-own-property-descriptor.js","./modules/es6.reflect.get-prototype-of":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.get-prototype-of.js","./modules/es6.reflect.has":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.has.js","./modules/es6.reflect.is-extensible":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.is-extensible.js","./modules/es6.reflect.own-keys":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.own-keys.js","./modules/es6.reflect.prevent-extensions":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.prevent-extensions.js","./modules/es6.reflect.set":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.set.js","./modules/es6.reflect.set-prototype-of":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.reflect.set-prototype-of.js","./modules/es6.regexp.constructor":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.regexp.constructor.js","./modules/es6.regexp.flags":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.regexp.flags.js","./modules/es6.regexp.match":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.regexp.match.js","./modules/es6.regexp.replace":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.regexp.replace.js","./modules/es6.regexp.search":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.regexp.search.js","./modules/es6.regexp.split":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.regexp.split.js","./modules/es6.regexp.to-string":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.regexp.to-string.js","./modules/es6.set":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.set.js","./modules/es6.string.anchor":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.anchor.js","./modules/es6.string.big":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.big.js","./modules/es6.string.blink":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.blink.js","./modules/es6.string.bold":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.bold.js","./modules/es6.string.code-point-at":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.code-point-at.js","./modules/es6.string.ends-with":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.ends-with.js","./modules/es6.string.fixed":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.fixed.js","./modules/es6.string.fontcolor":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.fontcolor.js","./modules/es6.string.fontsize":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.fontsize.js","./modules/es6.string.from-code-point":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.from-code-point.js","./modules/es6.string.includes":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.includes.js","./modules/es6.string.italics":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.italics.js","./modules/es6.string.iterator":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.iterator.js","./modules/es6.string.link":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.link.js","./modules/es6.string.raw":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.raw.js","./modules/es6.string.repeat":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.repeat.js","./modules/es6.string.small":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.small.js","./modules/es6.string.starts-with":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.starts-with.js","./modules/es6.string.strike":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.strike.js","./modules/es6.string.sub":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.sub.js","./modules/es6.string.sup":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.sup.js","./modules/es6.string.trim":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.string.trim.js","./modules/es6.symbol":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.symbol.js","./modules/es6.typed.array-buffer":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.typed.array-buffer.js","./modules/es6.typed.data-view":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.typed.data-view.js","./modules/es6.typed.float32-array":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.typed.float32-array.js","./modules/es6.typed.float64-array":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.typed.float64-array.js","./modules/es6.typed.int16-array":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.typed.int16-array.js","./modules/es6.typed.int32-array":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.typed.int32-array.js","./modules/es6.typed.int8-array":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.typed.int8-array.js","./modules/es6.typed.uint16-array":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.typed.uint16-array.js","./modules/es6.typed.uint32-array":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.typed.uint32-array.js","./modules/es6.typed.uint8-array":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.typed.uint8-array.js","./modules/es6.typed.uint8-clamped-array":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.typed.uint8-clamped-array.js","./modules/es6.weak-map":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.weak-map.js","./modules/es6.weak-set":"node_modules/babel-polyfill/node_modules/core-js/modules/es6.weak-set.js","./modules/es7.array.includes":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.array.includes.js","./modules/es7.asap":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.asap.js","./modules/es7.error.is-error":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.error.is-error.js","./modules/es7.map.to-json":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.map.to-json.js","./modules/es7.math.iaddh":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.math.iaddh.js","./modules/es7.math.imulh":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.math.imulh.js","./modules/es7.math.isubh":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.math.isubh.js","./modules/es7.math.umulh":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.math.umulh.js","./modules/es7.object.define-getter":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.object.define-getter.js","./modules/es7.object.define-setter":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.object.define-setter.js","./modules/es7.object.entries":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.object.entries.js","./modules/es7.object.get-own-property-descriptors":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.object.get-own-property-descriptors.js","./modules/es7.object.lookup-getter":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.object.lookup-getter.js","./modules/es7.object.lookup-setter":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.object.lookup-setter.js","./modules/es7.object.values":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.object.values.js","./modules/es7.observable":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.observable.js","./modules/es7.reflect.define-metadata":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.reflect.define-metadata.js","./modules/es7.reflect.delete-metadata":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.reflect.delete-metadata.js","./modules/es7.reflect.get-metadata":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.reflect.get-metadata.js","./modules/es7.reflect.get-metadata-keys":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.reflect.get-metadata-keys.js","./modules/es7.reflect.get-own-metadata":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.reflect.get-own-metadata.js","./modules/es7.reflect.get-own-metadata-keys":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.reflect.get-own-metadata-keys.js","./modules/es7.reflect.has-metadata":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.reflect.has-metadata.js","./modules/es7.reflect.has-own-metadata":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.reflect.has-own-metadata.js","./modules/es7.reflect.metadata":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.reflect.metadata.js","./modules/es7.set.to-json":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.set.to-json.js","./modules/es7.string.at":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.string.at.js","./modules/es7.string.match-all":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.string.match-all.js","./modules/es7.string.pad-end":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.string.pad-end.js","./modules/es7.string.pad-start":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.string.pad-start.js","./modules/es7.string.trim-left":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.string.trim-left.js","./modules/es7.string.trim-right":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.string.trim-right.js","./modules/es7.symbol.async-iterator":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.symbol.async-iterator.js","./modules/es7.symbol.observable":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.symbol.observable.js","./modules/es7.system.global":"node_modules/babel-polyfill/node_modules/core-js/modules/es7.system.global.js","./modules/web.dom.iterable":"node_modules/babel-polyfill/node_modules/core-js/modules/web.dom.iterable.js","./modules/web.immediate":"node_modules/babel-polyfill/node_modules/core-js/modules/web.immediate.js","./modules/web.timers":"node_modules/babel-polyfill/node_modules/core-js/modules/web.timers.js"}},{"id":"node_modules/process/browser.js","source":"var process = module.exports = {};\n\n// cached from whatever global is present so that test runners that stub it\n// don't break things.  But we need to wrap it in a try catch in case it is\n// wrapped in strict mode code which doesn't define any globals.  It's inside a\n// function because try/catches deoptimize in certain engines.\n\nvar cachedSetTimeout;\nvar cachedClearTimeout;\n\nfunction defaultSetTimout() {\n    throw new Error('setTimeout has not been defined');\n}\nfunction defaultClearTimeout () {\n    throw new Error('clearTimeout has not been defined');\n}\n(function () {\n    try {\n        if (typeof setTimeout === 'function') {\n            cachedSetTimeout = setTimeout;\n        } else {\n            cachedSetTimeout = defaultSetTimout;\n        }\n    } catch (e) {\n        cachedSetTimeout = defaultSetTimout;\n    }\n    try {\n        if (typeof clearTimeout === 'function') {\n            cachedClearTimeout = clearTimeout;\n        } else {\n            cachedClearTimeout = defaultClearTimeout;\n        }\n    } catch (e) {\n        cachedClearTimeout = defaultClearTimeout;\n    }\n} ())\nfunction runTimeout(fun) {\n    if (cachedSetTimeout === setTimeout) {\n        //normal enviroments in sane situations\n        return setTimeout(fun, 0);\n    }\n    // if setTimeout wasn't available but was latter defined\n    if ((cachedSetTimeout === defaultSetTimout || !cachedSetTimeout) && setTimeout) {\n        cachedSetTimeout = setTimeout;\n        return setTimeout(fun, 0);\n    }\n    try {\n        // when when somebody has screwed with setTimeout but no I.E. maddness\n        return cachedSetTimeout(fun, 0);\n    } catch(e){\n        try {\n            // When we are in I.E. but the script has been evaled so I.E. doesn't trust the global object when called normally\n            return cachedSetTimeout.call(null, fun, 0);\n        } catch(e){\n            // same as above but when it's a version of I.E. that must have the global object for 'this', hopfully our context correct otherwise it will throw a global error\n            return cachedSetTimeout.call(this, fun, 0);\n        }\n    }\n\n\n}\nfunction runClearTimeout(marker) {\n    if (cachedClearTimeout === clearTimeout) {\n        //normal enviroments in sane situations\n        return clearTimeout(marker);\n    }\n    // if clearTimeout wasn't available but was latter defined\n    if ((cachedClearTimeout === defaultClearTimeout || !cachedClearTimeout) && clearTimeout) {\n        cachedClearTimeout = clearTimeout;\n        return clearTimeout(marker);\n    }\n    try {\n        // when when somebody has screwed with setTimeout but no I.E. maddness\n        return cachedClearTimeout(marker);\n    } catch (e){\n        try {\n            // When we are in I.E. but the script has been evaled so I.E. doesn't  trust the global object when called normally\n            return cachedClearTimeout.call(null, marker);\n        } catch (e){\n            // same as above but when it's a version of I.E. that must have the global object for 'this', hopfully our context correct otherwise it will throw a global error.\n            // Some versions of I.E. have different rules for clearTimeout vs setTimeout\n            return cachedClearTimeout.call(this, marker);\n        }\n    }\n\n\n\n}\nvar queue = [];\nvar draining = false;\nvar currentQueue;\nvar queueIndex = -1;\n\nfunction cleanUpNextTick() {\n    if (!draining || !currentQueue) {\n        return;\n    }\n    draining = false;\n    if (currentQueue.length) {\n        queue = currentQueue.concat(queue);\n    } else {\n        queueIndex = -1;\n    }\n    if (queue.length) {\n        drainQueue();\n    }\n}\n\nfunction drainQueue() {\n    if (draining) {\n        return;\n    }\n    var timeout = runTimeout(cleanUpNextTick);\n    draining = true;\n\n    var len = queue.length;\n    while(len) {\n        currentQueue = queue;\n        queue = [];\n        while (++queueIndex < len) {\n            if (currentQueue) {\n                currentQueue[queueIndex].run();\n            }\n        }\n        queueIndex = -1;\n        len = queue.length;\n    }\n    currentQueue = null;\n    draining = false;\n    runClearTimeout(timeout);\n}\n\nprocess.nextTick = function (fun) {\n    var args = new Array(arguments.length - 1);\n    if (arguments.length > 1) {\n        for (var i = 1; i < arguments.length; i++) {\n            args[i - 1] = arguments[i];\n        }\n    }\n    queue.push(new Item(fun, args));\n    if (queue.length === 1 && !draining) {\n        runTimeout(drainQueue);\n    }\n};\n\n// v8 likes predictible objects\nfunction Item(fun, array) {\n    this.fun = fun;\n    this.array = array;\n}\nItem.prototype.run = function () {\n    this.fun.apply(null, this.array);\n};\nprocess.title = 'browser';\nprocess.browser = true;\nprocess.env = {};\nprocess.argv = [];\nprocess.version = ''; // empty string to avoid regexp issues\nprocess.versions = {};\n\nfunction noop() {}\n\nprocess.on = noop;\nprocess.addListener = noop;\nprocess.once = noop;\nprocess.off = noop;\nprocess.removeListener = noop;\nprocess.removeAllListeners = noop;\nprocess.emit = noop;\nprocess.prependListener = noop;\nprocess.prependOnceListener = noop;\n\nprocess.listeners = function (name) { return [] }\n\nprocess.binding = function (name) {\n    throw new Error('process.binding is not supported');\n};\n\nprocess.cwd = function () { return '/' };\nprocess.chdir = function (dir) {\n    throw new Error('process.chdir is not supported');\n};\nprocess.umask = function() { return 0; };","deps":{}},{"id":"node_modules/regenerator-runtime/runtime.js","source":"(function (process,global){\n/**\n * Copyright (c) 2014, Facebook, Inc.\n * All rights reserved.\n *\n * This source code is licensed under the BSD-style license found in the\n * https://raw.github.com/facebook/regenerator/master/LICENSE file. An\n * additional grant of patent rights can be found in the PATENTS file in\n * the same directory.\n */\n\n!(function(global) {\n  \"use strict\";\n\n  var hasOwn = Object.prototype.hasOwnProperty;\n  var undefined; // More compressible than void 0.\n  var $Symbol = typeof Symbol === \"function\" ? Symbol : {};\n  var iteratorSymbol = $Symbol.iterator || \"@@iterator\";\n  var toStringTagSymbol = $Symbol.toStringTag || \"@@toStringTag\";\n\n  var inModule = typeof module === \"object\";\n  var runtime = global.regeneratorRuntime;\n  if (runtime) {\n    if (inModule) {\n      // If regeneratorRuntime is defined globally and we're in a module,\n      // make the exports object identical to regeneratorRuntime.\n      module.exports = runtime;\n    }\n    // Don't bother evaluating the rest of this file if the runtime was\n    // already defined globally.\n    return;\n  }\n\n  // Define the runtime globally (as expected by generated code) as either\n  // module.exports (if we're in a module) or a new, empty object.\n  runtime = global.regeneratorRuntime = inModule ? module.exports : {};\n\n  function wrap(innerFn, outerFn, self, tryLocsList) {\n    // If outerFn provided and outerFn.prototype is a Generator, then outerFn.prototype instanceof Generator.\n    var protoGenerator = outerFn && outerFn.prototype instanceof Generator ? outerFn : Generator;\n    var generator = Object.create(protoGenerator.prototype);\n    var context = new Context(tryLocsList || []);\n\n    // The ._invoke method unifies the implementations of the .next,\n    // .throw, and .return methods.\n    generator._invoke = makeInvokeMethod(innerFn, self, context);\n\n    return generator;\n  }\n  runtime.wrap = wrap;\n\n  // Try/catch helper to minimize deoptimizations. Returns a completion\n  // record like context.tryEntries[i].completion. This interface could\n  // have been (and was previously) designed to take a closure to be\n  // invoked without arguments, but in all the cases we care about we\n  // already have an existing method we want to call, so there's no need\n  // to create a new function object. We can even get away with assuming\n  // the method takes exactly one argument, since that happens to be true\n  // in every case, so we don't have to touch the arguments object. The\n  // only additional allocation required is the completion record, which\n  // has a stable shape and so hopefully should be cheap to allocate.\n  function tryCatch(fn, obj, arg) {\n    try {\n      return { type: \"normal\", arg: fn.call(obj, arg) };\n    } catch (err) {\n      return { type: \"throw\", arg: err };\n    }\n  }\n\n  var GenStateSuspendedStart = \"suspendedStart\";\n  var GenStateSuspendedYield = \"suspendedYield\";\n  var GenStateExecuting = \"executing\";\n  var GenStateCompleted = \"completed\";\n\n  // Returning this object from the innerFn has the same effect as\n  // breaking out of the dispatch switch statement.\n  var ContinueSentinel = {};\n\n  // Dummy constructor functions that we use as the .constructor and\n  // .constructor.prototype properties for functions that return Generator\n  // objects. For full spec compliance, you may wish to configure your\n  // minifier not to mangle the names of these two functions.\n  function Generator() {}\n  function GeneratorFunction() {}\n  function GeneratorFunctionPrototype() {}\n\n  var Gp = GeneratorFunctionPrototype.prototype = Generator.prototype;\n  GeneratorFunction.prototype = Gp.constructor = GeneratorFunctionPrototype;\n  GeneratorFunctionPrototype.constructor = GeneratorFunction;\n  GeneratorFunctionPrototype[toStringTagSymbol] = GeneratorFunction.displayName = \"GeneratorFunction\";\n\n  // Helper for defining the .next, .throw, and .return methods of the\n  // Iterator interface in terms of a single ._invoke method.\n  function defineIteratorMethods(prototype) {\n    [\"next\", \"throw\", \"return\"].forEach(function(method) {\n      prototype[method] = function(arg) {\n        return this._invoke(method, arg);\n      };\n    });\n  }\n\n  runtime.isGeneratorFunction = function(genFun) {\n    var ctor = typeof genFun === \"function\" && genFun.constructor;\n    return ctor\n      ? ctor === GeneratorFunction ||\n        // For the native GeneratorFunction constructor, the best we can\n        // do is to check its .name property.\n        (ctor.displayName || ctor.name) === \"GeneratorFunction\"\n      : false;\n  };\n\n  runtime.mark = function(genFun) {\n    if (Object.setPrototypeOf) {\n      Object.setPrototypeOf(genFun, GeneratorFunctionPrototype);\n    } else {\n      genFun.__proto__ = GeneratorFunctionPrototype;\n      if (!(toStringTagSymbol in genFun)) {\n        genFun[toStringTagSymbol] = \"GeneratorFunction\";\n      }\n    }\n    genFun.prototype = Object.create(Gp);\n    return genFun;\n  };\n\n  // Within the body of any async function, `await x` is transformed to\n  // `yield regeneratorRuntime.awrap(x)`, so that the runtime can test\n  // `value instanceof AwaitArgument` to determine if the yielded value is\n  // meant to be awaited. Some may consider the name of this method too\n  // cutesy, but they are curmudgeons.\n  runtime.awrap = function(arg) {\n    return new AwaitArgument(arg);\n  };\n\n  function AwaitArgument(arg) {\n    this.arg = arg;\n  }\n\n  function AsyncIterator(generator) {\n    function invoke(method, arg, resolve, reject) {\n      var record = tryCatch(generator[method], generator, arg);\n      if (record.type === \"throw\") {\n        reject(record.arg);\n      } else {\n        var result = record.arg;\n        var value = result.value;\n        if (value instanceof AwaitArgument) {\n          return Promise.resolve(value.arg).then(function(value) {\n            invoke(\"next\", value, resolve, reject);\n          }, function(err) {\n            invoke(\"throw\", err, resolve, reject);\n          });\n        }\n\n        return Promise.resolve(value).then(function(unwrapped) {\n          // When a yielded Promise is resolved, its final value becomes\n          // the .value of the Promise<{value,done}> result for the\n          // current iteration. If the Promise is rejected, however, the\n          // result for this iteration will be rejected with the same\n          // reason. Note that rejections of yielded Promises are not\n          // thrown back into the generator function, as is the case\n          // when an awaited Promise is rejected. This difference in\n          // behavior between yield and await is important, because it\n          // allows the consumer to decide what to do with the yielded\n          // rejection (swallow it and continue, manually .throw it back\n          // into the generator, abandon iteration, whatever). With\n          // await, by contrast, there is no opportunity to examine the\n          // rejection reason outside the generator function, so the\n          // only option is to throw it from the await expression, and\n          // let the generator function handle the exception.\n          result.value = unwrapped;\n          resolve(result);\n        }, reject);\n      }\n    }\n\n    if (typeof process === \"object\" && process.domain) {\n      invoke = process.domain.bind(invoke);\n    }\n\n    var previousPromise;\n\n    function enqueue(method, arg) {\n      function callInvokeWithMethodAndArg() {\n        return new Promise(function(resolve, reject) {\n          invoke(method, arg, resolve, reject);\n        });\n      }\n\n      return previousPromise =\n        // If enqueue has been called before, then we want to wait until\n        // all previous Promises have been resolved before calling invoke,\n        // so that results are always delivered in the correct order. If\n        // enqueue has not been called before, then it is important to\n        // call invoke immediately, without waiting on a callback to fire,\n        // so that the async generator function has the opportunity to do\n        // any necessary setup in a predictable way. This predictability\n        // is why the Promise constructor synchronously invokes its\n        // executor callback, and why async functions synchronously\n        // execute code before the first await. Since we implement simple\n        // async functions in terms of async generators, it is especially\n        // important to get this right, even though it requires care.\n        previousPromise ? previousPromise.then(\n          callInvokeWithMethodAndArg,\n          // Avoid propagating failures to Promises returned by later\n          // invocations of the iterator.\n          callInvokeWithMethodAndArg\n        ) : callInvokeWithMethodAndArg();\n    }\n\n    // Define the unified helper method that is used to implement .next,\n    // .throw, and .return (see defineIteratorMethods).\n    this._invoke = enqueue;\n  }\n\n  defineIteratorMethods(AsyncIterator.prototype);\n\n  // Note that simple async functions are implemented on top of\n  // AsyncIterator objects; they just return a Promise for the value of\n  // the final result produced by the iterator.\n  runtime.async = function(innerFn, outerFn, self, tryLocsList) {\n    var iter = new AsyncIterator(\n      wrap(innerFn, outerFn, self, tryLocsList)\n    );\n\n    return runtime.isGeneratorFunction(outerFn)\n      ? iter // If outerFn is a generator, return the full iterator.\n      : iter.next().then(function(result) {\n          return result.done ? result.value : iter.next();\n        });\n  };\n\n  function makeInvokeMethod(innerFn, self, context) {\n    var state = GenStateSuspendedStart;\n\n    return function invoke(method, arg) {\n      if (state === GenStateExecuting) {\n        throw new Error(\"Generator is already running\");\n      }\n\n      if (state === GenStateCompleted) {\n        if (method === \"throw\") {\n          throw arg;\n        }\n\n        // Be forgiving, per 25.3.3.3.3 of the spec:\n        // https://people.mozilla.org/~jorendorff/es6-draft.html#sec-generatorresume\n        return doneResult();\n      }\n\n      while (true) {\n        var delegate = context.delegate;\n        if (delegate) {\n          if (method === \"return\" ||\n              (method === \"throw\" && delegate.iterator[method] === undefined)) {\n            // A return or throw (when the delegate iterator has no throw\n            // method) always terminates the yield* loop.\n            context.delegate = null;\n\n            // If the delegate iterator has a return method, give it a\n            // chance to clean up.\n            var returnMethod = delegate.iterator[\"return\"];\n            if (returnMethod) {\n              var record = tryCatch(returnMethod, delegate.iterator, arg);\n              if (record.type === \"throw\") {\n                // If the return method threw an exception, let that\n                // exception prevail over the original return or throw.\n                method = \"throw\";\n                arg = record.arg;\n                continue;\n              }\n            }\n\n            if (method === \"return\") {\n              // Continue with the outer return, now that the delegate\n              // iterator has been terminated.\n              continue;\n            }\n          }\n\n          var record = tryCatch(\n            delegate.iterator[method],\n            delegate.iterator,\n            arg\n          );\n\n          if (record.type === \"throw\") {\n            context.delegate = null;\n\n            // Like returning generator.throw(uncaught), but without the\n            // overhead of an extra function call.\n            method = \"throw\";\n            arg = record.arg;\n            continue;\n          }\n\n          // Delegate generator ran and handled its own exceptions so\n          // regardless of what the method was, we continue as if it is\n          // \"next\" with an undefined arg.\n          method = \"next\";\n          arg = undefined;\n\n          var info = record.arg;\n          if (info.done) {\n            context[delegate.resultName] = info.value;\n            context.next = delegate.nextLoc;\n          } else {\n            state = GenStateSuspendedYield;\n            return info;\n          }\n\n          context.delegate = null;\n        }\n\n        if (method === \"next\") {\n          // Setting context._sent for legacy support of Babel's\n          // function.sent implementation.\n          context.sent = context._sent = arg;\n\n        } else if (method === \"throw\") {\n          if (state === GenStateSuspendedStart) {\n            state = GenStateCompleted;\n            throw arg;\n          }\n\n          if (context.dispatchException(arg)) {\n            // If the dispatched exception was caught by a catch block,\n            // then let that catch block handle the exception normally.\n            method = \"next\";\n            arg = undefined;\n          }\n\n        } else if (method === \"return\") {\n          context.abrupt(\"return\", arg);\n        }\n\n        state = GenStateExecuting;\n\n        var record = tryCatch(innerFn, self, context);\n        if (record.type === \"normal\") {\n          // If an exception is thrown from innerFn, we leave state ===\n          // GenStateExecuting and loop back for another invocation.\n          state = context.done\n            ? GenStateCompleted\n            : GenStateSuspendedYield;\n\n          var info = {\n            value: record.arg,\n            done: context.done\n          };\n\n          if (record.arg === ContinueSentinel) {\n            if (context.delegate && method === \"next\") {\n              // Deliberately forget the last sent value so that we don't\n              // accidentally pass it on to the delegate.\n              arg = undefined;\n            }\n          } else {\n            return info;\n          }\n\n        } else if (record.type === \"throw\") {\n          state = GenStateCompleted;\n          // Dispatch the exception by looping back around to the\n          // context.dispatchException(arg) call above.\n          method = \"throw\";\n          arg = record.arg;\n        }\n      }\n    };\n  }\n\n  // Define Generator.prototype.{next,throw,return} in terms of the\n  // unified ._invoke helper method.\n  defineIteratorMethods(Gp);\n\n  Gp[iteratorSymbol] = function() {\n    return this;\n  };\n\n  Gp[toStringTagSymbol] = \"Generator\";\n\n  Gp.toString = function() {\n    return \"[object Generator]\";\n  };\n\n  function pushTryEntry(locs) {\n    var entry = { tryLoc: locs[0] };\n\n    if (1 in locs) {\n      entry.catchLoc = locs[1];\n    }\n\n    if (2 in locs) {\n      entry.finallyLoc = locs[2];\n      entry.afterLoc = locs[3];\n    }\n\n    this.tryEntries.push(entry);\n  }\n\n  function resetTryEntry(entry) {\n    var record = entry.completion || {};\n    record.type = \"normal\";\n    delete record.arg;\n    entry.completion = record;\n  }\n\n  function Context(tryLocsList) {\n    // The root entry object (effectively a try statement without a catch\n    // or a finally block) gives us a place to store values thrown from\n    // locations where there is no enclosing try statement.\n    this.tryEntries = [{ tryLoc: \"root\" }];\n    tryLocsList.forEach(pushTryEntry, this);\n    this.reset(true);\n  }\n\n  runtime.keys = function(object) {\n    var keys = [];\n    for (var key in object) {\n      keys.push(key);\n    }\n    keys.reverse();\n\n    // Rather than returning an object with a next method, we keep\n    // things simple and return the next function itself.\n    return function next() {\n      while (keys.length) {\n        var key = keys.pop();\n        if (key in object) {\n          next.value = key;\n          next.done = false;\n          return next;\n        }\n      }\n\n      // To avoid creating an additional object, we just hang the .value\n      // and .done properties off the next function object itself. This\n      // also ensures that the minifier will not anonymize the function.\n      next.done = true;\n      return next;\n    };\n  };\n\n  function values(iterable) {\n    if (iterable) {\n      var iteratorMethod = iterable[iteratorSymbol];\n      if (iteratorMethod) {\n        return iteratorMethod.call(iterable);\n      }\n\n      if (typeof iterable.next === \"function\") {\n        return iterable;\n      }\n\n      if (!isNaN(iterable.length)) {\n        var i = -1, next = function next() {\n          while (++i < iterable.length) {\n            if (hasOwn.call(iterable, i)) {\n              next.value = iterable[i];\n              next.done = false;\n              return next;\n            }\n          }\n\n          next.value = undefined;\n          next.done = true;\n\n          return next;\n        };\n\n        return next.next = next;\n      }\n    }\n\n    // Return an iterator with no values.\n    return { next: doneResult };\n  }\n  runtime.values = values;\n\n  function doneResult() {\n    return { value: undefined, done: true };\n  }\n\n  Context.prototype = {\n    constructor: Context,\n\n    reset: function(skipTempReset) {\n      this.prev = 0;\n      this.next = 0;\n      // Resetting context._sent for legacy support of Babel's\n      // function.sent implementation.\n      this.sent = this._sent = undefined;\n      this.done = false;\n      this.delegate = null;\n\n      this.tryEntries.forEach(resetTryEntry);\n\n      if (!skipTempReset) {\n        for (var name in this) {\n          // Not sure about the optimal order of these conditions:\n          if (name.charAt(0) === \"t\" &&\n              hasOwn.call(this, name) &&\n              !isNaN(+name.slice(1))) {\n            this[name] = undefined;\n          }\n        }\n      }\n    },\n\n    stop: function() {\n      this.done = true;\n\n      var rootEntry = this.tryEntries[0];\n      var rootRecord = rootEntry.completion;\n      if (rootRecord.type === \"throw\") {\n        throw rootRecord.arg;\n      }\n\n      return this.rval;\n    },\n\n    dispatchException: function(exception) {\n      if (this.done) {\n        throw exception;\n      }\n\n      var context = this;\n      function handle(loc, caught) {\n        record.type = \"throw\";\n        record.arg = exception;\n        context.next = loc;\n        return !!caught;\n      }\n\n      for (var i = this.tryEntries.length - 1; i >= 0; --i) {\n        var entry = this.tryEntries[i];\n        var record = entry.completion;\n\n        if (entry.tryLoc === \"root\") {\n          // Exception thrown outside of any try block that could handle\n          // it, so set the completion value of the entire function to\n          // throw the exception.\n          return handle(\"end\");\n        }\n\n        if (entry.tryLoc <= this.prev) {\n          var hasCatch = hasOwn.call(entry, \"catchLoc\");\n          var hasFinally = hasOwn.call(entry, \"finallyLoc\");\n\n          if (hasCatch && hasFinally) {\n            if (this.prev < entry.catchLoc) {\n              return handle(entry.catchLoc, true);\n            } else if (this.prev < entry.finallyLoc) {\n              return handle(entry.finallyLoc);\n            }\n\n          } else if (hasCatch) {\n            if (this.prev < entry.catchLoc) {\n              return handle(entry.catchLoc, true);\n            }\n\n          } else if (hasFinally) {\n            if (this.prev < entry.finallyLoc) {\n              return handle(entry.finallyLoc);\n            }\n\n          } else {\n            throw new Error(\"try statement without catch or finally\");\n          }\n        }\n      }\n    },\n\n    abrupt: function(type, arg) {\n      for (var i = this.tryEntries.length - 1; i >= 0; --i) {\n        var entry = this.tryEntries[i];\n        if (entry.tryLoc <= this.prev &&\n            hasOwn.call(entry, \"finallyLoc\") &&\n            this.prev < entry.finallyLoc) {\n          var finallyEntry = entry;\n          break;\n        }\n      }\n\n      if (finallyEntry &&\n          (type === \"break\" ||\n           type === \"continue\") &&\n          finallyEntry.tryLoc <= arg &&\n          arg <= finallyEntry.finallyLoc) {\n        // Ignore the finally entry if control is not jumping to a\n        // location outside the try/catch block.\n        finallyEntry = null;\n      }\n\n      var record = finallyEntry ? finallyEntry.completion : {};\n      record.type = type;\n      record.arg = arg;\n\n      if (finallyEntry) {\n        this.next = finallyEntry.finallyLoc;\n      } else {\n        this.complete(record);\n      }\n\n      return ContinueSentinel;\n    },\n\n    complete: function(record, afterLoc) {\n      if (record.type === \"throw\") {\n        throw record.arg;\n      }\n\n      if (record.type === \"break\" ||\n          record.type === \"continue\") {\n        this.next = record.arg;\n      } else if (record.type === \"return\") {\n        this.rval = record.arg;\n        this.next = \"end\";\n      } else if (record.type === \"normal\" && afterLoc) {\n        this.next = afterLoc;\n      }\n    },\n\n    finish: function(finallyLoc) {\n      for (var i = this.tryEntries.length - 1; i >= 0; --i) {\n        var entry = this.tryEntries[i];\n        if (entry.finallyLoc === finallyLoc) {\n          this.complete(entry.completion, entry.afterLoc);\n          resetTryEntry(entry);\n          return ContinueSentinel;\n        }\n      }\n    },\n\n    \"catch\": function(tryLoc) {\n      for (var i = this.tryEntries.length - 1; i >= 0; --i) {\n        var entry = this.tryEntries[i];\n        if (entry.tryLoc === tryLoc) {\n          var record = entry.completion;\n          if (record.type === \"throw\") {\n            var thrown = record.arg;\n            resetTryEntry(entry);\n          }\n          return thrown;\n        }\n      }\n\n      // The context.catch method must only be called with a location\n      // argument that corresponds to a known catch block.\n      throw new Error(\"illegal catch attempt\");\n    },\n\n    delegateYield: function(iterable, resultName, nextLoc) {\n      this.delegate = {\n        iterator: values(iterable),\n        resultName: resultName,\n        nextLoc: nextLoc\n      };\n\n      return ContinueSentinel;\n    }\n  };\n})(\n  // Among the various tricks for obtaining a reference to the global\n  // object, this seems to be the most reliable technique that does not\n  // use indirect eval (which violates Content Security Policy).\n  typeof global === \"object\" ? global :\n  typeof window === \"object\" ? window :\n  typeof self === \"object\" ? self : this\n);\n\n}).call(this,require('_process'),typeof global !== \"undefined\" ? global : typeof self !== \"undefined\" ? self : typeof window !== \"undefined\" ? window : {})","deps":{"_process":"node_modules/process/browser.js"}},{"id":"src/main/js/ie/Error.js","source":"\"use strict\";\n\n//\n// Explicit polyfill for Error functions not supported in IE\n// and semingly not polyfilled by Babel.\n//\n\n// Error.captureStackTrace\n//\n// Only on ref to it in the Babel org on GitHub:\n// https://github.com/search?q=org%3Ababel+captureStackTrace&type=Code\n//\nError.captureStackTrace = Error.captureStackTrace || function (obj) {\n    if (Error.prepareStackTrace) {\n        var frame = {\n            isEval: function isEval() {\n                return false;\n            },\n            getFileName: function getFileName() {\n                return \"filename\";\n            },\n            getLineNumber: function getLineNumber() {\n                return 1;\n            },\n            getColumnNumber: function getColumnNumber() {\n                return 1;\n            },\n            getFunctionName: function getFunctionName() {\n                return \"functionName\";\n            }\n        };\n\n        obj.stack = Error.prepareStackTrace(obj, [frame, frame, frame]);\n    } else {\n        obj.stack = obj.stack || obj.name || \"Error\";\n    }\n};","deps":{}},{"id":"src/main/js/ie/iepolyfills.js","source":"var ___$$$___requiredModuleMappings = [];\n\nvar ___$$$___jsModules = require('@jenkins-cd/js-modules');\n\nif (!window.jenkinsCIGlobal) {\n    window.jenkinsCIGlobal = {};\n}\nif (!window.jenkinsCIGlobal._internal) {\n    window.jenkinsCIGlobal._internal = {};\n}\n\nvar whoami = 'iepolyfills';\nvar loadTimestamp = Date.now();\n\n___$$$___jsModules.whoami(whoami);\n\n// Clear out the session storage if this is the first\n// bundle to export on the page.\nvar trackKeyPrefix = 'jenkins-cd/js-modules/tracking/';\nif (window.sessionStorage && !jenkinsCIGlobal._internal.bundleLoadIdx) {\n    jenkinsCIGlobal._internal.bundleLoadIdx = 0;\n    var toRemove = [];\n    for (var i = 0; i < sessionStorage.length; i++) {\n        var key = sessionStorage.key(i);\n        if (key.indexOf(trackKeyPrefix) === 0) {\n            toRemove.push(key);\n        }\n    }\n    for (var i = 0; i < toRemove.length; i++) {\n        sessionStorage.removeItem(toRemove[i]);\n    }\n}\njenkinsCIGlobal._internal.bundleLoadIdx++;\n\nif (window.sessionStorage) {\n    sessionStorage.setItem(trackKeyPrefix + 'load:' + whoami, JSON.stringify({\n        event: 'load',\n        bundleId: whoami,\n        bundlePath: 'target/classes/org/jenkins/ui/jsmodules/blueocean-web/iepolyfills.js',\n        at: loadTimestamp,\n        loadIdx: jenkinsCIGlobal._internal.bundleLoadIdx\n    }));\n}\n\nfunction ___$$$___doExport(namespace, moduleName, module) {\n    var exportedModuleId = (namespace !== undefined ? (namespace + ':' + moduleName) : moduleName);\n    try {\n        ___$$$___jsModules.requireModule(exportedModuleId);\n        // No exception => already exported. Shouldn't happen, but okay !!\n        return;\n    } catch (e) {\n        // Not exported yet, hence exception on require. Okay to export !!\n        ___$$$___jsModules.exportModule(namespace, moduleName, module);\n        if (window.sessionStorage) {\n            sessionStorage.setItem(trackKeyPrefix + 'export:' + exportedModuleId, JSON.stringify({\n                event: 'export',\n                moduleId: exportedModuleId,\n                at: loadTimestamp,\n                bundleId: whoami\n            }));\n        }\n    }\n}\n\n/*** Start Module Exec Function ***************************************/\nfunction ___$$$___exec(onExec) {\n    'use strict';\n\n/*\n * The MIT License\n *\n * Copyright (c) 2016, CloudBees, Inc.\n *\n * Permission is hereby granted, free of charge, to any person obtaining a copy\n * of this software and associated documentation files (the \"Software\"), to deal\n * in the Software without restriction, including without limitation the rights\n * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell\n * copies of the Software, and to permit persons to whom the Software is\n * furnished to do so, subject to the following conditions:\n *\n * The above copyright notice and this permission notice shall be included in\n * all copies or substantial portions of the Software.\n *\n * THE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\n * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\n * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\n * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\n * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\n * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN\n * THE SOFTWARE.\n */\n\n/**\n * Internet explorer specific polyfills\n */\n\nrequire('./Error');\nrequire('babel-polyfill');\n\n    onExec();\n}\n/*** End Module Exec Function   ***************************************/\n\nfunction ___$$$___doExports() {\n    // Do exports, if any ....\n    ___$$$___doExport(undefined, 'iepolyfills', {});\n\n}\n\nfunction ___$$$___doCSS() {\n}\n\nfunction ___$$$___doBundleInit() {\n    try {\n        ___$$$___exec(function() {\n            ___$$$___doExports();\n            ___$$$___doCSS();\n        });\n    } catch (e) {\n        console.error('Error initializing Jenkins JavaScript bundle \"iepolyfills\"', e);\n    }\n}\n\nif (___$$$___requiredModuleMappings.length > 0) {\n    ___$$$___jsModules.importModule.apply(___$$$___jsModules.importModule, ___$$$___requiredModuleMappings)\n        .onFulfilled(function() {\n        ___$$$___doBundleInit();\n    });\n} else {\n    ___$$$___doBundleInit();\n}","deps":{"./Error":"src/main/js/ie/Error.js","@jenkins-cd/js-modules":"node_modules/@jenkins-cd/js-modules/js/index.js","babel-polyfill":"node_modules/babel-polyfill/lib/index.js"},"entry":true}]